@@ -3,7 +3,7 @@
  *  @brief  This class provides fast point location.
  *  This is an abstract class.
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -301,7 +301,7 @@ Bool EnclosingSimplexAlgorithmImplementation::checkPointInSimplex(const Point &
   Point v(dimension + 1, 1.0);
   for (UnsignedInteger i = 0; i < dimension; ++i)
     v[i] = point[i];
-  const Point coordinates(simplexMatrix.solveLinearSystem(v, false));
+  const Point coordinates(simplexMatrix.solveLinearSystemInPlace(v));
   for (UnsignedInteger i = 0; i <= dimension; ++i)
     if (!(coordinates[i] >= 0.0 && coordinates[i] <= 1.0))
       return false;
