@@ -2,7 +2,7 @@
 /**
  *  @brief Catalog records all user information to a file or tty
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -32,33 +32,28 @@
 BEGIN_NAMESPACE_OPENTURNS
 
 
-static pthread_mutex_t Catalog_InstanceMutex_;
+static std::mutex Catalog_InstanceMutex_;
 static Catalog * Catalog_P_instance_ = 0;
 static const Catalog_init static_initializer_Catalog;
 
 Catalog_init::Catalog_init()
 {
-  if (!Catalog_P_instance_)
+  static std::once_flag flag;
+  std::call_once(flag, [&]()
   {
-#ifndef OT_MUTEXINIT_NOCHECK
-    pthread_mutexattr_t attr;
-    pthread_mutexattr_init( &attr );
-    pthread_mutexattr_settype( &attr, PTHREAD_MUTEX_ERRORCHECK );
-    pthread_mutex_init( &Catalog_InstanceMutex_, &attr );
-#else
-    pthread_mutex_init( &Catalog_InstanceMutex_, NULL );
-#endif
     Catalog_P_instance_ = new Catalog;
-  }
+  });
   assert(Catalog_P_instance_);
 }
 
 Catalog_init::~Catalog_init()
 {
-  if (Catalog_P_instance_)
-    pthread_mutex_destroy(&Catalog_InstanceMutex_);
-  delete Catalog_P_instance_;
-  Catalog_P_instance_ = 0;
+  static std::once_flag flag;
+  std::call_once(flag, [&]()
+  {
+    delete Catalog_P_instance_;
+    Catalog_P_instance_ = 0;
+  });
 }
 
 
