@@ -2,7 +2,7 @@
 /**
  *  @brief ResourceMap defines top-most resourceMap strategies
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -18,9 +18,11 @@
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
-#include <unistd.h>                 // for sysconf
-#include "openturns/OTthread.hxx"
+#include <mutex>
 #include "openturns/OTconfig.hxx"
+#ifdef OPENTURNS_HAVE_UNISTD_H
+#include <unistd.h>                 // for sysconf
+#endif
 #include "openturns/OSS.hxx"
 #include "openturns/ResourceMap.hxx"
 #include "openturns/Exception.hxx"
@@ -42,33 +44,28 @@ static const char * XMLTag_value_int              = "value_int";
 static const char * XMLTag_value_bool             = "value_bool";
 #endif
 
-static pthread_mutex_t ResourceMap_InstanceMutex_;
+static std::mutex ResourceMap_InstanceMutex_;
 static ResourceMap * ResourceMap_P_instance_ = 0;
 static const ResourceMap_init static_initializer_ResourceMap;
 
 ResourceMap_init::ResourceMap_init()
 {
-  if (!ResourceMap_P_instance_)
+  static std::once_flag flag;
+  std::call_once(flag, [&]()
   {
-#ifndef OT_MUTEXINIT_NOCHECK
-    pthread_mutexattr_t attr;
-    pthread_mutexattr_init( &attr);
-    pthread_mutexattr_settype(&attr, PTHREAD_MUTEX_RECURSIVE);
-    pthread_mutex_init(&ResourceMap_InstanceMutex_, &attr);
-#else
-    pthread_mutex_init(&ResourceMap_InstanceMutex_, NULL);
-#endif
     ResourceMap_P_instance_ = new ResourceMap;
-  }
+  });
   assert(ResourceMap_P_instance_);
 }
 
 ResourceMap_init::~ResourceMap_init()
 {
-  if (ResourceMap_P_instance_)
-    pthread_mutex_destroy(&ResourceMap_InstanceMutex_);
-  delete ResourceMap_P_instance_;
-  ResourceMap_P_instance_ = 0;
+  static std::once_flag flag;
+  std::call_once(flag, [&]()
+  {
+    delete ResourceMap_P_instance_;
+    ResourceMap_P_instance_ = 0;
+  });
 }
 
 
@@ -718,7 +715,6 @@ void ResourceMap::loadDefaultConfiguration()
   addAsString("Drawable-DefaultPattern", "s");
   addAsString("Drawable-DefaultPointStyle", "plus");
   addAsString("Drawable-DefaultSurfaceColor", "white");
-  addAsString("Drawable-NoSpecifiedLabel", "");
   addAsUnsignedInteger("Drawable-DataThreshold", 2000);
   addAsUnsignedInteger("Drawable-DefaultPalettePhase", 12);
 
@@ -726,15 +722,9 @@ void ResourceMap::loadDefaultConfiguration()
   addAsScalar("Text-DefaultTextSize", 0.75);
 
   // GraphImplementation parameters //
-#ifdef R_EXECUTABLE
-  addAsString("Graph-RExecutableCommand", R_EXECUTABLE);
-#else
-  addAsString("Graph-RExecutableCommand", "");
-#endif
   addAsScalar("Graph-DefaultHorizontalMargin", 0.05);
   addAsScalar("Graph-DefaultLegendFontSize", 1.0);
   addAsScalar("Graph-DefaultVerticalMargin", 0.05);
-  addAsString("Graph-NoSpecifiedLabel", "");
   addAsUnsignedInteger("Graph-DefaultHeight", 480);
   addAsUnsignedInteger("Graph-DefaultWidth", 640);
 
@@ -817,14 +807,6 @@ void ResourceMap::loadDefaultConfiguration()
   addAsUnsignedInteger("Pagmo-pso-variant", 5);
   addAsUnsignedInteger("Pagmo-pso-neighb_type", 2);
   addAsUnsignedInteger("Pagmo-pso-neighb_param", 4);
-  // pso_gen
-  addAsScalar("Pagmo-pso_gen-omega", 0.7298);
-  addAsScalar("Pagmo-pso_gen-eta1", 2.05);
-  addAsScalar("Pagmo-pso_gen-eta2", 2.05);
-  addAsScalar("Pagmo-pso_gen-max_vel", 0.5);
-  addAsUnsignedInteger("Pagmo-pso_gen-variant", 5);
-  addAsUnsignedInteger("Pagmo-pso_gen-neighb_type", 2);
-  addAsUnsignedInteger("Pagmo-pso_gen-neighb_param", 4);
   // sga
   addAsScalar("Pagmo-sga-cr", 0.9);
   addAsScalar("Pagmo-sga-eta_c", 1.0);
@@ -992,7 +974,9 @@ void ResourceMap::loadDefaultConfiguration()
   addAsUnsignedInteger("FAST-DefaultResamplingSize", 1);
 
   // HSIC parameters //
+  addAsBool("HSICEstimator-ParallelPValues", true);
   addAsUnsignedInteger("HSICEstimator-PermutationSize", 100);
+  addAsUnsignedInteger("HSICEstimator-InputCovarianceMatrixCacheSizeMb", 1000); // 1 Gb
 
   // RandomGenerator parameters //
   addAsUnsignedInteger("RandomGenerator-InitialSeed", 0);
@@ -1003,6 +987,9 @@ void ResourceMap::loadDefaultConfiguration()
   addAsScalar("CovarianceModel-DefaultTMin", -5.0);
   addAsUnsignedInteger("CovarianceModel-DefaultPointNumber",  129);
 
+  // DiracCovarianceModel parameters //
+  addAsBool("DiracCovarianceModel-CheckUnique", true);
+
   // SpectralModel parameters //
   addAsScalar("SpectralModel-DefaultMaximumFrequency",  5.0);
   addAsScalar("SpectralModel-DefaultMinimumFrequency", -5.0);
@@ -1021,6 +1008,7 @@ void ResourceMap::loadDefaultConfiguration()
   addAsString("Sample-CommentMarkers", "#");
   addAsUnsignedInteger("Sample-PrintEllipsisSize", 3);
   addAsUnsignedInteger("Sample-PrintEllipsisThreshold", 1000);
+  addAsString("Sample-PrintFormat", "{:.7g}");
   addAsUnsignedInteger("Sample-SmallKendallTau", 23);
 
   // DomainImplementation parameters
@@ -1046,6 +1034,12 @@ void ResourceMap::loadDefaultConfiguration()
 
   // Matrix parameters
   addAsUnsignedInteger("Matrix-size-visible-in-str-from", 5);
+  addAsScalar("Matrix-DefaultSmallPivot", 1.0e-7 );
+  addAsScalar("Matrix-LargestEigenValueRelativeError", 1.0e-4);
+  addAsScalar("Matrix-SymmetryThreshold", 1.0e-12);
+  addAsUnsignedInteger("Matrix-LargestEigenValueIterations", 50);
+  addAsScalar("Matrix-MaximalScaling", 1.0e-5);
+  addAsScalar("Matrix-StartingScaling", 1.0e-13);
 
   // Tensor parameters
   addAsUnsignedInteger("Tensor-size-visible-in-str-from", 5);
@@ -1053,12 +1047,6 @@ void ResourceMap::loadDefaultConfiguration()
   // Tensor parameters
   addAsUnsignedInteger("ComplexTensor-size-visible-in-str-from", 6);
 
-  // MatrixImplementation parameters //
-  addAsScalar("Matrix-DefaultSmallPivot", 1.0e-7 );
-  addAsScalar("Matrix-LargestEigenValueRelativeError", 1.0e-4);
-  addAsScalar("Matrix-SymmetryThreshold", 1.0e-12);
-  addAsUnsignedInteger("Matrix-LargestEigenValueIterations", 50);
-
   // BernsteinCopulaFactory parameters //
   addAsScalar("BernsteinCopulaFactory-alpha", 1.0);
   addAsString("BernsteinCopulaFactory-BinNumberSelectionMethod", "LogLikelihood");
@@ -1109,6 +1097,24 @@ void ResourceMap::loadDefaultConfiguration()
 
   // GeneralizedExtremeValue parameters //
   addAsScalar("GeneralizedExtremeValue-XiThreshold", 1.0e-6);
+  addAsScalar("GeneralizedExtremeValue-MMin", 1.05);
+  addAsScalar("GeneralizedExtremeValue-MMax", 1.0e3);
+
+  // GeneralizedExtremeValueFactory parameters //
+  addAsUnsignedInteger("GeneralizedExtremeValueFactory-MaximumEvaluationNumber", 10000);
+  addAsUnsignedInteger("GeneralizedExtremeValueFactory-FeasibilityMaximumIterationNumber", 100);
+  addAsScalar("GeneralizedExtremeValueFactory-FeasibilityRhoFactor", -1.5);
+  addAsScalar("GeneralizedExtremeValueFactory-XiSearchLowerBound", -5.0);
+  addAsScalar("GeneralizedExtremeValueFactory-XiSearchUpperBound", 5.0);
+  addAsString("GeneralizedExtremeValueFactory-InitializationMethod", "Gumbel");
+  addAsString("GeneralizedExtremeValueFactory-NormalizationMethod", "MinMax");
+
+  // ProfileLikelihoodResult parameters //
+  addAsScalar("ProfileLikelihoodResult-AbsolutePrecision", 1.0e-10);
+  addAsScalar("ProfileLikelihoodResult-RelativePrecision", 1.0e-10);
+  addAsScalar("ProfileLikelihoodResult-ConfidenceIntervalMargin", 0.05);
+  addAsScalar("ProfileLikelihoodResult-TextMargin", 0.03);
+  addAsScalar("ProfileLikelihoodResult-StartingScaling", 1e-2);
 
   // GeneralizedParetoFactory parameters //
   addAsScalar("GeneralizedParetoFactory-MaximumAbsoluteError", 1.0e-10);
@@ -1244,6 +1250,10 @@ void ResourceMap::loadDefaultConfiguration()
   // UserDefined parameters //
   addAsUnsignedInteger("UserDefined-SmallSize", 10000);
 
+  // UniformOverMesh parameters //
+  addAsUnsignedInteger("UniformOverMesh-MarginalIntegrationNodesNumber", 64);
+  addAsUnsignedInteger("UniformOverMesh-MaximumIntegrationNodesNumber", 262144);
+
   // VonMisesFactory parameters //
   addAsScalar("VonMisesFactory-AbsolutePrecision", 1.0e-12);
   addAsScalar("VonMisesFactory-RelativePrecision", 1.0e-12);
@@ -1329,7 +1339,10 @@ void ResourceMap::loadDefaultConfiguration()
   addAsUnsignedInteger("SubsetSampling-DefaultMaximumOuterSampling", 10000);
 
   // NAIS parameters //
-  addAsScalar("NAIS-DefaultRhoQuantile", 0.25);
+  addAsScalar("NAIS-DefaultQuantileLevel", 0.25);
+
+  // Cross Entropy Importance Sampling parameters //
+  addAsScalar("CrossEntropyImportanceSampling-DefaultQuantileLevel", 0.25);
 
   // DirectionalSampling parameters //
   addAsUnsignedInteger("DirectionalSampling-MeanContributionIntegrationNodesNumber", 255);
@@ -1373,8 +1386,20 @@ void ResourceMap::loadDefaultConfiguration()
   addAsBool("FunctionalChaosAlgorithm-Sparse", false);
   addAsString("FunctionalChaosAlgorithm-FittingAlgorithm", "CorrectedLeaveOneOut");
 
+  // LeastSquaresExpansion parameters //
+  addAsString("LeastSquaresExpansion-DecompositionMethod", "QR");
+
+  // FunctionalChaosResult parameters //
+  addAsUnsignedInteger("FunctionalChaosResult-PrintEllipsisSize", 3);
+  addAsUnsignedInteger("FunctionalChaosResult-PrintEllipsisThreshold", 1000);
+  addAsString("FunctionalChaosResult-PrintFormat", "{:.7g}");
+  addAsUnsignedInteger("FunctionalChaosResult-PrintColumnWidth", 15);
+
   // FunctionalChaosSobolIndices parameters //
   addAsScalar("FunctionalChaosSobolIndices-VariancePartThreshold", 1.0e-2);
+  addAsString("FunctionalChaosSobolIndices-PrintFormat", "{:.6f}");
+  addAsUnsignedInteger("FunctionalChaosSobolIndices-MaximumNumberOfOutput", 1000);
+  addAsUnsignedInteger("FunctionalChaosSobolIndices-PrintColumnWidth", 15);
 
   // LinearModelAlgorithm parameters //
   addAsString("LinearModelAlgorithm-DecompositionMethod", "QR");
@@ -1392,15 +1417,11 @@ void ResourceMap::loadDefaultConfiguration()
   addAsScalar("GeneralLinearModelAlgorithm-DefaultOptimizationLowerBound", 1.0e-2);
   addAsScalar("GeneralLinearModelAlgorithm-DefaultOptimizationScaleFactor", 2.0);
   addAsScalar("GeneralLinearModelAlgorithm-DefaultOptimizationUpperBound", 1.0e2);
-  addAsScalar("GeneralLinearModelAlgorithm-MaximalScaling", 1.0e-5);
   addAsScalar("GeneralLinearModelAlgorithm-MeanEpsilon", 1.0e-12);
-  addAsScalar("GeneralLinearModelAlgorithm-StartingScaling", 1.0e-13);
   addAsString("GeneralLinearModelAlgorithm-DefaultOptimizationAlgorithm", "TNC");
   addAsString("GeneralLinearModelAlgorithm-LinearAlgebra", "LAPACK");
 
   // KrigingAlgorithm parameters //
-  addAsScalar("KrigingAlgorithm-MaximalScaling", 1.0e-5);
-  addAsScalar("KrigingAlgorithm-StartingScaling", 1.0e-13);
   addAsString("KrigingAlgorithm-LinearAlgebra", "LAPACK");
 
   // SquaredExponential parameters //
@@ -1441,6 +1462,7 @@ void ResourceMap::loadDefaultConfiguration()
   addAsScalar("Distribution-DefaultQuantileEpsilon", 1.0e-12);
   addAsScalar("Distribution-DefaultPDFEpsilon", 1.0e-14);
   addAsScalar("Distribution-DefaultCDFEpsilon", 1.0e-14);
+  addAsScalar("Distribution-DependenceEpsilon", 1.0e-12);
   addAsScalar("Distribution-DiscreteDrawPDFScaling", 0.25);
   addAsString("Distribution-EntropySamplingMethod", "MonteCarlo");
   addAsUnsignedInteger("Distribution-CharacteristicFunctionBlockMax", 20);
@@ -1505,8 +1527,6 @@ void ResourceMap::loadDefaultConfiguration()
   addAsUnsignedInteger("HMatrix-ValidationRerun", 0);
 
   // GaussianProcess parameters //
-  addAsScalar("GaussianProcess-MaximalScaling", 1.0e-5);
-  addAsScalar("GaussianProcess-StartingScaling", 1.0e-13);
   addAsUnsignedInteger("GaussianProcess-GibbsMaximumIteration", 100);
 
   // SpectralGaussianProcess parameters //
@@ -1528,18 +1548,20 @@ void ResourceMap::loadDefaultConfiguration()
   addAsUnsignedInteger("BoxCoxFactory-DefaultPointNumber", 201);
 
   // VisualTest parameters //
+  addAsUnsignedInteger("VisualTest-CloudSmallSize", 100);
+  addAsUnsignedInteger("VisualTest-CloudMediumSize", 1000);
   addAsUnsignedInteger("VisualTest-KendallPlot-MonteCarloSize", 100);
+  addAsScalar("VisualTest-DependenceConfidenceLevel", 0.95);
 
   // RandomWalkMetropolisHastings parameters //
   addAsScalar("RandomWalkMetropolisHastings-DefaultAdaptationExpansionFactor", 1.2);
   addAsScalar("RandomWalkMetropolisHastings-DefaultAdaptationLowerBound", 0.117); // = 0.5 * 0.234
   addAsScalar("RandomWalkMetropolisHastings-DefaultAdaptationShrinkFactor", 0.8);
   addAsScalar("RandomWalkMetropolisHastings-DefaultAdaptationUpperBound", 0.468); // = 2.0 * 0.234
-  addAsUnsignedInteger("RandomWalkMetropolisHastings-DefaultAdaptationPeriod", 100);
+  addAsUnsignedInteger("RandomWalkMetropolisHastings-DefaultAdaptationPeriod", 30);
 
   // MetropolisHastingsImplementation parameters //
-  addAsUnsignedInteger("MetropolisHastings-DefaultBurnIn", 0);
-  addAsUnsignedInteger("MetropolisHastings-DefaultThinning", 1);
+  addAsUnsignedInteger("RandomWalkMetropolisHastings-DefaultBurnIn", 1000);
 
   // GaussianLinearCalibration parameters //
   addAsString("GaussianLinearCalibration-Method", "QR");
@@ -1556,16 +1578,22 @@ void ResourceMap::loadDefaultConfiguration()
   addAsUnsignedInteger("GaussianNonLinearCalibration-BootstrapSize", 100);
   addAsUnsignedInteger("GaussianNonLinearCalibration-MultiStartSize", 100);
 
+  // CalibrationResult parameters //
+  addAsScalar("CalibrationResult-xRangeMarginFactor", 0.2);
+  addAsString("CalibrationResult-PriorLineStyle", "dashed");
+  addAsString("CalibrationResult-PosteriorLineStyle", "dotdash");
+  addAsString("CalibrationResult-ObservationLineStyle", "solid");
+  addAsString("CalibrationResult-PriorPointStyle", "circle");
+  addAsString("CalibrationResult-PosteriorPointStyle", "diamond");
+  addAsString("CalibrationResult-ObservationPointStyle", "fsquare");
+
   // ARMA parameters //
   addAsScalar("ARMA-MeanEpsilon", 1.0e-14);
 
   // ARMALikelihoodFactory parameters //
   addAsScalar("ARMALikelihoodFactory-DefaultRhoBeg", 0.01);
   addAsScalar("ARMALikelihoodFactory-DefaultRhoEnd", 1.0e-10);
-  addAsScalar("ARMALikelihoodFactory-DefaultStartingPointScale", 1.0);
-  addAsScalar("ARMALikelihoodFactory-MaximalScaling", 1.0e-5);
   addAsScalar("ARMALikelihoodFactory-RootEpsilon", 1.0e-6);
-  addAsScalar("ARMALikelihoodFactory-StartingScaling", 1.0e-13);
   addAsUnsignedInteger("ARMALikelihoodFactory-DefaultMaximumEvaluationNumber", 10000);
 
   // FittingTest parameters //
@@ -1594,15 +1622,14 @@ void ResourceMap::loadDefaultConfiguration()
   // Classifier parameters //
   addAsBool("Classifier-Parallel", true);
 
-  // TensorApproximationAlgorithm parameters //
-  addAsScalar("TensorApproximationAlgorithm-DefaultMaximumRadiusError", 1.0e-5);
-  addAsScalar("TensorApproximationAlgorithm-DefaultMaximumResidualError", 1.0e-5);
-  addAsString("TensorApproximationAlgorithm-DecompositionMethod", "SVD");
-  addAsString("TensorApproximationAlgorithm-Method", "GreedyRankOne");
-  addAsUnsignedInteger("TensorApproximationAlgorithm-DefaultMaximumAlternatingLeastSquaresIteration", 100);
-
   // viewer.View parameters //
   addAsString("View-ImageFormat", "png");
+
+  // SmolyakExperiment parameters //
+  addAsScalar("SmolyakExperiment-MergeRelativeEpsilon", 1.0e-8);
+  addAsScalar("SmolyakExperiment-MergeAbsoluteEpsilon", 1.0e-8);
+  addAsBool("SmolyakExperiment-MergeQuadrature", true);
+
 }
 
 void ResourceMap::reload()
