@@ -2,7 +2,7 @@
 /**
  *  @brief XMLStorageManager provides an interface for different storage classes
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -257,7 +257,7 @@ XMLStorageManager::XMLReadObject XMLStorageManager::readDOMElement()
       }
       catch(...)
       {
-        throw InternalException(HERE) << "Error trying to load " << ro.label_ << ", skipped.";
+        throw InternalException(HERE) << "Error trying to load class " << className << " with label " << ro.label_ << ", skipped.";
       }
     }
   }
@@ -311,6 +311,12 @@ void toStringConverter(const String & value, String & st)
   st = value;
 }
 
+static inline
+void toStringConverter(const Bool & value, String & st)
+{
+  st = (OSS() << value);
+}
+
 template <typename _Tp>
 static inline
 void toStringConverter(const _Tp & value, String & st)
