@@ -2,7 +2,7 @@
 /**
  *  @brief A collection of numerical math function
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -115,6 +115,16 @@ void Basis::add(const Function & elt)
 }
 
 /* Dimension accessor */
+UnsignedInteger Basis::getInputDimension() const
+{
+  return getImplementation()->getInputDimension();
+}
+
+UnsignedInteger Basis::getOutputDimension() const
+{
+  return getImplementation()->getOutputDimension();
+}
+
 UnsignedInteger Basis::getDimension() const
 {
   return getImplementation()->getDimension();
