@@ -2,7 +2,7 @@
 /**
  *  @brief This is an abstract class for basis
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -77,11 +77,22 @@ void BasisImplementation::add(const Function & )
   throw NotYetImplementedException(HERE) << "In BasisImplementation::add(const Function & elt)";
 }
 
-UnsignedInteger BasisImplementation::getDimension() const
+UnsignedInteger BasisImplementation::getInputDimension() const
 {
   throw NotYetImplementedException(HERE) << "In BasisImplementation::getDimension() const";
 }
 
+UnsignedInteger BasisImplementation::getOutputDimension() const
+{
+  throw NotYetImplementedException(HERE) << "In BasisImplementation::getDimension() const";
+}
+
+UnsignedInteger BasisImplementation::getDimension() const
+{
+  LOGWARN(OSS() << "Basis.getDimension is deprecated, use getInputDimension");
+  return getInputDimension();
+}
+
 UnsignedInteger BasisImplementation::getSize() const
 {
   throw NotYetImplementedException(HERE) << "In BasisImplementation::getSize() const";
