@@ -2,7 +2,7 @@
 /**
  *  @brief Class for a Box cox implementation
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -129,7 +129,7 @@ struct BoxCoxEvaluationComputeSamplePolicy
         const Scalar lambda_j = evaluation_.getLambda()[j];
         const Scalar logX = log(input_(i, j) + evaluation_.getShift()[j]);
         if (std::abs(lambda_j * logX) < 1e-8) output_(i, j) = logX * (1.0 + 0.5 * lambda_j * logX);
-        else output_(i, j) = expm1(lambda_j * logX) / lambda_j;
+        else output_(i, j) = std::expm1(lambda_j * logX) / lambda_j;
       } // j
     } // i
   } // operator ()
@@ -169,7 +169,7 @@ Point BoxCoxEvaluation::operator() (const Point & inP) const
     const Scalar lambda_i = lambda_[index];
     const Scalar logX = log(x);
     if (std::abs(lambda_i * logX) < 1e-8) result[index] = logX * (1.0 + 0.5 * lambda_i * logX);
-    else result[index] = expm1(lambda_i * logX) / lambda_i;
+    else result[index] = std::expm1(lambda_i * logX) / lambda_i;
   }
   callsNumber_.increment();
   return result;
