@@ -2,7 +2,7 @@
 /**
  *  @brief Abstract top-level class for all linear functions
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -28,6 +28,15 @@ BEGIN_NAMESPACE_OPENTURNS
 CLASSNAMEINIT(LinearFunction)
 
 /* Default constructor */
+LinearFunction::LinearFunction()
+  : Function(new LinearEvaluation(),
+             new ConstantGradient(),
+             new NullHessian())
+{
+  // Nothing to do
+}
+
+/* Parameter constructor */
 LinearFunction::LinearFunction(const Point & center,
                                const Point & constant,
                                const Matrix & linear)
