@@ -2,7 +2,7 @@
 /**
  * @brief Marginal evaluation
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -21,6 +21,7 @@
 
 #include "openturns/MarginalEvaluation.hxx"
 #include "openturns/PersistentObjectFactory.hxx"
+#include "openturns/BatchFailedException.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -136,9 +137,19 @@ Sample MarginalEvaluation::operator() (const Sample & inSample) const
   const UnsignedInteger inputDimension = p_evaluation_->getInputDimension();
   const UnsignedInteger sampleDimension = inSample.getDimension();
   if (sampleDimension != inputDimension) throw InvalidArgumentException(HERE) << "Error: expected a sample of dimension=" << inputDimension << ", got dimension=" << sampleDimension;
-  const Sample fullOutput(p_evaluation_->operator()(inSample));
-  callsNumber_.fetchAndAdd(size);
-  return fullOutput.getMarginal(indices_);
+  try
+  {
+    const Sample fullOutput(p_evaluation_->operator()(inSample));
+    callsNumber_.fetchAndAdd(size);
+    return fullOutput.getMarginal(indices_);
+  }
+  catch (BatchFailedException & exc)
+  {
+    // rethrow but with updated output sample
+    callsNumber_.fetchAndAdd(size);
+    exc.setOutputSample(exc.getOutputSample().getMarginal(indices_));
+    throw exc;
+  }
 }
 
 /* Accessor for input point dimension */
