@@ -2,7 +2,7 @@
 /**
  *  @brief Meshing algorithm for intervals
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -22,6 +22,9 @@
 #include "openturns/IntervalMesher.hxx"
 #include "openturns/PersistentObjectFactory.hxx"
 #include "openturns/Exception.hxx"
+#include "openturns/Tuples.hxx"
+#include "openturns/KPermutations.hxx"
+#include "openturns/SpecFunc.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -89,6 +92,8 @@ Mesh IntervalMesher::build(const Interval & interval,
 {
   const UnsignedInteger dimension = interval.getDimension();
   if (discretization_.getSize() != dimension) throw InvalidArgumentException(HERE) << "Error: the mesh factory is for intervals of dimension=" << discretization_.getSize() << ", here dimension=" << dimension;
+  const Point lowerBound(interval.getLowerBound());
+  const Point upperBound(interval.getUpperBound());
 
   // Waiting for a generic implementation in higher dimension
   if (dimension == 1)
@@ -97,8 +102,8 @@ Mesh IntervalMesher::build(const Interval & interval,
     const UnsignedInteger n = diamond ? 2 * discretization_[0] - 1 : discretization_[0];
     Sample vertices(n + 1, 1);
     // First the vertices
-    const Scalar a = interval.getLowerBound()[0];
-    const Scalar b = interval.getUpperBound()[0];
+    const Scalar a = lowerBound[0];
+    const Scalar b = upperBound[0];
     vertices(0, 0) = a;
     vertices(n, 0) = b;
     for (UnsignedInteger i = 1; i < n; ++i) vertices(i, 0) = (i * b + (n - i) * a) / n;
@@ -117,8 +122,6 @@ Mesh IntervalMesher::build(const Interval & interval,
     const UnsignedInteger n = discretization_[1];
     // First the vertices
     Sample vertices((m + 1) * (n + 1) + (diamond ? m * n : 0), 2);
-    const Point lowerBound(interval.getLowerBound());
-    const Point upperBound(interval.getUpperBound());
     Point discretizedX(m + 1);
     for (UnsignedInteger i = 0; i <= m; ++i)
       discretizedX[i] = ((m - i) * lowerBound[0] + i * upperBound[0]) / m;
@@ -201,8 +204,6 @@ Mesh IntervalMesher::build(const Interval & interval,
     const UnsignedInteger p = discretization_[2];
     // First the vertices
     Sample vertices((m + 1) * (n + 1) * (p + 1) + (diamond ? m * n * p : 0), 3);
-    const Point lowerBound(interval.getLowerBound());
-    const Point upperBound(interval.getUpperBound());
     Point discretizedX(m + 1);
     for (UnsignedInteger i = 0; i <= m; ++i)
       discretizedX[i] = ((m - i) * lowerBound[0] + i * upperBound[0]) / m;
@@ -478,7 +479,81 @@ Mesh IntervalMesher::build(const Interval & interval,
     } // k
     return Mesh(vertices, simplices);
   } // dimension == 3
-  throw NotYetImplementedException(HERE) << "In IntervalMesher::build(const Interval & interval, const Bool diamond) const";
+  // Dimension > 3
+  if (diamond)
+    throw NotYetImplementedException(HERE) << "In IntervalMesher::build with n-d/diamond=true";
+  Indices verticesDiscretization(dimension);
+  for (UnsignedInteger i = 0; i < dimension; ++i)
+    verticesDiscretization[i] = discretization_[i] + 1;
+  // Generate vertices
+  const IndicesCollection allVerticesTuples(Tuples(verticesDiscretization).generate());
+  const UnsignedInteger numVertices = allVerticesTuples.getSize();
+  Sample vertices(numVertices, dimension);
+  for (UnsignedInteger i = 0; i < numVertices; ++i)
+  {
+    for (UnsignedInteger j = 0; j < dimension; ++j)
+    {
+      const Scalar s = (1.0 * allVerticesTuples(i, j)) / discretization_[j];
+      vertices(i, j) = lowerBound[j] * (1.0 - s) + upperBound[j] * s;
+    } // j
+  } // i
+  // Generate simplices:
+  const IndicesCollection allHypercubesTuples(Tuples(discretization_).generate());
+  const UnsignedInteger numHypercubes = allHypercubesTuples.getSize();
+  const IndicesCollection allSimplicesPermutations(KPermutations(dimension, dimension).generate());
+  const UnsignedInteger numSimplicesPermutations = allSimplicesPermutations.getSize();
+  const UnsignedInteger numSimplices = numHypercubes * numSimplicesPermutations;
+  IndicesCollection simplices(numSimplices, dimension + 1);
+  // Reference simplex
+  IndicesCollection referenceSimplices(numSimplicesPermutations, dimension + 1);
+  Indices base(dimension);
+  UnsignedInteger product = 1;
+  for (UnsignedInteger i = 0; i < dimension; ++i)
+  {
+    base[i] = product;
+    product *= verticesDiscretization[i];
+  }
+
+  // Generate all the increasing sequences of 0 and 1 of size (dimension+1) encoded in base 2
+  Indices standardSimplex(dimension + 1, 0);
+  for (UnsignedInteger j = 0; j <= dimension; ++j)
+  {
+    // Interpret these sequences as a binary representation of an integer
+    for (UnsignedInteger k = 0; k < j; ++k)
+      standardSimplex[j] += 1 << k;
+  }
+  for (UnsignedInteger i = 0; i < numSimplicesPermutations; ++i)
+  {
+    for (UnsignedInteger j = 0; j <= dimension; ++j)
+    {
+      // Translate these sequences into integers using the mixed base verticesDiscretization
+      UnsignedInteger component = standardSimplex[j];
+      for (UnsignedInteger k = 0; k < dimension; ++k)
+      {
+        referenceSimplices(i, j) += (component % 2) * base[allSimplicesPermutations(i, k)];
+        component /= 2;
+      } // k
+    } // j
+  } // i
+  // For each hypercube add the reference simplex and all its permutations with
+  // the proper translation
+  UnsignedInteger simplexIndex = 0;
+  for (UnsignedInteger i = 0; i < numHypercubes; ++i)
+  {
+    // Compute the translation associated to this hypercube
+    UnsignedInteger translation = 0;
+    for (UnsignedInteger k = 0; k < dimension; ++k)
+      translation += allHypercubesTuples(i, k) * base[k];
+    for (UnsignedInteger j = 0; j < numSimplicesPermutations; ++j)
+    {
+      for (UnsignedInteger k = 0; k <= dimension; ++k)
+      {
+        simplices(simplexIndex, k) = referenceSimplices(j, k) + translation;
+      } // k
+      ++simplexIndex;
+    } // j
+  } // i
+  return Mesh(vertices, simplices);
 }
 
 END_NAMESPACE_OPENTURNS
