@@ -2,7 +2,7 @@
 /**
  *  @brief Mesh is defined as a collection of n-D vertices and simplices
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -258,7 +258,7 @@ Bool Mesh::checkPointInSimplexWithCoordinates(const Point & point,
   buildSimplexMatrix(index, matrix);
   Point v(point);
   v.add(1.0);
-  coordinates = matrix.solveLinearSystem(v, false);
+  coordinates = matrix.solveLinearSystemInPlace(v);
   for (UnsignedInteger i = 0; i <= dimension_; ++i) if ((coordinates[i] < -epsilon) || (coordinates[i] > 1.0 + epsilon)) return false;
   return true;
 }
@@ -726,7 +726,7 @@ Graph Mesh::draw3D(const Bool drawEdge,
   // Fourth, draw the triangles in decreasing depth
   Graph graph(String(OSS() << "Mesh " << getName()), getDescription()[0], getDescription()[1], true, "topright");
   std::sort(trianglesAndDepth.begin(), trianglesAndDepth.end());
-  Scalar clippedRho = std::min(1.0, std::max(0.0, rho));
+  const Scalar clippedRho = SpecFunc::Clip01(rho);
   if (rho != clippedRho) LOGWARN(OSS() << "The shrinking factor must be in (0,1), here rho=" << rho);
   Sample face(3, 2);
   Sample data;
