@@ -2,7 +2,7 @@
 /**
  *  @brief Cloud class for cloud plots
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -118,26 +118,6 @@ String Cloud::__repr__() const
   return oss;
 }
 
-/* Draw method */
-String Cloud::draw() const
-{
-  dataFileName_ = "";
-  OSS oss;
-  if (pointStyle_ != "none")
-  {
-    // Stores the data in a temporary file
-    oss << DrawableImplementation::draw() << "\n";
-    // The specific R command for drawing
-    oss << "points(dataOT[,1], dataOT[,2]";
-    const String code((OSS() << getPointCode(pointStyle_)));
-    oss << ",pch=" << (pointStyle_ == "dot" ? "\".\"" : code)
-        << ",col=\"" << color_
-        << "\",lwd=" << lineWidth_
-        << ")";
-  }
-  return oss;
-}
-
 /* Clone method */
 Cloud * Cloud::clone() const
 {
