@@ -2,7 +2,7 @@
 /**
  *  @brief Curve class for curve plots
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -137,33 +137,6 @@ String Curve::__repr__() const
   return oss;
 }
 
-/* Draw method */
-String Curve::draw() const
-{
-  dataFileName_ = "";
-  OSS oss;
-  // Stores the data in a temporary file
-  oss << DrawableImplementation::draw() << "\n";
-  // The specific R command for drawing
-  oss << "lines(dataOT[,1], dataOT[,2]"
-      << ", lty=\"" << lineStyle_
-      << "\", col=\"" << color_
-      << "\", lwd=" << lineWidth_;
-  if (pointStyle_ != "none")
-  {
-    const String code((OSS() << getPointCode(pointStyle_)));
-    oss << ", type=\"b\""
-        << ", pch=" << (pointStyle_ == "dot" ? "\".\"" : code);
-  }
-  else
-  {
-    oss << ", type=\"l\"";
-  }
-  oss << ")";
-
-  return oss;
-}
-
 /* Clone method */
 Curve * Curve::clone() const
 {
