@@ -2,7 +2,7 @@
 /**
  *  @brief Graph implements graphic devices for plotting through R
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -274,27 +274,6 @@ void Graph::setTitle(const String & title)
   getImplementation()->setTitle(title);
 }
 
-/* The method that generates the graphic files */
-void Graph::draw(const String & file,
-                 const Scalar width,
-                 const Scalar height,
-                 SignedInteger format)
-{
-  getImplementation()->draw(file, width, height, format);
-}
-
-/* Get the R command corresponding to the graph */
-String Graph::getRCommand() const
-{
-  return getImplementation()->getRCommand();
-}
-
-/* Clean temporary files */
-void Graph::clean()
-{
-  getImplementation()->clean();
-}
-
 /* Margin accessor */
 void Graph::setXMargin(const Scalar xMargin)
 {
