@@ -2,7 +2,7 @@
 /**
  *  @brief Polygon class for polygon plots
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -127,31 +127,6 @@ String Polygon::__repr__() const
   return oss;
 }
 
-/* Draw method */
-String Polygon::draw() const
-{
-  dataFileName_ = "";
-  OSS oss;
-  // Stores the data in a temporary file
-  oss << DrawableImplementation::draw();
-  // The specific R command for drawing
-  oss << "polygon(dataOT[,1], dataOT[,2]"
-      << ", border="
-      << "\"" << edgeColor_ << "\""
-      << ", lty=\"" << lineStyle_ << "\""
-      << ", col="
-      << "\"" << color_ << "\""
-      << ", lwd=" << lineWidth_;
-  if (pointStyle_ != "none")
-  {
-    const String code((OSS() << getPointCode(pointStyle_)));
-    oss << ", pch=" << (pointStyle_ == "dot" ? "\".\"" : code);
-  }
-  oss << ")";
-
-  return oss;
-}
-
 /* Clone method */
 Polygon * Polygon::clone() const
 {
