@@ -2,7 +2,7 @@
 /**
  *  @brief Staircase class for staircase plots
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -91,24 +91,6 @@ String Staircase::__repr__() const
   return oss;
 }
 
-/* Draw method */
-String Staircase::draw() const
-{
-  dataFileName_ = "";
-  OSS oss;
-  // Stores the data in a temporary file
-  oss << DrawableImplementation::draw() << "\n";
-  // The specific R command for drawing
-  oss << "lines(dataOT[, 1], dataOT[, 2]"
-      << ", lty=\"" << lineStyle_
-      << "\", col=\"" << color_
-      << "\", lwd=" << lineWidth_
-      << ", type=\"" << pattern_
-      << "\")";
-
-  return oss;
-}
-
 /* Clone method */
 Staircase * Staircase::clone() const
 {
