@@ -2,7 +2,7 @@
 /**
  *  @brief Text class for plot labels
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -30,7 +30,6 @@ static const Factory<Text> Factory_Text;
 
 /* Accepted text position */
 std::map<String, UnsignedInteger> Text::Position;
-Bool Text::IsTextFirstInitialization = true;
 
 
 /* Default constructor */
@@ -189,36 +188,14 @@ void Text::setTextSize(const Scalar size)
   textSize_ = size;
 }
 
-
-/* Draw method */
-String Text::draw() const
+Scalar Text::getRotation() const
 {
-  dataFileName_ = "";
-  OSS oss;
-  if (textAnnotations_.getSize() == 0)
-    return oss;
-  // Stores the data in a temporary file
-  oss << DrawableImplementation::draw() << "\n";
+  return rotation_;
+}
 
-  oss << "labels <- rep(\"\", " << textAnnotations_.getSize() << ")\n";
-  oss << "position <- rep(3, " << textAnnotations_.getSize() << ")\n";
-// We assume that only few labels are printed, otherwise graph is ugly
-  for (UnsignedInteger i = 0; i < textAnnotations_.getSize(); ++i)
-  {
-    if (textAnnotations_[i] != "")
-    {
-      oss << "labels[" << (i + 1) << "] <- \"" << textAnnotations_[i] << "\"\n";
-      const std::map<String, UnsignedInteger>::const_iterator it(Position.find(textPositions_[i]));
-      oss << "position[" << (i + 1) << "] <- \"" << it->second << "\"\n";
-    }
-  }
-  oss << "indices <- which(labels != \"\")\n";
-  oss << "text(dataOT[indices,1], dataOT[indices,2], labels[indices], cex = " << textSize_
-      << ", xpd = TRUE, pos = position[indices]"
-      << ", col=\"" << color_ << "\""
-      << ", offset = 0.25)\n";
-
-  return oss;
+void Text::setRotation(const Scalar rotation)
+{
+  rotation_ = rotation;
 }
 
 /* Clone method */
@@ -236,6 +213,22 @@ void Text::checkData(const Sample & data) const
   }
 }
 
+Bool Text::IsValidTextPosition(String textPosition)
+{
+  InitializePositionMap();
+  const std::map<String, UnsignedInteger>::const_iterator it(Position.find(textPosition));
+  return (it != Position.end());
+}
+
+void Text::InitializePositionMap()
+{
+  if (!Position.empty()) return;
+  Position["bottom"] = 1;
+  Position["left"] = 2;
+  Position["top"] = 3;
+  Position["right"] = 4;
+}
+
 /* Method save() stores the object through the StorageManager */
 void Text::save(Advocate & adv) const
 {
@@ -243,26 +236,7 @@ void Text::save(Advocate & adv) const
   adv.saveAttribute( "textAnnotations_", textAnnotations_ );
   adv.saveAttribute( "textPositions_", textPositions_ );
   adv.saveAttribute( "textSize_", textSize_ );
-}
-
-Bool Text::IsValidTextPosition(String textPosition)
-{
-  if(IsTextFirstInitialization)
-  {
-    InitializePositionMap();
-    IsTextFirstInitialization = false;
-  }
-
-  const std::map<String, UnsignedInteger>::const_iterator it(Position.find(textPosition));
-  return (it != Position.end());
-}
-
-void Text::InitializePositionMap()
-{
-  Position["bottom"] = 1;
-  Position["left"] = 2;
-  Position["top"] = 3;
-  Position["right"] = 4;
+  adv.saveAttribute( "rotation_", rotation_ );
 }
 
 /* Method load() reloads the object from the StorageManager */
@@ -272,8 +246,8 @@ void Text::load(Advocate & adv)
   adv.loadAttribute( "textAnnotations_", textAnnotations_ );
   adv.loadAttribute( "textPositions_", textPositions_ );
   adv.loadAttribute( "textSize_", textSize_ );
+  if (adv.hasAttribute("rotation_"))
+    adv.loadAttribute( "rotation_", rotation_ );
 }
 
-
-
 END_NAMESPACE_OPENTURNS
