@@ -2,7 +2,7 @@
 /**
  *  @brief IterativeMoments implements the iterative computation of centered moments
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -72,12 +72,6 @@ Sample IterativeMoments::getCentralMoments() const
   return centralMoments_;
 }
 
-Sample IterativeMoments::getCenteredMoments() const
-{
-  LOGWARN(OSS() << "IterativeMoments::getCenteredMoments is deprecated, use getCentralMoments");
-  return getCentralMoments();
-}
-
 /* Accessor to the maximum order declared */
 UnsignedInteger IterativeMoments::getOrder() const
 {
@@ -106,7 +100,7 @@ Point IterativeMoments::getVariance() const
 }
 
 /* Accessor to the unbiased estimator of the skewness
-   The factors used in the formula below allow to provide an unbiased
+   The factors used in the formula below allow one to provide an unbiased
    estimate the skewness.
    Joanes, Derrick N.; Gill, Christine A. (1998),
    "Comparing measures of sample skewness and kurtosis",
@@ -131,7 +125,7 @@ Point IterativeMoments::getSkewness() const
 }
 
 /* Accessor to the unbiased estimator of the kurtosis
-   The factors used in the formula below allow to provide an unbiased
+   The factors used in the formula below allow one to provide an unbiased
    estimate the kurtosis.
    Joanes, Derrick N.; Gill, Christine A. (1998),
    "Comparing measures of sample skewness and kurtosis",
