@@ -2,7 +2,7 @@
 /**
  *  @brief Dlib solvers
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -26,6 +26,7 @@
 
 #ifdef OPENTURNS_HAVE_DLIB
 #include "openturns/DlibFunctions.hxx"
+#include "openturns/OTwindows.h" // dlib includes windows.h
 #include <dlib/optimization.h>
 #ifdef OPENTURNS_HAVE_DLIB_GLOBAL_OPTIMIZATION
 #include <dlib/global_optimization.h>
@@ -320,12 +321,9 @@ public:
     lastInput_ = xPoint;
     lastOutput_ = fxPoint;
 
-    optimizationResult_.store(lastInput_,
-                              lastOutput_,
-                              absoluteError,
-                              relativeError,
-                              residualError,
-                              constraintError);
+    optimizationResult_.store(lastInput_, lastOutput_,
+                              absoluteError, relativeError, residualError, constraintError,
+                              dlibAlgorithm_.getMaximumConstraintError());
 
     if (!stopSearch) optimizationResult_.setIterationNumber(optimizationResult_.getIterationNumber() + 1);
 
@@ -589,7 +587,7 @@ void Dlib::run()
     for (UnsignedInteger i = 0; i < dimension; ++ i)
     {
       lb(i) = SpecFunc::LowestScalar;
-      ub(i) =  SpecFunc::MaxScalar;
+      ub(i) = SpecFunc::MaxScalar;
     }
   }
 
@@ -597,10 +595,10 @@ void Dlib::run()
   result_ = OptimizationResult(getProblem());
 
   /** SWITCH BETWEEN ALGORITHMS **/
-  if (   algoName_ == "cg"
-         || algoName_ == "bfgs"
-         || algoName_ == "lbfgs"
-         || algoName_ == "newton")
+  if (algoName_ == "cg"
+      || algoName_ == "bfgs"
+      || algoName_ == "lbfgs"
+      || algoName_ == "newton")
   {
     // Create searchStrategy
     DlibSearchStrategy searchStrategy;
