@@ -2,7 +2,7 @@
 /**
  *  @brief IpoptProblem implements the Ipopt::TNLP interface
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -275,7 +275,16 @@ bool IpoptProblem::eval_grad_f( int n,
   std::copy(x, x + n, xPoint.begin());
 
   // Computing objective function gradient
-  Matrix gradOT(optimProblem_.getObjective().gradient(xPoint));
+  Matrix gradOT;
+  try
+  {
+    gradOT = optimProblem_.getObjective().gradient(xPoint);
+  }
+  catch (const std::exception & exc)
+  {
+    LOGWARN(OSS() << "Ipopt went to an abnormal point x=" << xPoint.__str__() << " msg=" << exc.what());
+    return false;
+  }
 
   // Conversion from OT::Matrix to double array
   for (int i = 0; i < n; ++i)
@@ -305,7 +314,16 @@ bool IpoptProblem::eval_g(int n,
   if (optimProblem_.hasEqualityConstraint())
   {
     nbEqualityConstraints = optimProblem_.getEqualityConstraint().getOutputDimension();
-    Point equalityConstraint(optimProblem_.getEqualityConstraint()(xPoint));
+    Point equalityConstraint;
+    try
+    {
+      equalityConstraint = optimProblem_.getEqualityConstraint()(xPoint);
+    }
+    catch (const std::exception & exc)
+    {
+      LOGWARN(OSS() << "Ipopt went to an abnormal point x=" << xPoint.__str__() << " msg=" << exc.what());
+      return false;
+    }
     std::copy(equalityConstraint.begin(), equalityConstraint.end(), g + k);
     k += nbEqualityConstraints;
   }
@@ -313,7 +331,16 @@ bool IpoptProblem::eval_g(int n,
   if (optimProblem_.hasInequalityConstraint())
   {
     nbInequalityConstraints = optimProblem_.getInequalityConstraint().getOutputDimension();
-    Point inequalityConstraint(optimProblem_.getInequalityConstraint()(xPoint));
+    Point inequalityConstraint;
+    try
+    {
+      inequalityConstraint = optimProblem_.getInequalityConstraint()(xPoint);
+    }
+    catch (const std::exception & exc)
+    {
+      LOGWARN(OSS() << "Ipopt went to an abnormal point x=" << xPoint.__str__() << " msg=" << exc.what());
+      return false;
+    }
     std::copy(inequalityConstraint.begin(), inequalityConstraint.end(), g + k);
     k += nbInequalityConstraints;
   }
@@ -357,7 +384,16 @@ bool IpoptProblem::eval_jac_g(int n,
     if (optimProblem_.hasEqualityConstraint())
     {
       nbEqualityConstraints = optimProblem_.getEqualityConstraint().getOutputDimension();
-      Matrix equalityConstraintGradient(optimProblem_.getEqualityConstraint().gradient(xPoint));
+      Matrix equalityConstraintGradient;
+      try
+      {
+        equalityConstraintGradient = optimProblem_.getEqualityConstraint().gradient(xPoint);
+      }
+      catch (const std::exception & exc)
+      {
+        LOGWARN(OSS() << "Ipopt went to an abnormal point x=" << xPoint.__str__() << " msg=" << exc.what());
+        return false;
+      }
       for (UnsignedInteger i = 0; i < nbEqualityConstraints; ++i)
         for (int j = 0; j < n; ++j)
         {
@@ -369,7 +405,16 @@ bool IpoptProblem::eval_jac_g(int n,
     if (optimProblem_.hasInequalityConstraint())
     {
       nbInequalityConstraints = optimProblem_.getInequalityConstraint().getOutputDimension();
-      Matrix inequalityConstraintGradient(optimProblem_.getInequalityConstraint().gradient(xPoint));
+      Matrix inequalityConstraintGradient;
+      try
+      {
+        inequalityConstraintGradient = optimProblem_.getInequalityConstraint().gradient(xPoint);
+      }
+      catch (const std::exception & exc)
+      {
+        LOGWARN(OSS() << "Ipopt went to an abnormal point x=" << xPoint.__str__() << " msg=" << exc.what());
+        return false;
+      }
       for (UnsignedInteger i = 0; i < nbInequalityConstraints; ++i)
         for (int j = 0; j < n; ++j)
         {
@@ -425,7 +470,16 @@ bool IpoptProblem::eval_h(int n,
     std::copy(x, x + n, xPoint.begin());
 
     // Compute objective hessian
-    const SymmetricMatrix objectiveHessian(obj_factor * optimProblem_.getObjective().hessian(xPoint).getSheet(0));
+    SymmetricMatrix objectiveHessian;
+    try
+    {
+      objectiveHessian = obj_factor * optimProblem_.getObjective().hessian(xPoint).getSheet(0);
+    }
+    catch (const std::exception & exc)
+    {
+      LOGWARN(OSS() << "Ipopt went to an abnormal point x=" << xPoint.__str__() << " msg=" << exc.what());
+      return false;
+    }
 
     // Compute constraints hessian
     int k = 0;
@@ -433,7 +487,16 @@ bool IpoptProblem::eval_h(int n,
 
     if (optimProblem_.hasEqualityConstraint())
     {
-      const SymmetricTensor equalityConstraintHessian(optimProblem_.getEqualityConstraint().hessian(xPoint));
+      SymmetricTensor equalityConstraintHessian;
+      try
+      {
+        equalityConstraintHessian = optimProblem_.getEqualityConstraint().hessian(xPoint);
+      }
+      catch (const std::exception & exc)
+      {
+        LOGWARN(OSS() << "Ipopt went to an abnormal point x=" << xPoint.__str__() << " msg=" << exc.what());
+        return false;
+      }
       for (UnsignedInteger i = 0; i < nbEqualityConstraints; ++i)
       {
         constraintsHessian = constraintsHessian + lambda[k] * equalityConstraintHessian.getSheet(i);
@@ -443,7 +506,16 @@ bool IpoptProblem::eval_h(int n,
 
     if (optimProblem_.hasInequalityConstraint())
     {
-      const SymmetricTensor inequalityConstraintHessian(optimProblem_.getInequalityConstraint().hessian(xPoint));
+      SymmetricTensor inequalityConstraintHessian;
+      try
+      {
+        inequalityConstraintHessian = optimProblem_.getInequalityConstraint().hessian(xPoint);
+      }
+      catch (const std::exception & exc)
+      {
+        LOGWARN(OSS() << "Ipopt went to an abnormal point x=" << xPoint.__str__() << " msg=" << exc.what());
+        return false;
+      }
       for (UnsignedInteger i = 0; i < nbInequalityConstraints; ++i)
       {
         constraintsHessian = constraintsHessian + lambda[k] * inequalityConstraintHessian.getSheet(i);
@@ -481,11 +553,18 @@ bool IpoptProblem::eval_gi(int n,
     nbEqualityConstraints = optimProblem_.getEqualityConstraint().getOutputDimension();
 
   // Computing constraints values
-  if (i < nbEqualityConstraints)
-    gi = optimProblem_.getEqualityConstraint().getMarginal(i)(xPoint)[0];
-  else
-    gi = optimProblem_.getInequalityConstraint().getMarginal(i - nbEqualityConstraints)(xPoint)[0];
-
+  try
+  {
+    if (i < nbEqualityConstraints)
+      gi = optimProblem_.getEqualityConstraint().getMarginal(i)(xPoint)[0];
+    else
+      gi = optimProblem_.getInequalityConstraint().getMarginal(i - nbEqualityConstraints)(xPoint)[0];
+  }
+  catch (const std::exception & exc)
+  {
+    LOGWARN(OSS() << "Ipopt went to an abnormal point x=" << xPoint.__str__() << " msg=" << exc.what());
+    return false;
+  }
   return true;
 }
 
@@ -514,13 +593,31 @@ bool IpoptProblem::eval_grad_gi(int n,
 
     if (i < nbEqualityConstraints)
     {
-      Matrix equalityConstraintGradient(optimProblem_.getEqualityConstraint().getMarginal(i).gradient(xPoint));
+      Matrix equalityConstraintGradient;
+      try
+      {
+        equalityConstraintGradient = optimProblem_.getEqualityConstraint().getMarginal(i).gradient(xPoint);
+      }
+      catch (const std::exception & exc)
+      {
+        LOGWARN(OSS() << "Ipopt went to an abnormal point x=" << xPoint.__str__() << " msg=" << exc.what());
+        return false;
+      }
       for (int j = 0; j < n; ++j)
         values[j] = equalityConstraintGradient(j, 0);
     }
     else
     {
-      Matrix inequalityConstraintGradient(optimProblem_.getInequalityConstraint().getMarginal(i - nbEqualityConstraints).gradient(xPoint));
+      Matrix inequalityConstraintGradient;
+      try
+      {
+        inequalityConstraintGradient = optimProblem_.getInequalityConstraint().getMarginal(i - nbEqualityConstraints).gradient(xPoint);
+      }
+      catch (const std::exception & exc)
+      {
+        LOGWARN(OSS() << "Ipopt went to an abnormal point x=" << xPoint.__str__() << " msg=" << exc.what());
+        return false;
+      }
       for (int j = 0; j < n; ++j)
         values[j] = inequalityConstraintGradient(j, 0);
     }
