@@ -2,7 +2,7 @@
 /**
  *  @brief MultiStart optimization algorithm
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -225,7 +225,7 @@ Sample MultiStart::getStartingSample() const
 void MultiStart::checkStartingSampleConsistentWithOptimizationProblem(const Sample & startingSample, const OptimizationProblem & problem) const
 {
   const UnsignedInteger problemDimension = problem.getDimension();
-  if ( (problemDimension > 0) && (startingSample.getSize() > 0) ) // only perform check if problem is initalized and starting points are already defined
+  if ( (problemDimension > 0) && (startingSample.getSize() > 0) ) // only perform check if problem is initialized and starting points are already defined
   {
     if (problemDimension != startingSample.getDimension())
     {
