@@ -2,7 +2,7 @@
 /**
  *  @brief NLopt solver
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -70,7 +70,8 @@ void NLopt::InitializeAlgorithmNames()
   AlgorithmNames_["LD_MMA"] = nlopt::LD_MMA;
   AlgorithmNames_["LN_COBYLA"] = nlopt::LN_COBYLA;
   AlgorithmNames_["LN_NEWUOA"] = nlopt::LN_NEWUOA;
-  AlgorithmNames_["LN_NEWUOA_BOUND"] = nlopt::LN_NEWUOA_BOUND;
+  // https://github.com/stevengj/nlopt/issues/511
+  //AlgorithmNames_["LN_NEWUOA_BOUND"] = nlopt::LN_NEWUOA_BOUND;
   AlgorithmNames_["LN_NELDERMEAD"] = nlopt::LN_NELDERMEAD;
   AlgorithmNames_["LN_SBPLX"] = nlopt::LN_SBPLX;
   AlgorithmNames_["LN_AUGLAG"] = nlopt::LN_AUGLAG;
@@ -129,7 +130,6 @@ void NLopt::SetSeed(const UnsignedInteger seed)
 NLopt::NLopt(const String & algoName)
   : OptimizationAlgorithmImplementation()
   , algoName_(algoName)
-  , p_opt_(0)
 {
   GetAlgorithmCode(algoName);
 }
@@ -138,7 +138,6 @@ NLopt::NLopt(const OptimizationProblem & problem,
              const String & algoName)
   : OptimizationAlgorithmImplementation(problem)
   , algoName_(algoName)
-  , p_opt_(0)
 {
   checkProblem(problem);
 }
@@ -168,6 +167,10 @@ void NLopt::checkProblem(const OptimizationProblem & problem) const
         throw InvalidArgumentException(HERE) << "Error: " << getAlgorithmName() << " global algorithm requires finite bounds";
     }
   }
+
+  if ((getAlgorithmName() == "LN_NEWUOA") && problem.hasBounds())
+    throw InvalidArgumentException(HERE) << "Error: LN_NEWUOA algorithm does not support bounds";
+
 #ifdef OPENTURNS_HAVE_NLOPT
   const UnsignedInteger dimension = problem.getDimension();
   const nlopt::algorithm algo = static_cast<nlopt::algorithm>(GetAlgorithmCode(getAlgorithmName()));
@@ -329,66 +332,14 @@ void NLopt::run()
   {
     throw InternalException(HERE) << "NLopt raised an exception: " << exc.what();
   }
-  p_opt_ = 0;
+  p_opt_ = nullptr;
 
-  Point optimizer(x.begin(), x.end());
-  OptimizationResult result(getProblem());
+  // some AUGLAG variants call inequality constraints less times than objective
+  // https://github.com/stevengj/nlopt/blob/master/src/algs/auglag/auglag.c#L96
+  if (getProblem().hasInequalityConstraint() && (inequalityConstraintHistory_.getSize() != evaluationInputHistory_.getSize()))
+    inequalityConstraintHistory_ = getProblem().getInequalityConstraint()(evaluationInputHistory_);
 
-  const UnsignedInteger size = evaluationInputHistory_.getSize();
-
-  Scalar absoluteError = -1.0;
-  Scalar relativeError = -1.0;
-  Scalar residualError = -1.0;
-  Scalar constraintError = -1.0;
-
-  for (UnsignedInteger i = 0; i < size; ++ i)
-  {
-    const Point inP(evaluationInputHistory_[i]);
-    const Point outP(evaluationOutputHistory_[i]);
-    constraintError = 0.0;
-    if (getProblem().hasBounds())
-    {
-      const Interval bounds(getProblem().getBounds());
-      for (UnsignedInteger j = 0; j < dimension; ++ j)
-      {
-        if (bounds.getFiniteLowerBound()[j])
-          constraintError = std::max(constraintError, bounds.getLowerBound()[j] - inP[j]);
-        if (bounds.getFiniteUpperBound()[j])
-          constraintError = std::max(constraintError, inP[j] - bounds.getUpperBound()[j]);
-      }
-    }
-    if (getProblem().hasEqualityConstraint())
-    {
-      const Point g(equalityConstraintHistory_[i]);
-      constraintError = std::max(constraintError, g.normInf());
-    }
-    if (getProblem().hasInequalityConstraint())
-    {
-      // some AUGLAG variants call inequality constraints less times
-      // https://github.com/stevengj/nlopt/blob/master/src/algs/auglag/auglag.c#L96
-      const Bool same = (inequalityConstraintHistory_.getSize() == evaluationInputHistory_.getSize());
-      Point h(same ? inequalityConstraintHistory_[i] : getProblem().getInequalityConstraint()(inP));
-      for (UnsignedInteger k = 0; k < getProblem().getInequalityConstraint().getOutputDimension(); ++ k)
-      {
-        h[k] = std::min(h[k], 0.0);// convention h(x)>=0 <=> admissibility
-      }
-      constraintError = std::max(constraintError, h.normInf());
-    }
-    if (i > 0)
-    {
-      const Point inPM(evaluationInputHistory_[i - 1]);
-      const Point outPM(evaluationOutputHistory_[i - 1]);
-      absoluteError = (inP - inPM).normInf();
-      relativeError = (inP.normInf() > 0.0) ? (absoluteError / inP.normInf()) : -1.0;
-      residualError = (std::abs(outP[0]) > 0.0) ? (std::abs(outP[0] - outPM[0]) / std::abs(outP[0])) : -1.0;
-    }
-    result.store(inP, outP, absoluteError, relativeError, residualError, constraintError);
-  }
-
-  result.setEvaluationNumber(size);
-  result.setOptimalPoint(optimizer);
-  result.setOptimalValue(Point(1, optimalValue));
-  setResult(result);
+  setResultFromEvaluationHistory(evaluationInputHistory_, evaluationOutputHistory_, inequalityConstraintHistory_, equalityConstraintHistory_);
 #else
   (void) p_opt_;
   throw NotYetImplementedException(HERE) << "No NLopt support";
