@@ -2,7 +2,7 @@
 /**
  *  @brief OptimizationAlgorithmImplementation implements an algorithm for solving an optimization problem
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -21,6 +21,7 @@
 
 #include "openturns/OptimizationAlgorithmImplementation.hxx"
 #include "openturns/PersistentObjectFactory.hxx"
+#include "openturns/SpecFunc.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -33,7 +34,6 @@ OptimizationAlgorithmImplementation::OptimizationAlgorithmImplementation()
   : PersistentObject()
   , progressCallback_(std::make_pair<ProgressCallback, void *>(0, 0))
   , stopCallback_(std::make_pair<StopCallback, void *>(0, 0))
-  , startingPoint_(Point(0))
   , maximumIterationNumber_(ResourceMap::GetAsUnsignedInteger("OptimizationAlgorithm-DefaultMaximumIterationNumber"))
   , maximumEvaluationNumber_(ResourceMap::GetAsUnsignedInteger("OptimizationAlgorithm-DefaultMaximumEvaluationNumber"))
   , maximumAbsoluteError_(ResourceMap::GetAsScalar("OptimizationAlgorithm-DefaultMaximumAbsoluteError"))
@@ -71,6 +71,9 @@ Point OptimizationAlgorithmImplementation::getStartingPoint() const
 /* Starting point accessor */
 void OptimizationAlgorithmImplementation::setStartingPoint(const Point & startingPoint)
 {
+  for (UnsignedInteger j = 0; j < startingPoint.getDimension(); ++ j)
+    if (!SpecFunc::IsNormal(startingPoint[j]))
+      throw InvalidArgumentException(HERE) << "Optimization starting point has nan/inf values: " << startingPoint;
   startingPoint_ = startingPoint;
 }
 
@@ -259,4 +262,82 @@ void OptimizationAlgorithmImplementation::setStopCallback(StopCallback callBack,
 }
 
 
+void OptimizationAlgorithmImplementation::setResultFromEvaluationHistory(
+  const Sample & inputHistory, const Sample & outputHistory,
+  const Sample & inequalityHistory, const Sample & equalityHistory)
+{
+  // Update the result
+  result_ = OptimizationResult(getProblem());
+  const UnsignedInteger size = inputHistory.getSize();
+  const UnsignedInteger dimension = getProblem().getDimension();
+
+  Scalar absoluteError = -1.0;
+  Scalar relativeError = -1.0;
+  Scalar residualError = -1.0;
+  Scalar constraintError = -1.0;
+
+  for (UnsignedInteger i = 0; i < size; ++ i)
+  {
+    const Point inP(inputHistory[i]);
+    const Point outP(outputHistory[i]);
+    constraintError = 0.0;
+    if (getProblem().hasBounds())
+    {
+      const Interval bounds(getProblem().getBounds());
+      for (UnsignedInteger j = 0; j < dimension; ++ j)
+      {
+        if (bounds.getFiniteLowerBound()[j])
+          constraintError = std::max(constraintError, bounds.getLowerBound()[j] - inP[j]);
+        if (bounds.getFiniteUpperBound()[j])
+          constraintError = std::max(constraintError, inP[j] - bounds.getUpperBound()[j]);
+      }
+    }
+    if (getProblem().hasEqualityConstraint())
+    {
+      const Point g(equalityHistory[i]);
+      constraintError = std::max(constraintError, g.normInf());
+    }
+    if (getProblem().hasInequalityConstraint())
+    {
+      Point h(inequalityHistory[i]);
+      for (UnsignedInteger k = 0; k < getProblem().getInequalityConstraint().getOutputDimension(); ++ k)
+      {
+        h[k] = std::min(h[k], 0.0);// convention h(x)>=0 <=> admissibility
+      }
+      constraintError = std::max(constraintError, h.normInf());
+    }
+    if (!getProblem().isContinuous())
+    {
+      const Indices variablesType(getProblem().getVariablesType());
+      for (UnsignedInteger j = 0; j < dimension; ++ j)
+      {
+        switch (variablesType[j])
+        {
+          case OptimizationProblemImplementation::CONTINUOUS:
+            break;
+          case OptimizationProblemImplementation::BINARY:
+            constraintError = std::max(constraintError, std::abs(inP[j] - SpecFunc::Clip01(std::round(inP[j]))));
+            break;
+          case OptimizationProblemImplementation::INTEGER:
+            constraintError = std::max(constraintError, std::abs(inP[j] - std::round(inP[j])));
+            break;
+        }
+      }
+    }
+
+    if (i > 0)
+    {
+      const Point inPM(inputHistory[i - 1]);
+      const Point outPM(outputHistory[i - 1]);
+      absoluteError = (inP - inPM).normInf();
+      relativeError = (inP.normInf() > 0.0) ? (absoluteError / inP.normInf()) : -1.0;
+      residualError = (std::abs(outP[0]) > 0.0) ? (std::abs(outP[0] - outPM[0]) / std::abs(outP[0])) : -1.0;
+    }
+    result_.store(inP, outP, absoluteError, relativeError, residualError, constraintError, getMaximumConstraintError());
+  }
+  if (!result_.getOptimalPoint().getDimension())
+    throw InvalidArgumentException(HERE) << "no feasible point found during optimization";
+  result_.setEvaluationNumber(size);
+}
+
 END_NAMESPACE_OPENTURNS
