@@ -2,7 +2,7 @@
 /**
  *  @brief OptimizationResult stores the result of a OptimizationAlgorithmImplementation
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -300,26 +300,28 @@ void OptimizationResult::store(const Point & x,
                                const Scalar absoluteError,
                                const Scalar relativeError,
                                const Scalar residualError,
-                               const Scalar constraintError)
+                               const Scalar constraintError,
+                               const Scalar maximumConstraintError)
 {
   if (getProblem().getObjective().getOutputDimension() <= 1)
   {
-    if (!getOptimalValue().getDimension()
-        || getProblem().hasLevelFunction() // consider the last value as optimal for nearest-point algos
-        || ((getProblem().isMinimization() && y[0] < getOptimalValue()[0])
-            || (!getProblem().isMinimization() && y[0] > getOptimalValue()[0])))
+    const Bool objectiveImproved = (!getOptimalValue().getDimension())
+      || ((getProblem().isMinimization() && y[0] < getOptimalValue()[0]) || (!getProblem().isMinimization() && y[0] > getOptimalValue()[0]));
+
+    if ((objectiveImproved && (constraintError <= maximumConstraintError))
+      || getProblem().hasLevelFunction()) // consider the last value as optimal for nearest-point algos
     {
+      // update values
+      absoluteError_ = absoluteError;
+      relativeError_ = relativeError;
+      residualError_ = residualError;
+      constraintError_ = constraintError;
+
       setOptimalPoint(x);
       setOptimalValue(y);
     }
   }
 
-  // update values
-  absoluteError_ = absoluteError;
-  relativeError_ = relativeError;
-  residualError_ = residualError;
-  constraintError_ = constraintError;
-
   // append values
   absoluteErrorHistory_.store(Point(1, absoluteError));
   relativeErrorHistory_.store(Point(1, relativeError));
@@ -474,7 +476,7 @@ Point OptimizationResult::computeLagrangeMultipliers(const Point & x) const
         rhs.add(Point(inputDimension));
     }
   } // Inequality constraints
-  return Matrix(inputDimension, rhs.getDimension() / inputDimension, rhs).solveLinearSystem(lhs, false);
+  return Matrix(inputDimension, rhs.getDimension() / inputDimension, rhs).solveLinearSystemInPlace(lhs);
 }
 
 
