@@ -2,7 +2,7 @@
 /**
  *  @brief TNC is an actual implementation for OptimizationAlgorithmImplementation using the TNC library
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -48,8 +48,6 @@ TNC::TNC()
   , accuracy_(ResourceMap::GetAsScalar("TNC-DefaultAccuracy"))
   , fmin_(ResourceMap::GetAsScalar("TNC-DefaultFmin"))
   , rescale_(ResourceMap::GetAsScalar("TNC-DefaultRescale"))
-  , p_nfeval_(0)
-  , ignoreFailure_(false)
 {
   // Nothing to do
 }
@@ -63,8 +61,6 @@ TNC::TNC(const OptimizationProblem & problem)
   , accuracy_(ResourceMap::GetAsScalar("TNC-DefaultAccuracy"))
   , fmin_(ResourceMap::GetAsScalar("TNC-DefaultFmin"))
   , rescale_(ResourceMap::GetAsScalar("TNC-DefaultRescale"))
-  , p_nfeval_(0)
-  , ignoreFailure_(false)
 {
   checkProblem(problem);
 }
@@ -88,8 +84,6 @@ TNC::TNC (const OptimizationProblem & problem,
   , accuracy_(accuracy)
   , fmin_(fmin)
   , rescale_(rescale)
-  , p_nfeval_(0)
-  , ignoreFailure_(false)
 {
   checkProblem(problem);
 }
@@ -192,7 +186,7 @@ void TNC::run()
    * accuracy  : relative precision for finite difference calculations
    *             if <= machine_precision, set to sqrt(machine_precision)
    * fmin      : minimum function value estimate
-   * ftol      : precision goal for the value of f in the stoping criterion
+   * ftol      : precision goal for the value of f in the stopping criterion
    *             if ftol < 0.0, ftol is set to accuracy
    * xtol      : precision goal for the value of x in the stopping criterion
    *             (after applying x scaling factors)
@@ -214,6 +208,7 @@ void TNC::run()
    */
 
   int returnCode = tnc((int)dimension, &(*x.begin()), &f, NULL, TNC::ComputeObjectiveAndGradient, (void*) this, &(*low.begin()), &(*up.begin()), refScale, refOffset, message, getMaxCGit(), getMaximumEvaluationNumber(), getEta(), getStepmx(), getAccuracy(), getFmin(), getMaximumResidualError(), getMaximumAbsoluteError(), getMaximumConstraintError(), getRescale(), &nfeval);
+  p_nfeval_ = nullptr;
 
   if ((returnCode != TNC_LOCALMINIMUM) && (returnCode != TNC_FCONVERGED) && (returnCode != TNC_XCONVERGED) && (returnCode != TNC_USERABORT))
   {
@@ -222,49 +217,10 @@ void TNC::run()
     else
       throw InternalException(HERE) << "Solving problem by TNC method failed (" << tnc_rc_string[returnCode - TNC_MINRC] << ")";
   }
-  p_nfeval_ = 0;
+  if (!evaluationInputHistory_.getSize())
+    throw InternalException(HERE) << "TNC error at starting point x=" << x << " (" << tnc_rc_string[returnCode - TNC_MINRC] << ")";
 
-  // Update the result
-  result_ = OptimizationResult(getProblem());
-  const UnsignedInteger size = evaluationInputHistory_.getSize();
-
-  Scalar absoluteError = -1.0;
-  Scalar relativeError = -1.0;
-  Scalar residualError = -1.0;
-  Scalar constraintError = -1.0;
-
-  for (UnsignedInteger i = 0; i < size; ++ i)
-  {
-    const Point inP(evaluationInputHistory_[i]);
-    const Point outP(evaluationOutputHistory_[i]);
-    if (i > 0)
-    {
-      const Point inPM(evaluationInputHistory_[i - 1]);
-      const Point outPM(evaluationOutputHistory_[i - 1]);
-      absoluteError = (inP - inPM).normInf();
-      relativeError = (inP.normInf() > 0.0) ? (absoluteError / inP.normInf()) : -1.0;
-      residualError = (std::abs(outP[0]) > 0.0) ? (std::abs(outP[0] - outPM[0]) / std::abs(outP[0])) : -1.0;
-    }
-    constraintError = 0.0;
-    for (UnsignedInteger j = 0; j < dimension; ++ j)
-    {
-      if (finiteLow[j] && (inP[j] < low[j]))
-      {
-        constraintError = std::max(constraintError, low[j] - inP[j]);
-      }
-      if (finiteUp[j] && (up[j] < inP[j]))
-      {
-        constraintError = std::max(constraintError, inP[j] - up[j]);
-      }
-    } // for j
-    result_.store(inP, Point(1, outP[0]), absoluteError, relativeError, residualError, constraintError);
-  } // for i
-
-  /* Store the result */
-  result_.setEvaluationNumber(size);
-  result_.setOptimalPoint(x);
-  const Scalar sign = getProblem().isMinimization() ? 1.0 : -1.0;
-  result_.setOptimalValue(Point(1, sign * f));
+  setResultFromEvaluationHistory(evaluationInputHistory_, evaluationOutputHistory_);
 }
 
 /* Scale accessor */
@@ -418,7 +374,7 @@ int TNC::ComputeObjectiveAndGradient(double *x, double *f, double *g, void *stat
   Point outP;
   try
   {
-    for (UnsignedInteger i = 0; i < inP.getDimension(); ++i)
+    for (UnsignedInteger i = 0; i < dimension; ++ i)
       if (!SpecFunc::IsNormal(inP[i]))
         throw InvalidArgumentException(HERE) << "TNC got a nan input value";
 
