@@ -2,7 +2,7 @@
 /**
  *  @brief This class implements the fourth order fixed-step Runge-Kutta ODE integrator
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -21,6 +21,7 @@
 
 #include "openturns/PersistentObjectFactory.hxx"
 #include "openturns/RungeKutta.hxx"
+#include "openturns/SpecFunc.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -74,6 +75,9 @@ Sample RungeKutta::solve(const Point & initialState,
     const Scalar newT = timeGrid[i];
     const Scalar timeStep = newT - t;
     const Point phi(computeStep(transitionFunction, t, state, timeStep));
+    for (UnsignedInteger j = 0; j < phi.getDimension(); ++ j)
+      if (!SpecFunc::IsNormal(phi[j]))
+        throw InvalidArgumentException(HERE) << "RungeKutta: Step is " << phi.__str__() << " at " << state.__str__() << " with t=" << t << " h=" << timeStep;
     state += timeStep * phi;
     result[i] = state;
     t = newT;
