@@ -3,7 +3,7 @@
  *  @file  HMatrixImplementation.cxx
  *  @brief This file supplies support for HMat
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -20,7 +20,7 @@
  */
 #include <iostream>
 #include <cstdlib>
-#include <errno.h>
+#include <cstring>
 
 #include "openturns/HMatrixImplementation.hxx"
 #include "openturns/Log.hxx"
