@@ -2,7 +2,7 @@
 /**
  *  @brief This class is a top-level class for low discrepancy sequences
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -148,7 +148,7 @@ void LowDiscrepancySequenceImplementation::load(Advocate & adv)
 }
 
 
-/* Compute the local discrepancy of a sample, given a multidimensionnal interval */
+/* Compute the local discrepancy of a sample, given a multidimensional interval */
 Scalar LowDiscrepancySequenceImplementation::ComputeLocalDiscrepancy(const Sample & sample,
     const Interval & interval)
 {
@@ -380,7 +380,11 @@ Unsigned64BitsInteger LowDiscrepancySequenceImplementation::GetNextPrimeNumber(c
   if (n == 0) return 2;
 #ifdef OPENTURNS_HAVE_PRIMESIEVE
   primesieve::iterator it;
+#if PRIMESIEVE_VERSION_MAJOR >= 11
+  it.jump_to(n - 1);
+#else
   it.skipto(n - 1);
+#endif
   return it.next_prime();
 #else
   const Unsigned64BitsIntegerCollection primes(GetFirstPrimeNumbers(static_cast<UnsignedInteger>(n / SpecFunc::LambertW(n))));
