@@ -2,7 +2,7 @@
 /**
  *  @brief ProcessSample Class
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -226,11 +226,6 @@ Field ProcessSample::computeCentralMoment(const UnsignedInteger k) const
   return getImplementation()->computeCentralMoment(k);
 }
 
-Field ProcessSample::computeCenteredMoment(const UnsignedInteger k) const
-{
-  return getImplementation()->computeCenteredMoment(k);
-}
-
 /* Gives the raw moment of order k of the sample (by component) */
 Field ProcessSample::computeRawMoment(const UnsignedInteger k) const
 {
