@@ -2,7 +2,7 @@
 /**
  *  @brief ProcessSampleImplementation Class
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -270,12 +270,6 @@ Field ProcessSampleImplementation::computeCentralMoment(const UnsignedInteger k)
   return Field(mesh_, values);
 }
 
-Field ProcessSampleImplementation::computeCenteredMoment(const UnsignedInteger k) const
-{
-  LOGWARN(OSS() << "ProcessSample::computeCenteredMoment is deprecated, use computeCentralMoment");
-  return computeCentralMoment(k);
-}
-
 /*
  * Gives the raw moment of order k of the sample (by component)
  */
