@@ -1,7 +1,7 @@
 //                                               -*- C++ -*-
 /**
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -147,7 +147,7 @@ void ProductCovarianceModel::setCollection(const CovarianceModelCollection & col
 
 }
 
-const ProductCovarianceModel::CovarianceModelCollection & ProductCovarianceModel::getCollection() const
+ProductCovarianceModel::CovarianceModelCollection ProductCovarianceModel::getCollection() const
 {
   return collection_;
 }
