@@ -2,7 +2,7 @@
 /**
  *  @brief The class Sample implements blank free samples
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -63,18 +63,6 @@ void Sample::exportToCSVFile(const FileName & filename,
   getImplementation()->exportToCSVFile(filename, csvSeparator, numSeparator, precision, format);
 }
 
-/* Store a sample in a temporary text file, one realization by line. Returns the file name. */
-String Sample::storeToTemporaryFile() const
-{
-  return getImplementation()->storeToTemporaryFile();
-}
-
-/* Export a sample as a matrix, one row by realization, in a format suitable to exchange with R. */
-String Sample::streamToRFormat() const
-{
-  return getImplementation()->streamToRFormat();
-}
-
 /* Default constructor */
 Sample::Sample()
   : TypedInterfaceObject<SampleImplementation>(new SampleImplementation(0, 1))
@@ -515,11 +503,6 @@ Point Sample::computeCentralMoment(const UnsignedInteger k) const
   return getImplementation()->computeCentralMoment(k);
 }
 
-Point Sample::computeCenteredMoment(const UnsignedInteger k) const
-{
-  return getImplementation()->computeCenteredMoment(k);
-}
-
 /*
  * Gives the raw moment of order k of the sample (by component)
  */
