@@ -2,7 +2,7 @@
 /**
  *  @brief The class SampleImplementation implements blank free samples
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -632,55 +632,6 @@ SampleImplementation SampleImplementation::BuildFromTextFile(const FileName & fi
   return impl;
 }
 
-/* Store a sample in a temporary text file, one realization by line. Returns the file name. */
-String SampleImplementation::storeToTemporaryFile() const
-{
-  const String dataFileName(Path::BuildTemporaryFileName("RData.txt.XXXXXX"));
-  std::ofstream dataFile(dataFileName.c_str());
-  dataFile << std::setprecision(16);
-  // Fill-in the data file
-  UnsignedInteger index = 0;
-  for (UnsignedInteger i = 0; i < size_; ++i)
-  {
-    Scalar value = data_[index];
-    ++index;
-    if (SpecFunc::IsNaN(value)) dataFile << '\"' << value << '\"';
-    else dataFile << value;
-    for (UnsignedInteger j = 1; j < dimension_; ++j)
-    {
-      value = data_[index];
-      ++index;
-      if (SpecFunc::IsNaN(value)) dataFile << ' ' << '\"' << value << '\"';
-      else dataFile << ' ' << value;
-    }
-    dataFile << "\n";
-  }
-  dataFile.close();
-  return dataFileName;
-}
-
-/* Export a sample as a matrix, one row by realization, in a format suitable to exchange with R */
-String SampleImplementation::streamToRFormat() const
-{
-  OSS oss;
-  oss.setPrecision(16);
-  oss << "matrix(c(";
-  String separator("");
-  for (UnsignedInteger j = 0; j < dimension_; ++j)
-  {
-    UnsignedInteger index = j;
-    for (UnsignedInteger i = 0; i < size_; ++i, separator = ",")
-    {
-      const Scalar value = data_[index];
-      index += dimension_;
-      const Bool isNaN = SpecFunc::IsNaN(value);
-      oss << separator << (isNaN ? "\"" : "") << value << (isNaN ? "\"" : "");
-    }
-  }
-  oss << "), nrow=" << size_ << ", ncol=" << dimension_ << ")";
-  return oss;
-}
-
 /* Default constructor is private */
 SampleImplementation::SampleImplementation()
   : PersistentObject()
@@ -1080,18 +1031,16 @@ SampleImplementation & SampleImplementation::add(const Point & point)
 
 
 /* Appends another sample to the collection */
-SampleImplementation & SampleImplementation::add(const SampleImplementation & sample)
+SampleImplementation & SampleImplementation::add(const SampleImplementation & other)
 {
-  if (sample.getDimension() != dimension_)
-    throw InvalidArgumentException(HERE) << "Sample has invalid dimension ("
-                                         << sample.getDimension()
-                                         << ") expected : "
-                                         << getDimension();
-  //const UnsignedInteger oldSize = size_;
-  size_ += sample.getSize();
+  if (other.getDimension() != dimension_)
+    throw InvalidArgumentException(HERE) << "Sample has invalid dimension (" << other.getDimension()
+                                         << ") expected : " << getDimension();
+  // save original size in case other=this
+  const UnsignedInteger otherSize = other.getSize();
+  size_ += otherSize;
   data_.resize(size_ * dimension_);
-//   memmove( &data_[oldSize * dimension_], &(sample.data_[0]), sample.getSize() * dimension_ * sizeof(Scalar) );
-  std::copy_backward(sample.begin(), sample.end(), end());
+  std::copy_backward(other.begin(), other.begin() + otherSize, end());
   return *this;
 }
 
@@ -1100,19 +1049,23 @@ SampleImplementation & SampleImplementation::stack(const SampleImplementation &
 {
   if (sample.getSize() != size_) throw InvalidArgumentException(HERE) << "Error: the given sample has size=" << sample.getSize() << ", expected size=" << size_;
   const UnsignedInteger otherDimension = sample.getDimension();
-  SampleImplementation result(size_, dimension_ + otherDimension);
+  const UnsignedInteger totalDimension = dimension_ + otherDimension;
+  SampleImplementation result(size_, totalDimension);
   // First, the values
-  for (UnsignedInteger i = 0; i < size_; ++i)
+  for (UnsignedInteger i = 0; i < size_; ++ i)
   {
-    for (UnsignedInteger j = 0; j < dimension_; ++j) result(i, j) = operator()(i, j);
-    for (UnsignedInteger j = 0; j < otherDimension; ++j) result(i, dimension_ + j) = sample(i, j);
+    std::copy(data_begin() + i * dimension_, data_begin() + (i + 1) * dimension_,
+              result.data_begin() + i * totalDimension);
+    std::copy(sample.data_begin() + i * otherDimension, sample.data_begin() + (i + 1) * otherDimension,
+              result.data_begin() + i * totalDimension + dimension_);
   }
   // Second, the description
   if (!p_description_.isNull() || !sample.p_description_.isNull())
   {
     Description description(getDescription());
     const Description otherDescription(sample.getDescription());
-    for (UnsignedInteger i = 0; i < otherDimension; ++i) description.add(otherDescription[i]);
+    for (UnsignedInteger i = 0; i < otherDimension; ++ i)
+      description.add(otherDescription[i]);
     result.setDescription(description);
   }
   *this = result;
@@ -1803,12 +1756,6 @@ Point SampleImplementation::computeCentralMoment(const UnsignedInteger k) const
   return centeredMoment / size_;
 }
 
-Point SampleImplementation::computeCenteredMoment(const UnsignedInteger k) const
-{
-  LOGWARN(OSS() << "Sample::computeCenteredMoment is deprecated, use computeCentralMoment");
-  return computeCentralMoment(k);
-}
-
 /*
  * Gives the raw moment of order k of the sample (by component)
  */
