@@ -2,7 +2,7 @@
 /**
  *  @brief MatrixImplementation implements the classical mathematical MatrixImplementation
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -20,6 +20,7 @@
  */
 #include <cstdlib>
 #include <functional>
+#include <numeric>
 #include <cstring> // std::memset
 
 #include "openturns/MatrixImplementation.hxx"
@@ -508,7 +509,7 @@ MatrixImplementation & MatrixImplementation::operator*= (const Scalar s)
 /* Division by a Scalar*/
 MatrixImplementation MatrixImplementation::operator/ (const Scalar s) const
 {
-  if (!(s < 0.0 || s > 0.0)) throw InvalidArgumentException(HERE);
+  if (!(s < 0.0 || s > 0.0)) throw InvalidArgumentException(HERE) << "Trying to divide matrix by 0";
   if ((nbRows_ == 0) || (nbColumns_ == 0)) return *this;
   MatrixImplementation scalprod(*this);
   double alpha(1.0 / s);
@@ -522,7 +523,7 @@ MatrixImplementation MatrixImplementation::operator/ (const Scalar s) const
 /* In-place division by a Scalar */
 MatrixImplementation & MatrixImplementation::operator/= (const Scalar s)
 {
-  if (!(s < 0.0 || s > 0.0)) throw InvalidArgumentException(HERE);
+  if (!(s < 0.0 || s > 0.0)) throw InvalidArgumentException(HERE) << "Trying to divide matrix by 0 in place";
   if ((nbRows_ == 0) || (nbColumns_ == 0)) return *this;
   double alpha(1.0 / s);
   int one(1);
@@ -750,8 +751,7 @@ MatrixImplementation MatrixImplementation::cleanSym(const Scalar threshold) cons
 /* Resolution of a linear system : rectangular matrix
  * MX = b, M is an mxn matrix, b is an mxq matrix and
  * X is an nxq matrix */
-MatrixImplementation MatrixImplementation::solveLinearSystemRect (const MatrixImplementation & b,
-    const Bool keepIntact)
+MatrixImplementation MatrixImplementation::solveLinearSystemRectInPlace(const MatrixImplementation & b)
 {
   if (nbRows_ != b.nbRows_) throw InvalidDimensionException(HERE) << "The right-hand side has row dimension=" << b.nbRows_ << ", expected " << nbRows_;
   if (!(nbRows_ > 0 && nbColumns_ > 0 && b.nbColumns_ > 0)) throw InvalidDimensionException(HERE) << "Cannot solve a linear system with empty matrix or empty right-hand side";
@@ -772,40 +772,44 @@ MatrixImplementation MatrixImplementation::solveLinearSystemRect (const MatrixIm
   double rcond(ResourceMap::GetAsScalar("Matrix-DefaultSmallPivot"));
   int rank = -1;
 
-  MatrixImplementation Q;
-  if (keepIntact) Q = MatrixImplementation(*this);
-  MatrixImplementation & A = keepIntact ? Q : *this;
-
-  dgelsy_(&m, &n, &nrhs, &A[0], &m, &B[0], &p, &jpiv[0], &rcond, &rank, &lwork_d, &lwork, &info);
+  dgelsy_(&m, &n, &nrhs, &(*this)[0], &m, &B[0], &p, &jpiv[0], &rcond, &rank, &lwork_d, &lwork, &info);
   lwork = static_cast<int>(lwork_d);
   Point work(lwork);
-  dgelsy_(&m, &n, &nrhs, &A[0], &m, &B[0], &p, &jpiv[0], &rcond, &rank, &work[0], &lwork, &info);
+  dgelsy_(&m, &n, &nrhs, &(*this)[0], &m, &B[0], &p, &jpiv[0], &rcond, &rank, &work[0], &lwork, &info);
 
   MatrixImplementation result(n, q);
   for(UnsignedInteger j = 0; j < static_cast<UnsignedInteger>(q); ++j)
-    for (UnsignedInteger i = 0; i < static_cast<UnsignedInteger>(n); ++i)
-      result(i, j) = B(i, j);
+    std::copy(&B(0, j), &B(0, j) + n, &result(0, j));
   return result;
 }
 
+MatrixImplementation MatrixImplementation::solveLinearSystemRect(const MatrixImplementation & b) const
+{
+  MatrixImplementation A(*this);
+  return A.solveLinearSystemRectInPlace(b);
+}
+
 /* Resolution of a linear system : rectangular matrix
  * Mx = b, M is an mxn matrix, b is an m-dimensional
  * vector and x is an n-dimensional vector */
-Point MatrixImplementation::solveLinearSystemRect (const Point & b,
-    const Bool keepIntact)
+Point MatrixImplementation::solveLinearSystemRectInPlace(const Point & b)
 {
   const UnsignedInteger m = b.getDimension();
   if (nbRows_ != m) throw InvalidDimensionException(HERE) << "The right-hand side dimension is " << m << ", expected " << nbRows_;
   if (nbRows_ == 0) throw InvalidDimensionException(HERE) << "Cannot solve a linear system with empty matrix";
   // Solve the matrix linear system
   // A MatrixImplementation is also a collection of Scalar, so it is automatically converted into a Point
-  return solveLinearSystemRect(MatrixImplementation(m, 1, b), keepIntact);
+  return solveLinearSystemRectInPlace(MatrixImplementation(m, 1, b));
 }
 
+Point MatrixImplementation::solveLinearSystemRect(const Point & b) const
+{
+  MatrixImplementation A(*this);
+  return A.solveLinearSystemRectInPlace(b);
+}
 
-/* Resolution of a linear system : square matrix */
-MatrixImplementation MatrixImplementation::solveLinearSystemTri (const MatrixImplementation & b,
-    const Bool keepIntact,
+/* Resolution of a linear system : triangular matrix */
+MatrixImplementation MatrixImplementation::solveLinearSystemTriInPlace (const MatrixImplementation & b,
     const Bool lower,
     const Bool transposed)
 {
@@ -836,18 +840,20 @@ MatrixImplementation MatrixImplementation::solveLinearSystemTri (const MatrixImp
   int lda = nbRows_;
   // leading dimension of B
   int ldb = b.nbRows_;
-  if (keepIntact)
-  {
-    MatrixImplementation A(*this);
-    dtrsm_(&side, &uplo, &transa, &diag, &m, &n, &alpha, const_cast<double*>(&(A[0])), &lda, const_cast<double*>(&(B[0])), &ldb, &lside, &luplo, &ltransa, &ldiag);
-  }
-  else dtrsm_(&side, &uplo, &transa, &diag, &m, &n, &alpha, const_cast<double*>(&((*this)[0])), &lda, const_cast<double*>(&(B[0])), &ldb, &lside, &luplo, &ltransa, &ldiag);
+  dtrsm_(&side, &uplo, &transa, &diag, &m, &n, &alpha, const_cast<double*>(&((*this)[0])), &lda, const_cast<double*>(&(B[0])), &ldb, &lside, &luplo, &ltransa, &ldiag);
   return B;
 }
 
-/* Resolution of a linear system : square matrix */
-Point MatrixImplementation::solveLinearSystemTri (const Point & b,
-    const Bool keepIntact,
+MatrixImplementation MatrixImplementation::solveLinearSystemTri(const MatrixImplementation & b,
+    const Bool lower,
+    const Bool transposed) const
+{
+  MatrixImplementation A(*this);
+  return A.solveLinearSystemTriInPlace(b, lower, transposed);
+}
+
+/* Resolution of a linear system : triangular matrix */
+Point MatrixImplementation::solveLinearSystemTriInPlace(const Point & b,
     const Bool lower,
     const Bool transposed)
 {
@@ -855,14 +861,19 @@ Point MatrixImplementation::solveLinearSystemTri (const Point & b,
   if (nbRows_ != m) throw InvalidDimensionException(HERE) << "The right-hand side dimension is " << m << ", expected " << nbRows_;
   if (nbRows_ == 0) throw InvalidDimensionException(HERE) << "Cannot solve a linear system with empty matrix";
   // A MatrixImplementation is also a collection of Scalar, so it is automatically converted into a Point
-  return solveLinearSystemTri(MatrixImplementation(m, 1, b), keepIntact, lower, transposed);
+  return solveLinearSystemTriInPlace(MatrixImplementation(m, 1, b), lower, transposed);
 }
 
-
+Point MatrixImplementation::solveLinearSystemTri(const Point & b,
+    const Bool lower,
+    const Bool transposed) const
+{
+  MatrixImplementation A(*this);
+  return A.solveLinearSystemTriInPlace(b, lower, transposed);
+}
 
 /* Resolution of a linear system : square matrix */
-MatrixImplementation MatrixImplementation::solveLinearSystemSquare (const MatrixImplementation & b,
-    const Bool keepIntact)
+MatrixImplementation MatrixImplementation::solveLinearSystemSquareInPlace(const MatrixImplementation & b)
 {
   if (nbColumns_ != b.nbRows_ ) throw InvalidDimensionException(HERE) << "The right-hand side has row dimension=" << b.nbRows_ << ", expected " << nbRows_;
   if (!(nbRows_ > 0 && nbColumns_ > 0 && b.nbColumns_ > 0)) throw InvalidDimensionException(HERE) << "Cannot solve a linear system with empty matrix or empty right-hand side";
@@ -873,30 +884,35 @@ MatrixImplementation MatrixImplementation::solveLinearSystemSquare (const Matrix
   int nrhs(B.nbColumns_);
   int info;
   std::vector<int> ipiv(m);
-  if (keepIntact)
-  {
-    MatrixImplementation A(*this);
-    dgesv_(&m, &nrhs, &A[0], &m, &ipiv[0], &B[0], &m, &info);
-  }
-  else dgesv_(&m, &nrhs, &(*this)[0], &m, &ipiv[0], &B[0], &m, &info);
+  dgesv_(&m, &nrhs, &(*this)[0], &m, &ipiv[0], &B[0], &m, &info);
   if (info != 0) throw NotDefinedException(HERE) << "Error: the matrix is singular.";
   return B;
 }
 
+MatrixImplementation MatrixImplementation::solveLinearSystemSquare(const MatrixImplementation & b) const
+{
+  MatrixImplementation A(*this);
+  return A.solveLinearSystemSquareInPlace(b);
+}
+
 /* Resolution of a linear system : square matrix */
-Point MatrixImplementation::solveLinearSystemSquare (const Point & b,
-    const Bool keepIntact)
+Point MatrixImplementation::solveLinearSystemSquareInPlace(const Point & b)
 {
   const UnsignedInteger m = b.getDimension();
   if (nbRows_ != m) throw InvalidDimensionException(HERE) << "The right-hand side dimension is " << m << ", expected " << nbRows_;
   if (nbRows_ == 0) throw InvalidDimensionException(HERE) << "Cannot solve a linear system with empty matrix";
   // A MatrixImplementation is also a collection of Scalar, so it is automatically converted into a Point
-  return solveLinearSystemRect(MatrixImplementation(m, 1, b), keepIntact);
+  return solveLinearSystemSquareInPlace(MatrixImplementation(m, 1, b));
+}
+
+Point MatrixImplementation::solveLinearSystemSquare(const Point & b) const
+{
+  MatrixImplementation A(*this);
+  return A.solveLinearSystemSquareInPlace(b);
 }
 
 /* Resolution of a linear system : symmetric matrix */
-MatrixImplementation MatrixImplementation::solveLinearSystemSym (const MatrixImplementation & b,
-    const Bool keepIntact)
+MatrixImplementation MatrixImplementation::solveLinearSystemSymInPlace(const MatrixImplementation & b)
 {
   if (nbColumns_ != b.nbRows_ ) throw InvalidDimensionException(HERE) << "The right-hand side has row dimension=" << b.nbRows_ << ", expected " << nbRows_;
   if (!(nbRows_ > 0 && nbColumns_ > 0 && b.nbColumns_ > 0)) throw InvalidDimensionException(HERE) << "Cannot solve a linear system with empty matrix or empty right-hand side";
@@ -912,34 +928,40 @@ MatrixImplementation MatrixImplementation::solveLinearSystemSym (const MatrixImp
   std::vector<int> ipiv(n);
   int luplo(1);
 
-  MatrixImplementation Q;
-  if (keepIntact) Q = MatrixImplementation(*this);
-  MatrixImplementation & A = keepIntact ? Q : *this;
-
-  dsysv_(&uplo, &n, &nrhs, &A[0], &n, &ipiv[0], &B[0], &n, &lwork_d, &lwork, &info, &luplo);
+  dsysv_(&uplo, &n, &nrhs, &(*this)[0], &n, &ipiv[0], &B[0], &n, &lwork_d, &lwork, &info, &luplo);
   lwork = static_cast<int>(lwork_d);
   Point work(lwork);
-  dsysv_(&uplo, &n, &nrhs, &A[0], &n, &ipiv[0], &B[0], &n, &work[0], &lwork, &info, &luplo);
+  dsysv_(&uplo, &n, &nrhs, &(*this)[0], &n, &ipiv[0], &B[0], &n, &work[0], &lwork, &info, &luplo);
 
   if (info != 0) throw NotDefinedException(HERE) << "Error: the matrix is singular.";
   return B;
 }
 
+MatrixImplementation MatrixImplementation::solveLinearSystemSym(const MatrixImplementation & b) const
+{
+  MatrixImplementation A(*this);
+  return A.solveLinearSystemSymInPlace(b);
+}
+
 /* Resolution of a linear system : symmetric matrix */
-Point MatrixImplementation::solveLinearSystemSym (const Point & b,
-    const Bool keepIntact)
+Point MatrixImplementation::solveLinearSystemSymInPlace(const Point & b)
 {
   const UnsignedInteger dimension = b.getDimension();
   if (nbRows_ != dimension) throw InvalidDimensionException(HERE) << "The right-hand side dimension is " << dimension << ", expected " << nbRows_;
   if (nbRows_ == 0) throw InvalidDimensionException(HERE) << "Cannot solve a linear system with empty matrix";
   MatrixImplementation B(dimension, 1, b);
   // A MatrixImplementation is also a collection of Scalar, so it is automatically converted into a Point
-  return solveLinearSystemSym(B, keepIntact);
+  return solveLinearSystemSymInPlace(B);
+}
+
+Point MatrixImplementation::solveLinearSystemSym(const Point & b) const
+{
+  MatrixImplementation A(*this);
+  return A.solveLinearSystemSymInPlace(b);
 }
 
 /* Resolution of a linear system : covariance matrix */
-MatrixImplementation MatrixImplementation::solveLinearSystemCov (const MatrixImplementation & b,
-    const Bool keepIntact)
+MatrixImplementation MatrixImplementation::solveLinearSystemCovInPlace(const MatrixImplementation & b)
 {
   if (nbRows_ != b.nbRows_ ) throw InvalidDimensionException(HERE) << "The right-hand side has row dimension=" << b.nbRows_ << ", expected " << nbRows_;
   if (!(nbRows_ > 0 && nbColumns_ > 0 && b.nbColumns_ > 0)) throw InvalidDimensionException(HERE) << "Cannot solve a linear system with empty matrix or empty right-hand side";
@@ -951,29 +973,32 @@ MatrixImplementation MatrixImplementation::solveLinearSystemCov (const MatrixImp
   int nrhs(B.nbColumns_);
   int info;
   int luplo(1);
-  if (keepIntact)
-  {
-    MatrixImplementation A(*this);
-    dposv_(&uplo, &n, &nrhs, &A[0], &n, &B[0], &n, &info, &luplo);
-  }
-  else
-  {
-    dposv_(&uplo, &n, &nrhs, &(*this)[0], &n, &B[0], &n, &info, &luplo);
-  }
+  dposv_(&uplo, &n, &nrhs, &(*this)[0], &n, &B[0], &n, &info, &luplo);
   if (info != 0) throw NotDefinedException(HERE) << "Error: the matrix is singular.";
   return B;
 }
 
+MatrixImplementation MatrixImplementation::solveLinearSystemCov(const MatrixImplementation & b) const
+{
+  MatrixImplementation A(*this);
+  return A.solveLinearSystemCovInPlace(b);
+}
+
 /* Resolution of a linear system : symmetric matrix */
-Point MatrixImplementation::solveLinearSystemCov (const Point & b,
-    const Bool keepIntact)
+Point MatrixImplementation::solveLinearSystemCovInPlace(const Point & b)
 {
   const UnsignedInteger dimension = b.getDimension();
   if (nbRows_ != dimension) throw InvalidDimensionException(HERE) << "The right-hand side dimension is " << dimension << ", expected " << nbRows_;
   if (nbRows_ == 0) throw InvalidDimensionException(HERE) << "Cannot solve a linear system with empty matrix";
   MatrixImplementation B(dimension, 1, b);
   // A MatrixImplementation is also a collection of Scalar, so it is automatically converted into a Point
-  return solveLinearSystemCov(B, keepIntact);
+  return solveLinearSystemCovInPlace(B);
+}
+
+Point MatrixImplementation::solveLinearSystemCov(const Point & b) const
+{
+  MatrixImplementation A(*this);
+  return A.solveLinearSystemCovInPlace(b);
 }
 
 /* Compute determinant */
@@ -1269,6 +1294,8 @@ Bool MatrixImplementation::computeLargestEigenValueModuleSquare(Scalar & maximum
   Point currentEigenVector(dimension, 1.0);
   Point nextEigenVector(genVectProd(currentEigenVector));
   Scalar nextEigenValue = nextEigenVector.norm();
+  if (!SpecFunc::IsNormal(nextEigenValue))
+    throw InvalidArgumentException(HERE) << "Cannot compute eigen value due to nan/inf values";
   maximumModule = nextEigenValue / std::sqrt(1.0 * dimension);
   Bool found = false;
   Scalar precision = 0.0;
@@ -1295,6 +1322,8 @@ Bool MatrixImplementation::computeLargestEigenValueModuleSym(Scalar & maximumMod
   Point currentEigenVector(dimension, 1.0);
   Point nextEigenVector(symVectProd(currentEigenVector));
   Scalar nextEigenValue = nextEigenVector.norm();
+  if (!SpecFunc::IsNormal(nextEigenValue))
+    throw InvalidArgumentException(HERE) << "Cannot compute eigen value due to nan/inf values";
   maximumModule = nextEigenValue / std::sqrt(1.0 * dimension);
   Bool found = false;
   Scalar precision = 0.0;
@@ -1453,13 +1482,60 @@ MatrixImplementation MatrixImplementation::computeCholesky(const Bool keepIntact
 
   dpotrf_(&uplo, &n, &A[0], &n, &info, &luplo);
   if (info != 0) throw NotSymmetricDefinitePositiveException(HERE) << "Error: the matrix is not definite positive.";
-  for (UnsignedInteger j = 0; j < (UnsignedInteger)(n); ++ j)
-    for (UnsignedInteger i = 0; i < j; ++ i)
-      A(i, j) = 0.0;
+  // ensure upper triangle is zero
+  for (UnsignedInteger j = 1; j < (UnsignedInteger)(n); ++ j)
+    std::fill_n(&A(0, j), j, 0.0);
   A.setName("");
   return A;
 }
 
+MatrixImplementation MatrixImplementation::computeRegularizedCholesky() const
+{
+  Bool continuationCondition = true;
+  Scalar maxEV = -1.0;
+  const Scalar startingScaling = ResourceMap::GetAsScalar("Matrix-StartingScaling");
+  const Scalar maximalScaling = ResourceMap::GetAsScalar("Matrix-MaximalScaling");
+  Scalar cumulatedScaling = 0.0;
+  Scalar scaling = startingScaling;
+  MatrixImplementation choleskyFactor;
+  MatrixImplementation work(*this);
+  while (continuationCondition)
+  {
+    try
+    {
+      choleskyFactor = work.computeCholesky(false);
+      continuationCondition = false;
+    }
+    // If the factorization failed regularize the matrix
+    // Here we use a generic exception as different exceptions may be thrown
+    catch (const Exception &)
+    {
+      // If the largest eigenvalue module has not been computed yet...
+      if (maxEV < 0.0)
+      {
+        const Bool found = computeLargestEigenValueModuleSym(maxEV);
+        if (!found) throw InternalException(HERE) << "In MatrixImplementation::computeRegularizedCholesky, could not find largest eigenvalue module up to the desired precision";
+        LOGDEBUG(OSS() << "maxEV=" << maxEV);
+        scaling *= maxEV;
+      }
+      cumulatedScaling += scaling ;
+      LOGDEBUG(OSS() << "scaling=" << scaling << ", cumulatedScaling=" << cumulatedScaling);
+      // Unroll the regularization to optimize the computation
+      work = *this;
+      for (UnsignedInteger i = 0; i < work.getDimension(); ++ i)
+        work(i, i) += cumulatedScaling;
+      scaling *= 2.0;
+      continuationCondition = scaling < maxEV * maximalScaling;
+    }
+  }
+  if (maxEV > 0.0 && scaling >= maximalScaling * maxEV)
+    throw InvalidArgumentException(HERE) << "In MatrixImplementation::computeRegularizedCholesky, could not compute the Cholesky factor."
+                                         << " Scaling up to "  << cumulatedScaling << " was not enough";
+  if (cumulatedScaling > 0.0)
+    LOGWARN(OSS() <<  "Warning! Scaling up to " << cumulatedScaling << " was needed in order to factorize the matrix.");
+  return choleskyFactor;
+}
+
 /* Update in-place the Cholesky factor L of an SPD matrix M given a rank-one update vv^T, ie L becomes Lnew such that LnewLnew^t = Mnew with Mnew = M + vv^t */
 void MatrixImplementation::CholeskyUpdate(MatrixImplementation & cholesky,
     const Point & vector)
@@ -1647,78 +1723,118 @@ UnsignedInteger MatrixImplementation::stride(const UnsignedInteger dim) const
 /** Diagonal extraction */
 MatrixImplementation MatrixImplementation::getDiagonal(const SignedInteger k) const
 {
-  SignedInteger m = nbRows_;
-  SignedInteger n = nbColumns_;
+  const SignedInteger m = nbRows_;
+  const SignedInteger n = nbColumns_;
   if (k >= n) throw OutOfBoundException(HERE) << "One must have k < nbColumns";
   if (-k > m) throw OutOfBoundException(HERE) << "One must have -nbRows < k ";
 
-  /* Fisrt step: the size of the diagonal */
-  UnsignedInteger nElt;
-  /* Extraction */
-  if(k >= 0)
-  {
-    nElt = std::min(m, n - k);
-  }
-  else
-  {
-    nElt = std::min(m + k, n);
-  }
+  /* First step: the size of the diagonal */
+  const UnsignedInteger nElt = (k >= 0 ? std::min(m, n - k) : std::min(m + k, n));
 
   /* Extraction */
   MatrixImplementation diag(nElt, 1);
-  if(k >= 0)
+  UnsignedInteger index = (k >= 0 ? k * m : -k);
+  const SignedInteger stride = m + 1;
+  for(UnsignedInteger l = 0; l < nElt; ++l)
   {
-    for(UnsignedInteger l = 0; l < nElt; ++l)
-    {
-      diag(l, 0) = (*this)(l, l + k);
-    }
-  }
-  else
-  {
-    for(UnsignedInteger l = 0; l < nElt; ++l)
-    {
-      diag(l, 0) = (*this)(l - k, l);
-    }
+    diag(l, 0) = (*this)[index];//(l, l + k);
+    index += stride;
   }
   return diag;
 }
 
+/** Extract diagonal */
+Point MatrixImplementation::getDiagonalAsPoint(const SignedInteger k) const
+{
+  const SignedInteger m = nbRows_;
+  const SignedInteger n = nbColumns_;
+  if (k >= n)
+    throw OutOfBoundException(HERE) << "One must have k < nbColumns";
+  if (-k > m)
+    throw OutOfBoundException(HERE) << "One must have -nbRows < k ";
+
+  /* First step: the size of the diagonal */
+  const UnsignedInteger nElt = (k >= 0 ? std::min(m, n - k) : std::min(m + k, n));
+
+  /* Extraction */
+  Point diag(nElt);
+  UnsignedInteger index = (k >= 0 ? k * m : -k);
+  const SignedInteger stride = m + 1;
+  for (UnsignedInteger l = 0; l < nElt; ++l)
+  {
+    diag[l] = (*this)[index]; //(l, l + k);
+    index += stride;
+  }
+  return diag;
+}
+
+/** Fill diagonal with values */
+void MatrixImplementation::setDiagonal(const MatrixImplementation &diag, const SignedInteger k)
+{
+  const SignedInteger m = nbRows_;
+  const SignedInteger n = nbColumns_;
+  if (k >= n)
+    throw OutOfBoundException(HERE) << "One must have k < nbColumns";
+  if (-k > m)
+    throw OutOfBoundException(HERE) << "One must have -nbRows < k ";
+  if ((diag.getNbRows() > 1) && (diag.getNbColumns() > 1))
+    throw InvalidDimensionException(HERE) << "Diag matrix must have one dimension equals to 1.";
+  /* First step: the size of the diagonal */
+  const SignedInteger nElt = (k >= 0 ? std::min(m, n - k) : std::min(m + k, n));
+
+  /* Extraction */
+  const SignedInteger stride = m + 1;
+  UnsignedInteger index = (k >= 0 ? k * m : -k);
+  for (SignedInteger l = 0; l < nElt; ++l)
+  {
+    (*this)[index] = diag[l];
+    index += stride;
+  }
+}
+
 /** Fill a diagonal with values */
 void MatrixImplementation::setDiagonal(const Point &diag, const SignedInteger k)
 {
-  SignedInteger m = nbRows_;
-  SignedInteger n = nbColumns_;
-  if (k >= n) throw OutOfBoundException(HERE) << "One must have k < nbColumns";
-  if (-k > m) throw OutOfBoundException(HERE) << "One must have -nbRows < k ";
+  const SignedInteger m = nbRows_;
+  const SignedInteger n = nbColumns_;
+  if (k >= n)
+    throw OutOfBoundException(HERE) << "One must have k < nbColumns";
+  if (-k > m)
+    throw OutOfBoundException(HERE) << "One must have -nbRows < k ";
+  /* First step: the size of the diagonal */
+  const UnsignedInteger nElt = (k >= 0 ? std::min(m, n - k) : std::min(m + k, n));
 
-  /* Fisrt step: the size of the diagonal */
-  UnsignedInteger nElt;
-  if(k >= 0)
+  /* Extraction */
+  if (diag.getSize() != nElt)
+    throw InvalidDimensionException(HERE) << "Dimension mismatch.";
+  const SignedInteger stride = m + 1;
+  UnsignedInteger index = (k >= 0 ? k * m : -k);
+  for (UnsignedInteger l = 0; l < nElt; ++l)
   {
-    nElt = std::min(m, n - k);
-  }
-  else
-  {
-    nElt = std::min(m + k, n);
+    (*this)[index] = diag[l];
+    index += stride;
   }
+}
 
-  /* Check dimensions */
-  if (nElt != diag.getSize()) throw InvalidDimensionException(HERE) << "Dimension mismatch";
+/** Fill diagonal with the same value */
+void MatrixImplementation::setDiagonal(const Scalar value, const SignedInteger k)
+{
+  const SignedInteger m = nbRows_;
+  const SignedInteger n = nbColumns_;
+  if (k >= n)
+    throw OutOfBoundException(HERE) << "One must have k < nbColumns";
+  if (-k > m)
+    throw OutOfBoundException(HERE) << "One must have -nbRows < k ";
+  /* First step: the size of the diagonal */
+  const SignedInteger nElt = (k >= 0 ? std::min(m, n - k) : std::min(m + k, n));
 
-  /* Fill with values */
-  if(k >= 0)
+  /* Extraction */
+  const SignedInteger stride = m + 1;
+  UnsignedInteger index = (k >= 0 ? k * m : -k);
+  for (SignedInteger l = 0; l < nElt; ++l)
   {
-    for(UnsignedInteger l = 0; l < nElt; ++l)
-    {
-      (*this)(l, l + k) = diag[l];
-    }
-  }
-  else
-  {
-    for(UnsignedInteger l = 0; l < nElt; ++l)
-    {
-      (*this)(l - k, l) = diag[l];
-    }
+    (*this)[index] = value;
+    index += stride;
   }
 }
 
@@ -1751,16 +1867,7 @@ Scalar MatrixImplementation::computeSumElements() const
   if (nbColumns_ == 0) throw InvalidDimensionException(HERE) << "Matrices should have positive number of columns!";
 
   /* Result */
-  Scalar sum = 0.0;
-
-  /* TODO: is there any better implementation ? */
-  for(UnsignedInteger j = 0; j < nbColumns_; ++j)
-  {
-    for(UnsignedInteger i = 0; i < nbRows_; ++i)
-    {
-      sum += (*this)(i, j);
-    }
-  }
+  const Scalar sum = std::accumulate(begin(), end(), 0.0);
 
   return sum;
 }
