@@ -2,7 +2,7 @@
 /**
  *  @brief The class building chaos expansions
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -38,7 +38,6 @@
 #include "openturns/HyperbolicAnisotropicEnumerateFunction.hxx"
 #include "openturns/OrthogonalUniVariatePolynomialFamily.hxx"
 #include "openturns/OrthogonalProductPolynomialFactory.hxx"
-#include "openturns/UserDefined.hxx"
 #include "openturns/StandardDistributionPolynomialFactory.hxx"
 #include "openturns/LeastSquaresMetaModelSelectionFactory.hxx"
 #include "openturns/LARS.hxx"
@@ -68,78 +67,19 @@ FunctionalChaosAlgorithm::FunctionalChaosAlgorithm()
 
 
 /* Constructor */
-FunctionalChaosAlgorithm::FunctionalChaosAlgorithm(const Function & model,
-    const Distribution & distribution,
-    const AdaptiveStrategy & adaptiveStrategy,
-    const ProjectionStrategy & projectionStrategy)
-  : MetaModelAlgorithm(distribution, model)
-  , adaptiveStrategy_(adaptiveStrategy)
-  , projectionStrategy_(projectionStrategy)
-  , maximumResidual_(ResourceMap::GetAsScalar( "FunctionalChaosAlgorithm-DefaultMaximumResidual" ))
+FunctionalChaosAlgorithm::FunctionalChaosAlgorithm(const Sample & inputSample,
+    const Sample & outputSample)
+  : FunctionalChaosAlgorithm(inputSample, Point(inputSample.getSize(), 1.0 / inputSample.getSize()), outputSample)
 {
-  LOGWARN(OSS() << "FunctionalChaosAlgorithm(Function) is deprecated");
+  // Nothing to do
 }
 
-/* Constructor */
-FunctionalChaosAlgorithm::FunctionalChaosAlgorithm(const Sample & inputSample,
-    const Sample & outputSample,
-    const Distribution & distribution,
-    const AdaptiveStrategy & adaptiveStrategy,
-    const ProjectionStrategy & projectionStrategy)
-  : MetaModelAlgorithm(inputSample, outputSample, distribution, DatabaseFunction(inputSample, outputSample))
-  , adaptiveStrategy_(adaptiveStrategy)
-  , projectionStrategy_(projectionStrategy)
-  , maximumResidual_(ResourceMap::GetAsScalar( "FunctionalChaosAlgorithm-DefaultMaximumResidual" ))
-{
-  // Overwrite the content of the projection strategy with the given data
-  projectionStrategy_.setMeasure(UserDefined(inputSample));
-  projectionStrategy_.setExperiment(FixedExperiment(inputSample));
-  projectionStrategy_.setWeights(Point(inputSample.getSize(), 1.0 / inputSample.getSize()));
-  projectionStrategy_.setInputSample(inputSample);
-  projectionStrategy_.setOutputSample(outputSample);
-}
 
 /* Constructor */
 FunctionalChaosAlgorithm::FunctionalChaosAlgorithm(const Sample & inputSample,
     const Point & weights,
-    const Sample & outputSample,
-    const Distribution & distribution,
-    const AdaptiveStrategy & adaptiveStrategy,
-    const ProjectionStrategy & projectionStrategy)
-  : MetaModelAlgorithm(inputSample, outputSample, distribution, DatabaseFunction(inputSample, outputSample))
-  , adaptiveStrategy_(adaptiveStrategy)
-  , projectionStrategy_(projectionStrategy)
-  , maximumResidual_(ResourceMap::GetAsScalar( "FunctionalChaosAlgorithm-DefaultMaximumResidual" ))
-{
-  // Overwrite the content of the projection strategy with the given data
-  projectionStrategy_.setMeasure(UserDefined(inputSample));
-  projectionStrategy_.setExperiment(FixedExperiment(inputSample));
-  projectionStrategy_.setWeights(weights);
-  projectionStrategy_.setInputSample(inputSample);
-  projectionStrategy_.setOutputSample(outputSample);
-}
-
-/* Constructor */
-FunctionalChaosAlgorithm::FunctionalChaosAlgorithm(const Function & model,
-    const Distribution & distribution,
-    const AdaptiveStrategy & adaptiveStrategy)
-  : MetaModelAlgorithm(distribution, model)
-  , adaptiveStrategy_(adaptiveStrategy)
-  , projectionStrategy_(LeastSquaresStrategy())
-  , maximumResidual_(ResourceMap::GetAsScalar( "FunctionalChaosAlgorithm-DefaultMaximumResidual" ))
-{
-  LOGWARN(OSS() << "FunctionalChaosAlgorithm(Function) is deprecated");
-}
-
-/* Constructor */
-FunctionalChaosAlgorithm::FunctionalChaosAlgorithm(const Sample & inputSample,
-    const Sample & outputSample,
-    const Distribution & distribution,
-    const AdaptiveStrategy & adaptiveStrategy)
-  : MetaModelAlgorithm(inputSample, outputSample, distribution, DatabaseFunction(inputSample, outputSample))
-  , adaptiveStrategy_(adaptiveStrategy)
-  , projectionStrategy_(LeastSquaresStrategy(inputSample, outputSample))
-  , maximumResidual_(ResourceMap::GetAsScalar( "FunctionalChaosAlgorithm-DefaultMaximumResidual" ))
+    const Sample & outputSample)
+  : FunctionalChaosAlgorithm(inputSample, weights, outputSample, BuildDistribution(inputSample))
 {
   // Nothing to do
 }
@@ -149,7 +89,20 @@ FunctionalChaosAlgorithm::FunctionalChaosAlgorithm(const Sample & inputSample,
 FunctionalChaosAlgorithm::FunctionalChaosAlgorithm(const Sample & inputSample,
     const Sample & outputSample,
     const Distribution & distribution)
-  : MetaModelAlgorithm(inputSample, outputSample, distribution, DatabaseFunction(inputSample, outputSample))
+  : FunctionalChaosAlgorithm(inputSample, Point(inputSample.getSize(), 1.0 / inputSample.getSize()), outputSample, distribution)
+{
+  // Nothing to do
+}
+
+
+/* Constructor */
+/* This one is big as it implements the automatic choice of
+   AdaptiveStrategy/ProjectionStrategy based on ResourceMap keys */
+FunctionalChaosAlgorithm::FunctionalChaosAlgorithm(const Sample & inputSample,
+    const Point & weights,
+    const Sample & outputSample,
+    const Distribution & distribution)
+  : MetaModelAlgorithm(inputSample, weights, outputSample, distribution)
   , adaptiveStrategy_()
   , projectionStrategy_()
   , maximumResidual_(ResourceMap::GetAsScalar("FunctionalChaosAlgorithm-DefaultMaximumResidual"))
@@ -170,16 +123,16 @@ FunctionalChaosAlgorithm::FunctionalChaosAlgorithm(const Sample & inputSample,
   {
     const String fittingAlgorithm(ResourceMap::GetAsString("FunctionalChaosAlgorithm-FittingAlgorithm"));
     if (fittingAlgorithm == "CorrectedLeaveOneOut")
-      projectionStrategy_ = LeastSquaresStrategy(inputSample, outputSample, LeastSquaresMetaModelSelectionFactory(LARS(), CorrectedLeaveOneOut()));
+      projectionStrategy_ = LeastSquaresStrategy(inputSample, weights, outputSample, LeastSquaresMetaModelSelectionFactory(LARS(), CorrectedLeaveOneOut()));
     else if (fittingAlgorithm == "KFold")
-      projectionStrategy_ = LeastSquaresStrategy(inputSample, outputSample, LeastSquaresMetaModelSelectionFactory(LARS(), KFold()));
+      projectionStrategy_ = LeastSquaresStrategy(inputSample, weights, outputSample, LeastSquaresMetaModelSelectionFactory(LARS(), KFold()));
     else
       throw InvalidArgumentException(HERE) << "Unknown fitting algorithm: " << fittingAlgorithm;
     LOGINFO(OSS() << "In FunctionalChaosAlgorithm, selected a sparse chaos expansion based on LARS and " << fittingAlgorithm);
   }
   else
   {
-    projectionStrategy_ = LeastSquaresStrategy(inputSample, outputSample);
+    projectionStrategy_ = LeastSquaresStrategy(inputSample, weights, outputSample);
     LOGINFO(OSS() << "In FunctionalChaosAlgorithm, selected a chaos expansion based on FixedStrategy");
   }
 
@@ -191,10 +144,43 @@ FunctionalChaosAlgorithm::FunctionalChaosAlgorithm(const Sample & inputSample,
   adaptiveStrategy_ = FixedStrategy(basis, totalSize);
 }
 
+
 /* Constructor */
 FunctionalChaosAlgorithm::FunctionalChaosAlgorithm(const Sample & inputSample,
-    const Sample & outputSample)
-  : FunctionalChaosAlgorithm(inputSample, outputSample, BuildDistribution(inputSample))
+    const Sample & outputSample,
+    const Distribution & distribution,
+    const AdaptiveStrategy & adaptiveStrategy)
+  : FunctionalChaosAlgorithm(inputSample, Point(inputSample.getSize(), 1.0 / inputSample.getSize()), outputSample, distribution, adaptiveStrategy)
+{
+  // Nothing to do
+}
+
+
+/* Constructor */
+/* This one forces the use of a basic LeastSquaresStrategy. Maybe we should
+implement the same logic as when both the AdaptiveStrategy and ProjectionStrategy
+are deduced from ResourceMap keys. */
+FunctionalChaosAlgorithm::FunctionalChaosAlgorithm(const Sample & inputSample,
+    const Point & weights,
+    const Sample & outputSample,
+    const Distribution & distribution,
+    const AdaptiveStrategy & adaptiveStrategy)
+  : MetaModelAlgorithm(inputSample, weights, outputSample, distribution)
+  , adaptiveStrategy_(adaptiveStrategy)
+  , projectionStrategy_(LeastSquaresStrategy(inputSample, weights, outputSample))
+  , maximumResidual_(ResourceMap::GetAsScalar( "FunctionalChaosAlgorithm-DefaultMaximumResidual" ))
+{
+  // Nothing to do
+}
+
+
+/* Constructor */
+FunctionalChaosAlgorithm::FunctionalChaosAlgorithm(const Sample & inputSample,
+    const Sample & outputSample,
+    const Distribution & distribution,
+    const AdaptiveStrategy & adaptiveStrategy,
+    const ProjectionStrategy & projectionStrategy)
+  : FunctionalChaosAlgorithm(inputSample, Point(inputSample.getSize(), 1.0 / inputSample.getSize()), outputSample, distribution, adaptiveStrategy, projectionStrategy)
 {
   // Nothing to do
 }
@@ -204,13 +190,19 @@ FunctionalChaosAlgorithm::FunctionalChaosAlgorithm(const Sample & inputSample,
     const Point & weights,
     const Sample & outputSample,
     const Distribution & distribution,
-    const AdaptiveStrategy & adaptiveStrategy)
-  : MetaModelAlgorithm(inputSample, outputSample, distribution, DatabaseFunction(inputSample, outputSample))
+    const AdaptiveStrategy & adaptiveStrategy,
+    const ProjectionStrategy & projectionStrategy)
+  : MetaModelAlgorithm(inputSample, weights, outputSample, distribution)
   , adaptiveStrategy_(adaptiveStrategy)
-  , projectionStrategy_(LeastSquaresStrategy(inputSample, weights, outputSample))
+  , projectionStrategy_(projectionStrategy)
   , maximumResidual_(ResourceMap::GetAsScalar( "FunctionalChaosAlgorithm-DefaultMaximumResidual" ))
 {
-  // Nothing to do
+  // Overwrite the content of the projection strategy with the given data
+  projectionStrategy_.setMeasure(distribution);
+  projectionStrategy_.setExperiment(FixedExperiment(inputSample));
+  projectionStrategy_.setWeights(weights);
+  projectionStrategy_.setInputSample(inputSample);
+  projectionStrategy_.setOutputSample(outputSample);
 }
 
 
@@ -258,14 +250,11 @@ AdaptiveStrategy FunctionalChaosAlgorithm::getAdaptiveStrategy() const
 /* Computes the functional chaos */
 void FunctionalChaosAlgorithm::run()
 {
-  const UnsignedInteger outputDimension = model_.getOutputDimension();
+  const UnsignedInteger outputDimension = getOutputSample().getDimension();
 
   // Get the measure upon which the orthogonal basis is built
   const OrthogonalBasis basis(adaptiveStrategy_.getImplementation()->basis_);
   const Distribution measure(basis.getMeasure());
-  // Correct the measure of the projection strategy if no input sample
-  const Bool databaseProjection = projectionStrategy_.getInputSample().getSize() > 0;
-  if (!databaseProjection) projectionStrategy_.setMeasure(measure);
 
   // First, compute all the parts that are independent of the marginal output
   // Create the isoprobabilistic transformation
@@ -282,11 +271,12 @@ void FunctionalChaosAlgorithm::run()
 
   // Build the composed model g = f o T^{-1}, which is a function of Z so it can be decomposed upon an orthonormal basis based on Z distribution
   const Bool noTransformation = (measure == distribution_);
-  if (noTransformation) composedModel_ = model_;
-  else composedModel_ = ComposedFunction(model_, inverseTransformation_);
+  const Function model(DatabaseFunction(getInputSample(), getOutputSample()));
+  if (noTransformation) composedModel_ = model;
+  else composedModel_ = ComposedFunction(model, inverseTransformation_);
   // If the input and output databases have already been given to the projection strategy, transport them to the measure space
   const Sample initialInputSample(projectionStrategy_.getInputSample());
-  if (databaseProjection && !noTransformation)
+  if (!noTransformation)
   {
     LOGINFO("Transform the input sample in the measure space");
     const Sample transformedSample(transformation_(initialInputSample));
@@ -348,8 +338,7 @@ void FunctionalChaosAlgorithm::run()
     Psi_k.add(basis.build(i));
   }
   // Build the result
-  result_ = FunctionalChaosResult(inputSample_, outputSample_, distribution_, transformation_, inverseTransformation_, composedModel_, basis, I_k, alpha_k, Psi_k, residuals, relativeErrors);
-  result_.setModel(model_);
+  result_ = FunctionalChaosResult(inputSample_, outputSample_, distribution_, transformation_, inverseTransformation_, basis, I_k, alpha_k, Psi_k, residuals, relativeErrors);
 }
 
 /* Marginal computation */
@@ -418,4 +407,3 @@ void FunctionalChaosAlgorithm::load(Advocate & adv)
 
 
 END_NAMESPACE_OPENTURNS
-
