@@ -2,7 +2,7 @@
 /**
  *  @brief Sensitivity analysis based on functional chaos expansion
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -21,8 +21,11 @@
 #include <algorithm>
 #include "openturns/PersistentObjectFactory.hxx"
 #include "openturns/FunctionalChaosSobolIndices.hxx"
+#include "openturns/FunctionalChaosRandomVector.hxx"
 #include "openturns/EnumerateFunction.hxx"
 #include "openturns/SpecFunc.hxx"
+#include "openturns/Os.hxx"
+#include "openturns/OSS.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -60,138 +63,128 @@ String FunctionalChaosSobolIndices::__repr__() const
 }
 
 
-inline bool varianceComparison(const std::pair<UnsignedInteger, Scalar> &a, const std::pair<UnsignedInteger, Scalar> &b)
+inline Bool varianceComparison(const std::pair<UnsignedInteger, Scalar> &a, const std::pair<UnsignedInteger, Scalar> &b)
 {
   return a.second > b.second;
 }
 
-String FunctionalChaosSobolIndices::summary() const
-{
-  LOGWARN(OSS() << "FunctionalChaosSobolIndices::summary is deprecated, use __str__()");
-  return __str__();
-}
-
 String FunctionalChaosSobolIndices::__str__(const String & /*offset*/) const
 {
-  const UnsignedInteger inputDimension = functionalChaosResult_.getDistribution().getDimension();
+  return __repr_markdown__();
+}
+
+String FunctionalChaosSobolIndices::__repr_markdown__() const
+{
+  const Distribution inputDistribution = functionalChaosResult_.getDistribution();
+  const UnsignedInteger inputDimension = inputDistribution.getDimension();
+  const Description inputDescription = inputDistribution.getDescription();
   const UnsignedInteger outputDimension = functionalChaosResult_.getMetaModel().getOutputDimension();
-  OSS oss;
+  OSS oss(false);
+  oss << FunctionalChaosSobolIndices::GetClassName() << Os::GetEndOfLine();
 
   const Indices indices(functionalChaosResult_.getIndices());
   const Sample coefficients(functionalChaosResult_.getCoefficients());
   const UnsignedInteger basisSize = indices.getSize();
+  EnumerateFunction enumerateFunction(functionalChaosResult_.getOrthogonalBasis().getEnumerateFunction());
 
-  // compute the variance
-  Point variance(outputDimension);
-  Point mean(outputDimension);
-  for (UnsignedInteger i = 0; i < outputDimension; ++i)
-  {
-    for (UnsignedInteger k = 0; k < basisSize; ++ k)
-      // Take into account only non-zero indices as the null index is the mean of the vector
-      if (indices[k] > 0)
-        variance[i] += coefficients(k, i) * coefficients(k, i);
-      else
-        mean[i] = coefficients(k, i);
-  }
-
-  // standard deviation
+  // compute the mean, the variance, the standard deviation
+  const FunctionalChaosRandomVector fcRandomVector(functionalChaosResult_);
+  const Point mean(fcRandomVector.getMean());
+  const CovarianceMatrix covarianceMatrix(fcRandomVector.getCovariance());
   Point stdDev(outputDimension);
-  for (UnsignedInteger i = 0; i < outputDimension; ++ i)
-    stdDev[i] = std::sqrt(variance[i]);
+  for (UnsignedInteger i = 0; i < outputDimension; ++i)
+    stdDev[i] = std::sqrt(covarianceMatrix(i, i));
 
   // quick summary
-  oss << " input dimension: " << inputDimension << "\n"
-      << " output dimension: " << outputDimension << "\n"
-      << " basis size: " << functionalChaosResult_.getReducedBasis().getSize() << "\n"
-      << " mean: " << mean.__str__() << "\n"
-      << " std-dev: " << stdDev.__str__() << "\n";
-  oss << String(60, '-') << "\n";
-  String st;
-
-  EnumerateFunction enumerateFunction(functionalChaosResult_.getOrthogonalBasis().getEnumerateFunction());
+  oss << "- input dimension=" << inputDimension << Os::GetEndOfLine()
+      << "- output dimension=" << outputDimension << Os::GetEndOfLine()
+      << "- basis size=" << functionalChaosResult_.getReducedBasis().getSize() << Os::GetEndOfLine()
+      << "- mean=" << mean << Os::GetEndOfLine()
+      << "- std-dev=" << stdDev << Os::GetEndOfLine();
+  oss << Os::GetEndOfLine();
+  String intermediateString;
+  const Scalar varianceThreshold = ResourceMap::GetAsScalar("FunctionalChaosSobolIndices-VariancePartThreshold");
+  const UnsignedInteger maximumNumberOfOutput = ResourceMap::GetAsUnsignedInteger("FunctionalChaosSobolIndices-MaximumNumberOfOutput");
+  const UnsignedInteger columnWidth = ResourceMap::GetAsUnsignedInteger("FunctionalChaosSobolIndices-PrintColumnWidth");
 
   for (UnsignedInteger m = 0; m < outputDimension; ++ m)
   {
-    UnsignedInteger maxdegree = 0;
-
-    std::vector< std::pair<UnsignedInteger, Scalar > > varianceOrder;
-
-    // compute part of contribution of each basis term
-    for (UnsignedInteger i = 1; i < basisSize; ++ i)
-    {
-      Scalar coefI = coefficients(i, m);
-      Indices multiIndices(enumerateFunction(indices[i]));
-      UnsignedInteger degreeI = 0;
-      for (UnsignedInteger k = 0; k < multiIndices.getSize(); ++ k) degreeI += multiIndices[k];
-
-      maxdegree = std::max(maxdegree, degreeI);
-      const Scalar varianceRatio = coefI * coefI / variance[m];
-      varianceOrder.push_back(std::pair<UnsignedInteger, Scalar >(i, varianceRatio));
-    }
-
-    // sort basis terms by descending variance contribution
-    std::sort(varianceOrder.begin(), varianceOrder.end(), varianceComparison);
-
+    if (m > maximumNumberOfOutput) break;
     if (outputDimension > 1)
-      oss << "Marginal: " << m << "\n";
+      oss << "Marginal: " << m << Os::GetEndOfLine();
+
+    const Point partOfVariance(getPartOfVariance(m));
+    const Sample partOfVarianceSample(Sample::BuildFromPoint(partOfVariance));
+    const Indices order(partOfVarianceSample.argsort(false));
 
     // table of part of variance for each basis term
-    oss << "Index   | Multi-indice                  | Part of variance  \n";
-    oss << String(60, '-') << "\n";
-    for (UnsignedInteger i = 0; i < varianceOrder.size(); ++ i)
+    // Print header
+    oss << "| Index |"
+        << OSS::PadString(" Multi-index", columnWidth) << "|"
+        << OSS::PadString(" Variance part", columnWidth) << "|"
+        << Os::GetEndOfLine();
+    // Print dashes
+    oss << "|-------|";
+    const String dashesSeparator(String(columnWidth, '-') + "|");
+    oss << dashesSeparator << dashesSeparator << Os::GetEndOfLine();
+    // Print table content
+    for (UnsignedInteger i = 0; i < basisSize; ++ i)
     {
-      // stop when the variance contribution becomes less than epsilon
-      if (varianceOrder[i].second < ResourceMap::GetAsScalar("FunctionalChaosSobolIndices-VariancePartThreshold"))
-        break;
+      const UnsignedInteger sortedIndex = order[i];
+      const UnsignedInteger rankIndex = indices[sortedIndex];
+      // stop when the part of variance becomes less than epsilon
+      if (partOfVariance[sortedIndex] < varianceThreshold) break;
+      Indices multiIndices(enumerateFunction(rankIndex));
 
-      Indices multiIndices(enumerateFunction(indices[varianceOrder[i].first]));
+      oss << "|" << std::setw(6) << sortedIndex << " |";
 
-      st = OSS() << std::setw(7) << varianceOrder[i].first;
-      oss << st << " | ";
+      intermediateString = OSS() << " " << multiIndices;
+      oss << OSS::PadString(intermediateString, columnWidth) << "|";
 
-      st = OSS() << multiIndices;
-      oss << st << String(st.size() < 29 ? 29 - st.size() : 0, ' ') << " | ";
-
-      st = OSS() << varianceOrder[i].second;
-      oss << st << "\n";
-    }
-    oss << String(60, '-') << "\n";
-    oss << "\n\n";
+      intermediateString = OSS() << " " << partOfVariance[sortedIndex];
+      oss << OSS::PadString(intermediateString, columnWidth) << "|" << Os::GetEndOfLine();
+    } // loop over the multi-indices
+    oss << Os::GetEndOfLine();
 
     // table of first/total order indices for each input
-    oss << String(60, '-') << "\n";
-    oss << "Component | Sobol index            | Sobol total index      \n";
-    oss << String(60, '-') << "\n";
+    // print table header
+    oss << "| Input |" << OSS::PadString(" Name", columnWidth) << "|";
+    oss << OSS::PadString(" Sobol' index", columnWidth) << "|";
+    oss << OSS::PadString(" Total index", columnWidth) << "|";
+    oss << Os::GetEndOfLine();
+    // print table dashes
+    oss << "|-------|"
+        << dashesSeparator << dashesSeparator << dashesSeparator << Os::GetEndOfLine();
     for (UnsignedInteger i = 0; i < inputDimension; ++ i)
     {
-      st = OSS() << std::setw(9) << i;
-      oss << st << " | ";
+      oss << "|" << std::setw(6) << i << " |";
 
-      st = OSS() << getSobolIndex(i, m);
-      oss << st << String(22 - st.size(), ' ') << " | ";
+      intermediateString = OSS() << " " << inputDescription[i];
+      oss << OSS::PadString(intermediateString, columnWidth) << "|";
 
-      st = OSS() << getSobolTotalIndex(i, m);
-      oss << st << String(22 - st.size(), ' ') << "\n";
-    }
-    oss << String(60, '-') << "\n";
-    oss << "\n";
-  }
+      intermediateString = OSS() << " " << getSobolIndex(i, m);
+      oss << OSS::PadString(intermediateString, columnWidth) << "|";
+
+      intermediateString = OSS() << " " << getSobolTotalIndex(i, m);
+      oss << OSS::PadString(intermediateString, columnWidth) << "|" << Os::GetEndOfLine();
+    } // Loop over the input marginals
+    oss << Os::GetEndOfLine();
+  } // Loop over the output marginals
   return oss;
 }
 
-/* Sobol index accessor */
-Scalar FunctionalChaosSobolIndices::getSobolIndex(const Indices & variableIndices,
+/* Sobol' index accessor */
+Scalar FunctionalChaosSobolIndices::getSobolIndex(const Indices & variablesGroup,
     const UnsignedInteger marginalIndex) const
 {
   const UnsignedInteger inputDimension = functionalChaosResult_.getDistribution().getDimension();
   const UnsignedInteger outputDimension = functionalChaosResult_.getMetaModel().getOutputDimension();
-  if (!variableIndices.check(inputDimension)) throw InvalidArgumentException(HERE) << "The variable indices of a Sobol indice must be in the range [0, dim-1] and must be different.";
+  if (!variablesGroup.check(inputDimension)) throw InvalidArgumentException(HERE) << "The variable indices of a Sobol' index must be in the range [0, dim-1] and must be different.";
   if (marginalIndex >= outputDimension) throw InvalidArgumentException(HERE) << "The marginal index must be in the range [0, dim-1].";
   // Check if the measure defining the basis has an independent copula else
   // the conditional covariance cannot be extracted from the decomposition
   if (!functionalChaosResult_.getOrthogonalBasis().getMeasure().hasIndependentCopula()) throw InternalException(HERE) << "Error: cannot compute Sobol indices from a non-tensorized basis.";
   if (!functionalChaosResult_.getDistribution().hasIndependentCopula()) LOGWARN(OSS(false) << "The Sobol indices are computed wrt the basis measure, and there is no one-to-one transformation between this measure and the input distribution. The interpretation of the indices may be misleading.");
-  const UnsignedInteger orderSobolIndice = variableIndices.getSize();
   const Sample coefficients(functionalChaosResult_.getCoefficients().getMarginal(marginalIndex));
   const Indices coefficientIndices(functionalChaosResult_.getIndices());
   const UnsignedInteger size = coefficients.getSize();
@@ -199,43 +192,55 @@ Scalar FunctionalChaosSobolIndices::getSobolIndex(const Indices & variableIndice
   const EnumerateFunction enumerateFunction(functionalChaosResult_.getOrthogonalBasis().getEnumerateFunction());
   // Sum the contributions of all the coefficients associated to a basis vector involving only the needed variables
   Scalar totalVariance = 0.0;
+  Bool mustInclude = false;
   for (UnsignedInteger i = 0; i < size; ++i)
   {
     if (coefficientIndices[i] > 0)
     {
       const Scalar coefficientI = coefficients(i, 0);
-      if (coefficientI != 0.0)
+      const Indices multiIndices(enumerateFunction(coefficientIndices[i]));
+      const UnsignedInteger normInf = multiIndices.normInf();
+      // Compute denominator
+      if (normInf > 0) totalVariance += coefficientI * coefficientI;
+      // Compute numerator
+      if (normInf == 0)
       {
-        Indices multiIndices(enumerateFunction(coefficientIndices[i]));
-        // Take into account only nonzero multi indices
-        if (*std::max_element(multiIndices.begin(), multiIndices.end()) > 0)
+        // Exclude the zero indices
+        mustInclude = false;
+      }
+      else
+      {
+        mustInclude = true;
+        for (UnsignedInteger variableIndex = 0; variableIndex < inputDimension; ++variableIndex)
         {
-          totalVariance += coefficientI * coefficientI;
-          Bool isProperSubset = true;
-          // First check that the exponents associated to the selected variables are > 0
-          for (UnsignedInteger j = 0; j < orderSobolIndice; ++j)
+          if (variablesGroup.contains(variableIndex))
           {
-            const UnsignedInteger varJ = variableIndices[j];
-            isProperSubset = isProperSubset && (multiIndices[varJ] > 0);
-            // We must set the value of the current variable index to 0 for the next test
-            multiIndices[varJ] = 0;
+            // Check that any variable in the group has a nonzero degree
+            if (multiIndices[variableIndex] == 0)
+            {
+              mustInclude = false;
+              break;
+            }
           }
-          // At this step, the current index could be associated to a function that does not involve all the variables
-          if (isProperSubset)
+          else
           {
-            // Second, check that the other coefficients are 0
-            if (*std::max_element(multiIndices.begin(), multiIndices.end()) == 0)
-              covarianceVariables += coefficientI * coefficientI;
+            // Check that any variable not in the group has a zero degree
+            if (multiIndices[variableIndex] > 0)
+            {
+              mustInclude = false;
+              break;
+            }
           }
-        } // *std::max_element(multiIndices.begin(), multiIndices.end())s > 0
-      } // if coefficientI <> 0
+        }
+      }
+      if (mustInclude) covarianceVariables += coefficientI * coefficientI;
     } // coefficientIndices[i] > 0
   } // Loop over the coefficients
   if (totalVariance > 0.0) return covarianceVariables / totalVariance;
   else return 0.0;
 }
 
-/* Sobol index accessor */
+/* Sobol' index accessor */
 Scalar FunctionalChaosSobolIndices::getSobolIndex(const UnsignedInteger variableIndex,
     const UnsignedInteger marginalIndex) const
 {
@@ -244,18 +249,18 @@ Scalar FunctionalChaosSobolIndices::getSobolIndex(const UnsignedInteger variable
 }
 
 /* Sobol total index accessor */
-Scalar FunctionalChaosSobolIndices::getSobolTotalIndex(const Indices & variableIndices,
+Scalar FunctionalChaosSobolIndices::getSobolTotalIndex(const Indices & variablesGroup,
     const UnsignedInteger marginalIndex) const
 {
   const UnsignedInteger inputDimension = functionalChaosResult_.getDistribution().getDimension();
   const UnsignedInteger outputDimension = functionalChaosResult_.getMetaModel().getOutputDimension();
-  if (!variableIndices.check(inputDimension)) throw InvalidArgumentException(HERE) << "The variable indices of a Sobol indice must be in the range [0, dim-1] and must be different.";
+  if (!variablesGroup.check(inputDimension)) throw InvalidArgumentException(HERE) << "The variable indices of a Sobol' index must be in the range [0, dim-1] and must be different.";
   if (marginalIndex >= outputDimension) throw InvalidArgumentException(HERE) << "The marginal index must be in the range [0, dim-1].";
   // Check if the measure defining the basis has an independent copula else
   // the conditional covariance cannot be extracted from the decomposition
   if (!functionalChaosResult_.getOrthogonalBasis().getMeasure().hasIndependentCopula()) throw InternalException(HERE) << "Error: cannot compute Sobol total indices from a non-tensorized basis.";
   if (!functionalChaosResult_.getDistribution().hasIndependentCopula()) LOGWARN(OSS(false) << "The Sobol total indices are computed wrt the basis measure, and there is no one-to-one transformation between this measure and the input distribution. The interpretation of the total indices may be misleading.");
-  const UnsignedInteger orderSobolIndice = variableIndices.getSize();
+  const UnsignedInteger groupDimension = variablesGroup.getSize();
   const Sample coefficients(functionalChaosResult_.getCoefficients().getMarginal(marginalIndex));
   const Indices coefficientIndices(functionalChaosResult_.getIndices());
   const UnsignedInteger size = coefficients.getSize();
@@ -272,18 +277,18 @@ Scalar FunctionalChaosSobolIndices::getSobolTotalIndex(const Indices & variableI
       {
         const Indices multiIndices(enumerateFunction(coefficientIndices[i]));
         // Take into account only nonzero multi indices
-        if (*std::max_element(multiIndices.begin(), multiIndices.end()) > 0)
+        if (multiIndices.normInf() > 0)
         {
           totalVariance += coefficientI * coefficientI;
           Bool isProperSubset = true;
           // Check that the exponents associated to the selected variables are > 0
-          for (UnsignedInteger j = 0; j < orderSobolIndice; ++j)
+          for (UnsignedInteger j = 0; j < groupDimension; ++j)
           {
-            const UnsignedInteger varJ = variableIndices[j];
+            const UnsignedInteger varJ = variablesGroup[j];
             isProperSubset = isProperSubset && (multiIndices[varJ] > 0);
           }
           if (isProperSubset) covarianceVariables += coefficientI * coefficientI;
-        } // *std::max_element(multiIndices.begin(), multiIndices.end()) > 0
+        } // multiIndices.normInf() > 0
       } // if coefficientI <> 0
     } // coefficientIndices[i] > 0
   } // Loop over the coefficients
@@ -300,18 +305,17 @@ Scalar FunctionalChaosSobolIndices::getSobolTotalIndex(const UnsignedInteger var
 }
 
 /* Sobol grouped (first order) index accessor */
-Scalar FunctionalChaosSobolIndices::getSobolGroupedIndex(const Indices & variableIndices,
+Scalar FunctionalChaosSobolIndices::getSobolGroupedIndex(const Indices & variablesGroup,
     const UnsignedInteger marginalIndex) const
 {
   const UnsignedInteger inputDimension = functionalChaosResult_.getDistribution().getDimension();
   const UnsignedInteger outputDimension = functionalChaosResult_.getMetaModel().getOutputDimension();
-  if (!variableIndices.check(inputDimension)) throw InvalidArgumentException(HERE) << "The variable indices of a Sobol indice must be in the range [0, dim-1] and must be different.";
+  if (!variablesGroup.check(inputDimension)) throw InvalidArgumentException(HERE) << "The variable indices of a Sobol' index must be in the range [0, dim-1] and must be different.";
   if (marginalIndex >= outputDimension) throw InvalidArgumentException(HERE) << "The marginal index must be in the range [0, dim-1].";
   // Check if the measure defining the basis has an independent copula else
   // the conditional covariance cannot be extracted from the decomposition
   if (!functionalChaosResult_.getOrthogonalBasis().getMeasure().hasIndependentCopula()) throw InternalException(HERE) << "Error: cannot compute Sobol indices from a non-tensorized basis.";
   if (!functionalChaosResult_.getDistribution().hasIndependentCopula()) LOGWARN(OSS(false) << "The Sobol indices are computed wrt the basis measure, and there is no one-to-one transformation between this measure and the input distribution. The interpretation of the indices may be misleading.");
-  const UnsignedInteger orderSobolIndice = variableIndices.getSize();
   const Sample coefficients(functionalChaosResult_.getCoefficients().getMarginal(marginalIndex));
   const Indices coefficientIndices(functionalChaosResult_.getIndices());
   const UnsignedInteger size = coefficients.getSize();
@@ -319,69 +323,131 @@ Scalar FunctionalChaosSobolIndices::getSobolGroupedIndex(const Indices & variabl
   const EnumerateFunction enumerateFunction(functionalChaosResult_.getOrthogonalBasis().getEnumerateFunction());
   // Sum the contributions of all the coefficients associated to a basis vector involving only the needed variables
   Scalar totalVariance = 0.0;
+  Bool mustInclude = false;
   for (UnsignedInteger i = 0; i < size; ++i)
   {
     if (coefficientIndices[i] > 0)
     {
       const Scalar coefficientI = coefficients(i, 0);
-      if (coefficientI != 0.0)
+      const Indices multiIndices(enumerateFunction(coefficientIndices[i]));
+      const UnsignedInteger normInf = multiIndices.normInf();
+      // Compute denominator
+      if (normInf > 0) totalVariance += coefficientI * coefficientI;
+      // Compute numerator
+      mustInclude = true;
+      if (normInf == 0)
       {
-        Indices multiIndices(enumerateFunction(coefficientIndices[i]));
-        // Take into account only nonzero multi indices
-        if (*std::max_element(multiIndices.begin(), multiIndices.end()) > 0)
+        // Exclude the zero indices
+        mustInclude = false;
+      }
+      else
+      {
+        for (UnsignedInteger variableIndex = 0; variableIndex < inputDimension; ++variableIndex)
         {
-          totalVariance += coefficientI * coefficientI;
-          // Set the exponents corresponding to the group to zero
-          for (UnsignedInteger j = 0; j < orderSobolIndice; ++j)
-            multiIndices[variableIndices[j]] = 0;
-          // Now check that all the indices are zero
-          if (*std::max_element(multiIndices.begin(), multiIndices.end()) == 0)
-            covarianceVariables += coefficientI * coefficientI;
-        } // *std::max_element(multiIndices.begin(), multiIndices.end()) > 0
-      } // if coefficientI <> 0
+          // Check that each variable having a nonzero degree is in the group
+          if (multiIndices[variableIndex] > 0 && ! variablesGroup.contains(variableIndex))
+          {
+            mustInclude = false;
+            break;
+          }
+        }
+      }
+      if (mustInclude) covarianceVariables += coefficientI * coefficientI;
     } // coefficientIndices[i] > 0
   } // Loop over the coefficients
   if (totalVariance > 0.0) return covarianceVariables / totalVariance;
   else return 0.0;
 }
 
-/* Sobol (first order) index accessor */
-Scalar FunctionalChaosSobolIndices::getSobolGroupedIndex(const UnsignedInteger variableIndex,
-    const UnsignedInteger marginalIndex) const
-{
-  LOGWARN(OSS() << "FunctionalChaosSobolIndices.getSobolGroupedIndex(int) is deprecated, use getSobolIndex");
-  const Indices index(1, variableIndex);
-  return getSobolGroupedIndex(index, marginalIndex);
-}
-
 /* Sobol grouped total index accessor */
-Scalar FunctionalChaosSobolIndices::getSobolGroupedTotalIndex(const Indices & variableIndices,
+Scalar FunctionalChaosSobolIndices::getSobolGroupedTotalIndex(const Indices & variablesGroup,
     const UnsignedInteger marginalIndex) const
 {
-  // Compute the complementary indice
   const UnsignedInteger inputDimension = functionalChaosResult_.getDistribution().getDimension();
-  if (!variableIndices.check(inputDimension)) throw InvalidArgumentException(HERE) << "The variable indices of a Sobol indice must be in the range [0, dim-1] and must be different.";
-  const Indices complementaryVariableIndices = variableIndices.complement(inputDimension);
-  // Compute total index from complementary first index
-  const Scalar complementaryFirstIndex = getSobolGroupedIndex(complementaryVariableIndices, marginalIndex);
-  const Scalar groupTotalIndex = 1.0 - complementaryFirstIndex;
-  return groupTotalIndex;
+  if (!variablesGroup.check(inputDimension)) throw InvalidArgumentException(HERE) << "The variable indices of a Sobol' index must be in the range [0, dim-1] and must be different.";
+  const Sample coefficients(functionalChaosResult_.getCoefficients().getMarginal(marginalIndex));
+  const Indices coefficientIndices(functionalChaosResult_.getIndices());
+  const UnsignedInteger size = coefficients.getSize();
+  Scalar covarianceVariables = 0.0;
+  const EnumerateFunction enumerateFunction(functionalChaosResult_.getOrthogonalBasis().getEnumerateFunction());
+  // Sum the contributions of all the coefficients associated to a basis vector involving only the needed variables
+  Scalar totalVariance = 0.0;
+  const UnsignedInteger groupDimension = variablesGroup.getSize();
+  Bool mustInclude = false;
+  for (UnsignedInteger i = 0; i < size; ++i)
+  {
+    if (coefficientIndices[i] > 0)
+    {
+      const Scalar coefficientI = coefficients(i, 0);
+      const Indices multiIndices(enumerateFunction(coefficientIndices[i]));
+      const UnsignedInteger normInf = multiIndices.normInf();
+      // Compute denominator
+      if (normInf > 0) totalVariance += coefficientI * coefficientI;
+      // Compute numerator
+      if (normInf == 0)
+      {
+        // Exclude the zero indices
+        mustInclude = false;
+      }
+      else
+      {
+        mustInclude = false;
+        for (UnsignedInteger j = 0; j < groupDimension; ++j)
+        {
+          const UnsignedInteger variableIndex = variablesGroup[j];
+          // Check if any variable in the group has a nonzero degree
+          if (multiIndices[variableIndex] > 0)
+          {
+            mustInclude = true;
+            break;
+          }
+        }
+      }
+      if (mustInclude) covarianceVariables += coefficientI * coefficientI;
+    } // coefficientIndices[i] > 0
+  } // Loop over the coefficients
+  if (totalVariance > 0.0) return covarianceVariables / totalVariance;
+  else return 0.0;
 }
-/* Sobol total index accessor */
-Scalar FunctionalChaosSobolIndices::getSobolGroupedTotalIndex(const UnsignedInteger variableIndex,
-    const UnsignedInteger marginalIndex) const
-{
-  LOGWARN(OSS() << "FunctionalChaosSobolIndices.getSobolGroupedTotalIndex(int) is deprecated, use getSobolTotalIndex");
-  const Indices index(1, variableIndex);
-  return getSobolGroupedTotalIndex(index, marginalIndex);
-}
-
 /* Functional chaos result accessor */
 FunctionalChaosResult FunctionalChaosSobolIndices::getFunctionalChaosResult() const
 {
   return functionalChaosResult_;
 }
 
+/** Part of variance accessor */
+Point FunctionalChaosSobolIndices::getPartOfVariance(const UnsignedInteger marginalIndex) const
+{
+  const UnsignedInteger inputDimension = functionalChaosResult_.getDistribution().getDimension();
+  const UnsignedInteger outputDimension = functionalChaosResult_.getMetaModel().getOutputDimension();
+  if (marginalIndex >= outputDimension) throw InvalidArgumentException(HERE) << "The marginal index must be in the range [0, dim-1].";
+  // Check if the measure defining the basis has an independent copula else
+  // the conditional covariance cannot be extracted from the decomposition
+  if (!functionalChaosResult_.getOrthogonalBasis().getMeasure().hasIndependentCopula()) throw InternalException(HERE) << "Error: cannot compute Sobol indices from a non-tensorized basis.";
+  if (!functionalChaosResult_.getDistribution().hasIndependentCopula()) LOGWARN(OSS(false) << "The Sobol indices are computed wrt the basis measure, and there is no one-to-one transformation between this measure and the input distribution. The interpretation of the indices may be misleading.");
+  const Indices indices(functionalChaosResult_.getIndices());
+  const Sample coefficients(functionalChaosResult_.getCoefficients());
+  const UnsignedInteger basisSize = indices.getSize();
+  const EnumerateFunction enumerateFunction(functionalChaosResult_.getOrthogonalBasis().getEnumerateFunction());
+
+  // compute the variance
+  const FunctionalChaosRandomVector fcRandomVector(functionalChaosResult_);
+  const CovarianceMatrix covarianceMatrix = fcRandomVector.getCovariance();
+  const Scalar variance = covarianceMatrix(marginalIndex, marginalIndex);
+  Point partOfVariance(basisSize);
+  // compute part of contribution of each multi-index
+  for (UnsignedInteger i = 0; i < basisSize; ++ i)
+  {
+    const Scalar coefI = coefficients(i, marginalIndex);
+    const UnsignedInteger rankIndex = indices[i];
+    const Indices multiIndices(enumerateFunction(rankIndex));
+    UnsignedInteger totalDegree = 0;
+    for (UnsignedInteger j = 0; j < inputDimension; ++j) totalDegree += multiIndices[j];
+    if (totalDegree > 0) partOfVariance[i] = coefI * coefI / variance;
+  } // Loop over the multi-indices
+  return partOfVariance;
+}
+
 /* Method save() stores the object through the StorageManager */
 void FunctionalChaosSobolIndices::save(Advocate & adv) const
 {
