@@ -2,7 +2,7 @@
 /**
  *  @brief The class builds generalized linear models
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -37,7 +37,8 @@
 #endif
 #include "openturns/IdentityFunction.hxx"
 #include "openturns/ComposedFunction.hxx"
-#include "openturns/DualLinearCombinationFunction.hxx"
+#include "openturns/LinearCombinationFunction.hxx"
+#include "openturns/AggregatedFunction.hxx"
 #include "openturns/MemoizeFunction.hxx"
 #include "openturns/MultiStart.hxx"
 
@@ -58,7 +59,7 @@ GeneralLinearModelAlgorithm::GeneralLinearModelAlgorithm()
   , rho_(0)
   , F_(0, 0)
   , result_()
-  , basisCollection_()
+  , basis_()
   , covarianceCholeskyFactor_()
   , covarianceCholeskyFactorHMatrix_()
   , optimizeParameters_(true)
@@ -84,7 +85,7 @@ GeneralLinearModelAlgorithm::GeneralLinearModelAlgorithm(const Sample & inputSam
   , rho_(0)
   , F_(0, 0)
   , result_()
-  , basisCollection_()
+  , basis_()
   , covarianceCholeskyFactor_()
   , covarianceCholeskyFactorHMatrix_()
   , keepCholeskyFactor_(keepCholeskyFactor)
@@ -115,7 +116,7 @@ GeneralLinearModelAlgorithm::GeneralLinearModelAlgorithm(const Sample & inputSam
   , rho_(0)
   , F_(0, 0)
   , result_()
-  , basisCollection_()
+  , basis_()
   , covarianceCholeskyFactor_()
   , covarianceCholeskyFactorHMatrix_()
   , keepCholeskyFactor_(keepCholeskyFactor)
@@ -127,52 +128,10 @@ GeneralLinearModelAlgorithm::GeneralLinearModelAlgorithm(const Sample & inputSam
   setCovarianceModel(covarianceModel);
 
   if (basis.getSize() > 0)
-  {
-    if (basis[0].getOutputDimension() > 1) LOGWARN(OSS() << "Expected a basis of scalar functions, but first function has dimension " << basis[0].getOutputDimension() << ". Only the first output component will be taken into account.");
-    if (outputSample.getDimension() > 1) LOGWARN(OSS() << "The basis of functions will be applied to all output marginals" );
-    // Set basis
-    basisCollection_ = BasisCollection(outputSample.getDimension(), basis);
-  }
+    setBasis(basis);
   else
-  {
     // If no basis then we suppose output sample centered
     checkYCentered(outputSample);
-  }
-
-  initializeMethod();
-  initializeDefaultOptimizationAlgorithm();
-}
-
-
-/* Parameters constructor */
-GeneralLinearModelAlgorithm::GeneralLinearModelAlgorithm(const Sample & inputSample,
-    const Sample & outputSample,
-    const CovarianceModel & covarianceModel,
-    const BasisCollection & basisCollection,
-    const Bool keepCholeskyFactor)
-  : MetaModelAlgorithm(inputSample, outputSample)
-  , covarianceModel_()
-  , reducedCovarianceModel_()
-  , solver_()
-  , optimizationBounds_()
-  , beta_(0)
-  , rho_(0)
-  , F_(0, 0)
-  , result_()
-  , basisCollection_()
-  , covarianceCholeskyFactor_()
-  , covarianceCholeskyFactorHMatrix_()
-  , keepCholeskyFactor_(keepCholeskyFactor)
-  , optimizeParameters_(ResourceMap::GetAsBool("GeneralLinearModelAlgorithm-OptimizeParameters"))
-  , analyticalAmplitude_(false)
-  , lastReducedLogLikelihood_(SpecFunc::LowestScalar)
-{
-  LOGWARN(OSS() << "GeneralLinearModelAlgorithm(inputSample, outpuSample, covarianceModel, basisCollection, keepCholeskyFactor) is deprecated");
-  // Set covariance model
-  setCovarianceModel(covarianceModel);
-
-  // Set basis collection
-  if (basisCollection.getSize() > 0) setBasisCollection(basisCollection);
 
   initializeMethod();
   initializeDefaultOptimizationAlgorithm();
@@ -214,7 +173,7 @@ void GeneralLinearModelAlgorithm::setCovarianceModel(const CovarianceModel & cov
           // Here we have to change the current value of the amplitude as it has
           // to be equal to 1 during the potential optimization step in order for
           // the analytical formula to be correct.
-          // Now, the amplitude has disapear form the active parameters so it must
+          // Now, the amplitude has disappear form the active parameters so it must
           // be updated using the amplitude accessor.
           reducedCovarianceModel_.setAmplitude(Point(1, 1.0));
           break;
@@ -242,8 +201,15 @@ void GeneralLinearModelAlgorithm::setCovarianceModel(const CovarianceModel & cov
     }
     if (isScaleActive)
     {
-      const Point inputSampleRange(inputSample_.getMax() - inputSample_.getMin());
-      for (UnsignedInteger k = 0; k < reducedCovarianceModel_.getScale().getSize(); ++k) upperBound[k] = inputSampleRange[k] * scaleFactor;
+      const Point inputSampleRange(inputSample_.computeRange());
+      for (UnsignedInteger k = 0; k < reducedCovarianceModel_.getScale().getSize(); ++k)
+      {
+        upperBound[k] = inputSampleRange[k] * scaleFactor;
+        if (upperBound[k] < lowerBound[k])
+        {
+          upperBound[k] += lowerBound[k];
+        }
+      }
     }
     LOGWARN(OSS() <<  "Warning! For coherency we set scale upper bounds = " << upperBound.__str__());
 
@@ -262,35 +228,24 @@ CovarianceModel GeneralLinearModelAlgorithm::getReducedCovarianceModel() const
   return reducedCovarianceModel_;
 }
 
-/* Set basis collection method */
-void GeneralLinearModelAlgorithm::setBasisCollection(const BasisCollection & basis)
+/* Set basis method */
+void GeneralLinearModelAlgorithm::setBasis(const Basis & basis)
 {
-  // If basis given, then its size should be the same as the output dimension (each marginal of multibasis is a basis that will be used for trend of the corresponding marginal.
-  if (basis.getSize() != outputSample_.getDimension())
-    throw InvalidArgumentException(HERE) << "In GeneralLinearModelAlgorithm::GeneralLinearModelAlgorithm, output sample dimension=" << outputSample_.getDimension()  << " does not match multi-basis dimension=" << basis.getSize();
-  // Get the output dimension of the basis
-  // The first marginal may be an empty basis
-  Bool continuationCondition = true;
-  UnsignedInteger index = 0;
-  UnsignedInteger outputDimension = 0;
-  while(continuationCondition)
+  // Basis does not provide any getOutputDimension
+  // getDimension checks also only the dimension of the first element in case of FiniteBasis
+  // If basis given, then its size should be the same as the output dimension (each item of the basis is a function with the same input/output dimensions).
+  if (!basis.isFinite())
+    throw InvalidArgumentException(HERE) << "In GeneralLinearModelAlgorithm::GeneralLinearModelAlgorithm, basis should be finite!" ;
+  const UnsignedInteger size = basis.getSize();
+  for (UnsignedInteger index = 0; index < size; ++index)
   {
-    try
-    {
-      outputDimension =  basis[index][0].getOutputDimension();
-      continuationCondition = false;
-    }
-    catch (const InvalidArgumentException &)
-    {
-      ++index;
-      continuationCondition = continuationCondition && index < basis.getSize();
-    }
+    if (basis[index].getOutputDimension() != outputSample_.getDimension())
+      throw InvalidArgumentException(HERE) << "In GeneralLinearModelAlgorithm::GeneralLinearModelAlgorithm, output sample dimension=" << outputSample_.getDimension() << " does not match basis[=" << index  << "] dimension=" << basis[index].getOutputDimension();
+    if (basis[index].getInputDimension() != inputSample_.getDimension())
+      throw InvalidArgumentException(HERE) << "In GeneralLinearModelAlgorithm::GeneralLinearModelAlgorithm, input sample dimension=" << inputSample_.getDimension() << " does not match basis[=" << index << "] dimension=" << basis[index].getInputDimension();
   }
-  if (outputDimension == 0)
-    throw InvalidArgumentException(HERE) << "In GeneralLinearModelAlgorithm::GeneralLinearModelAlgorithm, basisCollection argument contains basis with empty collection of functions";
-  if (outputDimension > 1) LOGWARN(OSS() << "Expected a basis of scalar functions, but some function has dimension" << outputDimension << ". Only the first output component will be taken into account.");
   // Everything is ok, we set the basis
-  basisCollection_ = basis;
+  basis_ = basis;
 }
 
 void GeneralLinearModelAlgorithm::checkYCentered(const Sample & Y)
@@ -333,29 +288,27 @@ void GeneralLinearModelAlgorithm::computeF()
   // of corresponding marginal
   const UnsignedInteger outputDimension = outputSample_.getDimension();
   const UnsignedInteger sampleSize = inputSample_.getSize();
-  const UnsignedInteger basisCollectionSize = basisCollection_.getSize();
-  UnsignedInteger totalSize = 0;
-  for (UnsignedInteger i = 0; i < basisCollectionSize; ++ i ) totalSize += basisCollection_[i].getSize();
-  // if totalSize > 0, then basisCollection_.getSize() should be equal to outputDimension
-  // This is checked in GeneralLinearModelAlgorithm::GeneralLinearModelAlgorithm
+  const UnsignedInteger basisSize = basis_.getSize();
+  // Basis \Phi is a function from R^{inputDimension} to R^{outputDimension}
+  // As we get B functions, total number of values is B * outputDimension
+  const UnsignedInteger totalSize = outputDimension * basisSize;
+
   F_ = Matrix(sampleSize * outputDimension, totalSize);
   if (totalSize == 0) return;
+
   // Compute F
-  UnsignedInteger index = 0;
-  for (UnsignedInteger outputMarginal = 0; outputMarginal < outputDimension; ++ outputMarginal )
+  for (UnsignedInteger j = 0; j < basisSize; ++j)
   {
-    const Basis localBasis = basisCollection_[outputMarginal];
-    const UnsignedInteger localBasisSize = localBasis.getSize();
-    for (UnsignedInteger j = 0; j < localBasisSize; ++j, ++index )
-    {
-      // Here we use potential parallelism in the evaluation of the basis functions
-      const Sample basisSample = localBasis[j](inputSample_);
-      for (UnsignedInteger i = 0; i < sampleSize; ++i) F_(outputMarginal + i * outputDimension, index) = basisSample(i, 0);
-    }
+    // Compute phi_j (X)
+    // Here we use potential parallelism in the evaluation of the basis functions
+    // It generates a sample of shape (sampleSize, outputDimension)
+    const Sample basisSample = basis_[j](inputSample_);
+    for (UnsignedInteger i = 0; i < sampleSize; ++i)
+      for (UnsignedInteger outputMarginal = 0; outputMarginal < outputDimension; ++outputMarginal)
+        F_(outputMarginal + i * outputDimension, j * outputDimension + outputMarginal) = basisSample(i, outputMarginal);
   }
 }
 
-
 /* Perform regression
 1) Compute the design matrix
 2) Call the parameters optimization
@@ -388,7 +341,7 @@ void GeneralLinearModelAlgorithm::run()
   //   maximizeReducedLogLikelihood()
   // + even if there is actually no parameter to optimize,
   //   maximizeReducedLogLikelihood() is the entry point to
-  //   computeReducedLogLikelyhood() which has side effects on covariance
+  //   computeReducedLogLikelihood() which has side effects on covariance
   //   discretization and factorization, and it computes beta_
   Scalar optimalLogLikelihood = maximizeReducedLogLikelihood();
 
@@ -396,45 +349,33 @@ void GeneralLinearModelAlgorithm::run()
   // Here we do the work twice:
   // 1) To get a collection of Point for the result class
   // 2) To get same results as Sample for the trend NMF
-  Collection<Point> trendCoefficients(basisCollection_.getSize());
-  Sample trendCoefficientsSample(beta_.getSize(), reducedCovarianceModel_.getOutputDimension());
-
-  UnsignedInteger cumulatedSize = 0;
-  for (UnsignedInteger outputIndex = 0; outputIndex < basisCollection_.getSize(); ++ outputIndex)
-  {
-    const UnsignedInteger localBasisSize = basisCollection_[outputIndex].getSize();
-    Point beta_i(localBasisSize);
-    for(UnsignedInteger basisElement = 0; basisElement < localBasisSize; ++ basisElement)
-    {
-      beta_i[basisElement] = beta_[cumulatedSize];
-      trendCoefficientsSample(cumulatedSize, outputIndex) =  beta_[cumulatedSize];
-      ++cumulatedSize;
-    }
-    trendCoefficients[outputIndex] = beta_i;
-  }
-
   LOGINFO("Build the output meta-model");
-  // The meta model is of type DualLinearCombination function
-  // We should write the coefficients into a Sample and build the basis into a collection
-  Collection<Function> allFunctionsCollection;
-  for (UnsignedInteger k = 0; k < basisCollection_.getSize(); ++k)
-    for (UnsignedInteger l = 0; l < basisCollection_[k].getSize(); ++l)
-      allFunctionsCollection.add(basisCollection_[k].build(l));
+  Collection<Function> marginalCollections(basis_.getSize());
+  Collection<Function> marginalFunctions(outputDimension);
+  Point beta_k(basis_.getSize());
+
   Function metaModel;
 
-  if (basisCollection_.getSize() > 0)
+  if (basis_.getSize() > 0)
   {
+    for (UnsignedInteger outputMarginal = 0; outputMarginal < outputDimension; ++outputMarginal)
+    {
+      for (UnsignedInteger k = 0; k < basis_.getSize(); ++k)
+      {
+        marginalCollections[k] = basis_[k].getMarginal(outputMarginal);
+        beta_k[k] = beta_[k * outputDimension + outputMarginal];
+      }
+      LinearCombinationFunction marginalFunction(marginalCollections, beta_k);
+      marginalFunctions[outputMarginal] = marginalFunction;
+    }
+
     // Care ! collection should be non empty
-    metaModel = DualLinearCombinationFunction(allFunctionsCollection, trendCoefficientsSample);
+    metaModel = AggregatedFunction(marginalFunctions);
   }
   else
   {
     // If no basis ==> zero function
-#ifdef OPENTURNS_HAVE_ANALYTICAL_PARSER
     metaModel = SymbolicFunction(Description::BuildDefault(covarianceModel_.getInputDimension(), "x"), Description(covarianceModel_.getOutputDimension(), "0.0"));
-#else
-    metaModel = DatabaseFunction(Sample(1, reducedCovarianceModel_.getInputDimension()), Sample(1, reducedCovarianceModel_.getOutputDimension()));
-#endif
   }
 
   // compute residual, relative error
@@ -456,7 +397,7 @@ void GeneralLinearModelAlgorithm::run()
   CovarianceModel reducedCovarianceModelCopy(reducedCovarianceModel_);
   reducedCovarianceModelCopy.setActiveParameter(covarianceModel_.getActiveParameter());
 
-  result_ = GeneralLinearModelResult(inputSample_, outputSample_, metaModel, residuals, relativeErrors, basisCollection_, trendCoefficients, reducedCovarianceModelCopy, optimalLogLikelihood);
+  result_ = GeneralLinearModelResult(inputSample_, outputSample_, metaModel, residuals, relativeErrors, basis_, beta_, reducedCovarianceModelCopy, optimalLogLikelihood);
 
   // The scaling is done there because it has to be done as soon as some optimization has been done, either numerically or through an analytical formula
   if (keepCholeskyFactor_)
@@ -471,7 +412,7 @@ void GeneralLinearModelAlgorithm::run()
     result_.setCholeskyFactor(covarianceCholeskyFactor_, covarianceCholeskyFactorHMatrix_);
   }
   else
-    result_ = GeneralLinearModelResult(inputSample_, outputSample_, metaModel, residuals, relativeErrors, basisCollection_, trendCoefficients, reducedCovarianceModelCopy, optimalLogLikelihood);
+    result_ = GeneralLinearModelResult(inputSample_, outputSample_, metaModel, residuals, relativeErrors, basis_, beta_, reducedCovarianceModelCopy, optimalLogLikelihood);
   hasRun_ = true;
 }
 
@@ -601,45 +542,9 @@ Scalar GeneralLinearModelAlgorithm::computeLapackLogDeterminantCholesky() const
   }
   if (C.getDimension() < 20)
     LOGDEBUG(OSS(false) << "C=\n" << C);
+
   LOGDEBUG("Compute the Cholesky factor of the covariance matrix");
-  Bool continuationCondition = true;
-  Scalar maxEV = -1.0;
-  const Scalar startingScaling = ResourceMap::GetAsScalar("GeneralLinearModelAlgorithm-StartingScaling");
-  const Scalar maximalScaling = ResourceMap::GetAsScalar("GeneralLinearModelAlgorithm-MaximalScaling");
-  Scalar cumulatedScaling = 0.0;
-  Scalar scaling = startingScaling;
-  while (continuationCondition)
-  {
-    try
-    {
-      covarianceCholeskyFactor_ = C.computeCholesky();
-      continuationCondition = false;
-    }
-    // If the factorization failed regularize the matrix
-    // Here we use a generic exception as different exceptions may be thrown
-    catch (const Exception &)
-    {
-      // If the largest eigenvalue module has not been computed yet...
-      if (maxEV < 0.0)
-      {
-        maxEV = C.computeLargestEigenValueModule();
-        LOGDEBUG(OSS() << "maxEV=" << maxEV);
-        scaling *= maxEV;
-      }
-      cumulatedScaling += scaling ;
-      LOGDEBUG(OSS() << "scaling=" << scaling << ", cumulatedScaling=" << cumulatedScaling);
-      // Unroll the regularization to optimize the computation
-      for (UnsignedInteger i = 0; i < C.getDimension(); ++i) C(i, i) += scaling;
-      scaling *= 2.0;
-      continuationCondition = scaling < maxEV * maximalScaling;
-    }
-  }
-  if (maxEV > 0.0 && scaling >= maximalScaling * maxEV)
-    throw InvalidArgumentException(HERE) << "In GeneralLinearModelAlgorithm::computeLapackLogDeterminantCholesky, could not compute the Cholesky factor."
-                                         << " Scaling up to "  << cumulatedScaling << " was not enough";
-  if (cumulatedScaling > 0.0)
-    LOGWARN(OSS() <<  "Warning! Scaling up to "  << cumulatedScaling << " was needed in order to get an admissible covariance. ");
-  LOGDEBUG(OSS(false) << "L=\n" << covarianceCholeskyFactor_);
+  covarianceCholeskyFactor_ = C.computeRegularizedCholesky();
 
   // y corresponds to output data
   const Point y(outputSample_.getImplementation()->getData());
@@ -649,7 +554,7 @@ Scalar GeneralLinearModelAlgorithm::computeLapackLogDeterminantCholesky() const
   rho_ = covarianceCholeskyFactor_.solveLinearSystem(y);
   LOGDEBUG(OSS(false) << "rho_=L^{-1}y=" << rho_);
   // If trend to estimate
-  if (basisCollection_.getSize() > 0)
+  if (basis_.getSize() > 0)
   {
     // Phi = L^{-1}F
     LOGDEBUG("Solve L.Phi = F");
@@ -705,7 +610,7 @@ Scalar GeneralLinearModelAlgorithm::computeHMatLogDeterminantCholesky() const
   LOGDEBUG("Solve L.rho = y");
   rho_ = covarianceCholeskyFactorHMatrix_.solveLower(y);
   // If trend to estimate
-  if (basisCollection_.getSize() > 0)
+  if (basis_.getSize() > 0)
   {
     // Phi = L^{-1}F
     LOGDEBUG("Solve L.Phi = F");
@@ -801,7 +706,7 @@ String GeneralLinearModelAlgorithm::__repr__() const
   oss << "class=" << getClassName()
       << ", inputSample=" << inputSample_
       << ", outputSample=" << outputSample_
-      << ", basis=" << basisCollection_
+      << ", basis=" << basis_
       << ", covarianceModel=" << covarianceModel_
       << ", reducedCovarianceModel=" << reducedCovarianceModel_
       << ", solver=" << solver_
@@ -843,7 +748,7 @@ UnsignedInteger GeneralLinearModelAlgorithm::getMethod() const
 void GeneralLinearModelAlgorithm::reset()
 {
   // Reset elements for new computation
-  // No need to update F_ as computeF /setBasisCollection are private
+  // No need to update F_ as computeF /setBasis are private
   // Same remark for setCovarianceModel & setData
   covarianceCholeskyFactor_ = TriangularMatrix();
   covarianceCholeskyFactorHMatrix_ = HMatrix();
@@ -874,7 +779,7 @@ void GeneralLinearModelAlgorithm::save(Advocate & adv) const
   adv.saveAttribute( "reducedCovarianceModel_", reducedCovarianceModel_ );
   adv.saveAttribute( "solver_", solver_ );
   adv.saveAttribute( "optimizationBounds_", optimizationBounds_ );
-  adv.saveAttribute( "basisCollection_", basisCollection_ );
+  adv.saveAttribute( "basis_", basis_ );
   adv.saveAttribute( "result_", result_ );
   adv.saveAttribute( "method", method_ );
   adv.saveAttribute( "keepCholeskyFactor_", keepCholeskyFactor_ );
@@ -892,7 +797,7 @@ void GeneralLinearModelAlgorithm::load(Advocate & adv)
   adv.loadAttribute( "reducedCovarianceModel_", reducedCovarianceModel_ );
   adv.loadAttribute( "solver_", solver_ );
   adv.loadAttribute( "optimizationBounds_", optimizationBounds_ );
-  adv.loadAttribute( "basisCollection_", basisCollection_ );
+  adv.loadAttribute( "basis_", basis_ );
   adv.loadAttribute( "result_", result_ );
   adv.loadAttribute( "method", method_ );
   adv.loadAttribute( "keepCholeskyFactor_", keepCholeskyFactor_ );
