@@ -2,7 +2,7 @@
 /**
  *  @brief The class building gaussian process regression
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -21,6 +21,7 @@
 
 #include "openturns/KrigingGradient.hxx"
 #include "openturns/PersistentObjectFactory.hxx"
+#include "openturns/AggregatedFunction.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -44,10 +45,10 @@ KrigingGradient::KrigingGradient()
 
 
 /* Constructor with parameters */
-KrigingGradient::KrigingGradient(const BasisCollection & basis,
+KrigingGradient::KrigingGradient(const Basis & basis,
                                  const Sample & inputSample,
                                  const CovarianceModel & covarianceModel,
-                                 const PointCollection & beta,
+                                 const Point & beta,
                                  const Sample & gamma)
   : GradientImplementation()
   , basis_(basis)
@@ -56,12 +57,19 @@ KrigingGradient::KrigingGradient(const BasisCollection & basis,
   , beta_(beta)
   , gamma_(gamma)
 {
-  if (basis.getSize() > 0)
+
+  if (!basis.isFinite())
+    throw InvalidArgumentException(HERE) << "In KrigingGradient::KrigingGradient, basis should be finite!";
+  const UnsignedInteger size = basis.getSize();
+  for (UnsignedInteger index = 0; index < size; ++index)
   {
-    if (basis.getSize() != covarianceModel.getOutputDimension())
-      throw InvalidArgumentException(HERE) << "In KrigingGradient::KrigingGradient, output sample dimension (" << covarianceModel.getOutputDimension()  << ") does not match multi-basis dimension (" << basis_.getSize() << ")";
+    if (basis[index].getOutputDimension() != covarianceModel.getOutputDimension())
+      throw InvalidArgumentException(HERE) << "In KrigingGradient::KrigingGradient, output sample dimension=" << covarianceModel.getOutputDimension() << " does not match basis[=" << index << "] dimension=" << basis[index].getOutputDimension();
+    if (basis[index].getInputDimension() != inputSample_.getDimension())
+      throw InvalidArgumentException(HERE) << "In KrigingGradient::KrigingGradient, input sample dimension=" << inputSample_.getDimension() << " does not match basis[=" << index << "] dimension=" << basis[index].getInputDimension();
   }
-  if (covarianceModel.getInputDimension() != inputSample.getDimension()) throw InvalidArgumentException(HERE) << "In KrigingGradient::KrigingGradient, error: the input dimension=" << covarianceModel.getInputDimension() << " of the covariance model should match the dimension=" << inputSample.getDimension() << " of the input sample";
+  if (covarianceModel.getInputDimension() != inputSample.getDimension())
+    throw InvalidArgumentException(HERE) << "In KrigingGradient::KrigingGradient, error: the input dimension=" << covarianceModel.getInputDimension() << " of the covariance model should match the dimension=" << inputSample.getDimension() << " of the input sample";
   if (gamma.getSize() != inputSample.getSize()) throw InvalidArgumentException(HERE) << "In KrigingGradient::KrigingGradient, error: the number of covariance coefficients=" << gamma.getSize() << " is different from the output sample dimension=" << covarianceModel.getOutputDimension();
   setParameter(Point(getInputDimension()));
 }
@@ -126,23 +134,13 @@ Matrix KrigingGradient::gradient(const Point & inP) const
   }
 
   // trend part
-  const UnsignedInteger basisSize = basis_.getSize();
-
-  // Evaluate the basis part sequentially
   // Number of basis is 0 or outputDimension
-  for (UnsignedInteger i = 0; i < basisSize; ++i)
+  for (UnsignedInteger k = 0; k < basis_.getSize(); ++k)
   {
-    // Get local basis -> basis_[i]
-    const Basis localBasis(basis_[i]);
-    const Point betaBasis(beta_[i]);
-    const UnsignedInteger localBasisSize = localBasis.getSize();
-    // For the i-th Basis (marginal), take into account the trend
-    // We write explicitly the linear combination instead of using a LinearCombinationGradient
-    for (UnsignedInteger j = 0; j < localBasisSize; ++j)
-    {
-      const Matrix gradient_bj(localBasis[j].gradient(inP) * betaBasis[j]);
-      for (UnsignedInteger k = 0; k < p; ++k) result(k, i) += gradient_bj(k, 0);
-    }
+    const Matrix gradient_bk(basis_[k].gradient(inP));
+    for (UnsignedInteger j = 0; j < dimension; ++j)
+      for (UnsignedInteger i = 0; i < p; ++i)
+        result(i, j) += gradient_bk(i, j) * beta_[k * dimension + j];
   }
 
   // update calls number
@@ -178,11 +176,51 @@ void KrigingGradient::save(Advocate & adv) const
 void KrigingGradient::load(Advocate & adv)
 {
   GradientImplementation::load(adv);
-  adv.loadAttribute("basis_", basis_);
   adv.loadAttribute("inputSample_", inputSample_);
   adv.loadAttribute("covarianceModel_", covarianceModel_);
-  adv.loadAttribute("beta_", beta_);
   adv.loadAttribute("gamma_", gamma_);
+  if (adv.getStudyVersion() >= 102100)
+  {
+    adv.loadAttribute("basis_", basis_);
+    adv.loadAttribute("beta_", beta_);
+  }
+  else
+  {
+    // Backward load method
+    // Here the implementation suggests that we rely on a collection of Basis and Point
+    // Partially compatible with new implementation : we should have here the basis of
+    // same size
+    PersistentCollection<Basis> basis;
+    PersistentCollection<Point> beta;
+    adv.loadAttribute("basis_", basis);
+    adv.loadAttribute("beta_", beta);
+    if (basis.getSize() != covarianceModel_.getOutputDimension())
+      throw InvalidArgumentException(HERE) << "Collection size differ from covariance model output dimension. Collection size="
+                                           << basis.getSize() << " whereas covariance model output dimension = " << covarianceModel_.getOutputDimension();
+    const UnsignedInteger basisSize = basis[0].getSize();
+    for (UnsignedInteger outputMarginalIndex = 1; outputMarginalIndex < basis.getSize(); ++outputMarginalIndex)
+    {
+      if (basis[outputMarginalIndex].getSize() != basisSize)
+        throw InvalidArgumentException(HERE) << "With new implementation, we should have all basis of same size. Here, basis[0].size = " << basisSize
+                                             << " whereas basis[" << outputMarginalIndex << "].size = " << basis[outputMarginalIndex].getSize();
+    }
+    // Now we convert the persistent collection of Basis/Point into a standard multivariate Basis
+    beta_ = Point(basisSize * basis.getSize());
+    Collection<Function> marginalCollection(covarianceModel_.getOutputDimension());
+    Collection<Function> phi(basisSize);
+    UnsignedInteger index = 0;
+
+    for (UnsignedInteger j = 0; j < basisSize; ++j)
+    {
+      for (UnsignedInteger outputMarginalIndex = 0; outputMarginalIndex < basis.getSize(); ++outputMarginalIndex)
+      {
+        marginalCollection[outputMarginalIndex] = basis[outputMarginalIndex].build(j);
+        beta_[index] = beta[outputMarginalIndex][j];
+      }
+      phi[j] = AggregatedFunction(marginalCollection);
+    }
+    basis_ = Basis(phi);
+  } // else
 }
 
 
