@@ -2,7 +2,7 @@
 /**
  *  @brief LinearModelAlgorithm implements the linear model
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -49,8 +49,10 @@ LinearModelAlgorithm::LinearModelAlgorithm(const Sample & inputSample,
   if (inputSample.getSize() != outputSample.getSize())
     throw InvalidArgumentException(HERE) << "In LinearModelAlgorithm::LinearModelAlgorithm, input sample size (" << inputSample.getSize() << ") does not match output sample size (" << outputSample.getSize() << ").";
 
+  if (outputSample.getDimension() != 1)
+    throw InvalidArgumentException(HERE) << "LinearModelAlgorithm can only handle and 1-d output sample.";
+
   const UnsignedInteger inputDimension = inputSample_.getDimension();
-#ifdef OPENTURNS_HAVE_ANALYTICAL_PARSER
   Collection<Function> functions;
   Description inputDescription(inputSample_.getDescription());
   try
@@ -69,9 +71,6 @@ LinearModelAlgorithm::LinearModelAlgorithm(const Sample & inputSample,
     functions.add(SymbolicFunction(inputDescription, Description(1, inputDescription[i])));
   }
   basis_ = Basis(functions);
-#else
-  basis_ = LinearBasisFactory(inputDimension).build();
-#endif
 }
 
 
@@ -86,15 +85,6 @@ LinearModelAlgorithm::LinearModelAlgorithm(const Sample & inputSample,
   basis_ = basis;
 }
 
-/** Oldest constructor (for compatibility) */
-LinearModelAlgorithm::LinearModelAlgorithm(const Sample &inputSample,
-    const Basis &basis,
-    const Sample &outputSample)
-  : LinearModelAlgorithm(inputSample, outputSample, basis)
-{
-  LOGWARN(OSS() << "LinearModelAlgorithm(inputSample, basis, outpuSample) is deprecated");
-}
-
 /* Virtual constructor */
 LinearModelAlgorithm * LinearModelAlgorithm::clone() const
 {
