@@ -2,7 +2,7 @@
 /**
  *  @brief Stepwise algorithms for linear model
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -80,18 +80,6 @@ LinearModelStepwiseAlgorithm::LinearModelStepwiseAlgorithm(const Sample & inputS
     throw InvalidArgumentException(HERE) << "Can only specify startIndices in BOTH mode";
 }
 
-/** Oldest constructor (for compatibility) */
-LinearModelStepwiseAlgorithm::LinearModelStepwiseAlgorithm(const Sample &inputSample,
-    const Basis &basis,
-    const Sample &outputSample,
-    const Indices &minimalIndices,
-    const Direction direction,
-    const Indices &startIndices)
-  : LinearModelStepwiseAlgorithm(inputSample, outputSample, basis, minimalIndices, direction, startIndices)
-{
-  LOGWARN(OSS() << "LinearModelStepwiseAlgorithm(inputSample, basis, outputSample, minimalIndices, direction, startIndices) is deprecated");
-}
-
 /* Virtual constructor */
 LinearModelStepwiseAlgorithm * LinearModelStepwiseAlgorithm::clone() const
 {
@@ -614,8 +602,8 @@ Scalar LinearModelStepwiseAlgorithm::computeLogLikelihood()
   Matrix R;
   currentQ_ = currentX_.computeQR(R, size < p, true);
   const MatrixImplementation b(*IdentityMatrix(p).getImplementation());
-  //                                                     keep intact, lower, transposed
-  currentInvRt_ = R.getImplementation()->solveLinearSystemTri(b, false, false, true);
+  //                                                                    lower, transposed
+  currentInvRt_ = R.getImplementation()->solveLinearSystemTriInPlace(b, false, true);
 
   // residual = Y - Q*Q^T*Y
   const Matrix QtY = currentQ_.getImplementation()->genProd(*(Y_.getImplementation()), true, false);
