@@ -2,7 +2,7 @@
 /**
  *  @brief EfficientGlobalOptimization or EGO algorithm
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -237,7 +237,7 @@ void EfficientGlobalOptimization::run()
     Scalar optimalValueSubstitute = optimalValue;
     if (hasNoise)
     {
-      // with noisy objective we dont have access to the real current optimal value
+      // with noisy objective we don't have access to the real current optimal value
       // so consider a quantile of the kriging prediction: argmin_xi mk(xi) + c * sk(xi)
       optimalValueSubstitute = problem.isMinimization() ? SpecFunc::MaxScalar : SpecFunc::LowestScalar;
       const Sample mx(metaModelResult.getConditionalMean(inputSample));
@@ -399,7 +399,7 @@ void EfficientGlobalOptimization::run()
 
     if (evaluationNumber > 0)
     {
-      KrigingAlgorithm algo(inputSample, outputSample, metaModelResult.getCovarianceModel(), metaModelResult.getBasisCollection());
+      KrigingAlgorithm algo(inputSample, outputSample, metaModelResult.getCovarianceModel(), metaModelResult.getBasis());
       LOGINFO(OSS() << "Rebuilding kriging ...");
       algo.setOptimizeParameters((parameterEstimationPeriod_ > 0) && ((evaluationNumber % parameterEstimationPeriod_) == 0));
       if (hasNoise)
