@@ -2,7 +2,7 @@
 /**
  *  @brief OrthogonalUniVariatePolynomialStandardDistribution polynomial factory
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -271,6 +271,25 @@ String StandardDistributionPolynomialFactory::__repr__() const
   return oss;
 }
 
+/* hasSpecificFamily_ accessor */
+Bool StandardDistributionPolynomialFactory::getHasSpecificFamily() const
+{
+  return hasSpecificFamily_;
+}
+
+/** orthonormalizationAlgorithm_ accessor */
+OrthonormalizationAlgorithm StandardDistributionPolynomialFactory::getOrthonormalizationAlgorithm() const
+{
+  return orthonormalizationAlgorithm_;
+}
+
+/** specificFamily_ accessor */
+OrthogonalUniVariatePolynomialFamily StandardDistributionPolynomialFactory::getSpecificFamily() const
+{
+  return specificFamily_;
+}
+
+
 /* Method save() stores the object through the StorageManager */
 void StandardDistributionPolynomialFactory::save(Advocate & adv) const
 {
