@@ -2,7 +2,7 @@
 /**
  * @brief HSICEstimator implements the sensitivity indices based on HSIC
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -66,6 +66,12 @@ Point HSICEstimator::getPValuesPermutation() const
   return getImplementation()->getPValuesPermutation();
 }
 
+/* Get the asymptotic p-values  */
+Point HSICEstimator::getPValuesAsymptotic() const
+{
+  return getImplementation()->getPValuesAsymptotic();
+}
+
 /* Draw the HSIC indices */
 Graph HSICEstimator::drawHSICIndices() const
 {
@@ -84,8 +90,20 @@ Graph HSICEstimator::drawPValuesPermutation() const
   return getImplementation()->drawPValuesPermutation();
 }
 
+/* Draw the p-values asymptotic with permutation */
+Graph HSICEstimator::drawPValuesAsymptotic() const
+{
+  return getImplementation()->drawPValuesAsymptotic();
+}
+
+// run all
+void HSICEstimator::run() const
+{
+  getImplementation()->run();
+}
+
 /* Get the covariance models */
-HSICEstimatorImplementation::CovarianceModelCollection HSICEstimator::getCovarianceModelCollection() const
+HSICEstimator::CovarianceModelCollection HSICEstimator::getCovarianceModelCollection() const
 {
   return getImplementation()->getCovarianceModelCollection();
 }
