@@ -2,7 +2,7 @@
 /**
  * @brief HSICEstimatorConditionalSensitivity implements the conditional sensivity HSIC indices
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -39,7 +39,8 @@ HSICEstimatorConditionalSensitivity::HSICEstimatorConditionalSensitivity(
   , const Function & weightFunction)
   : HSICEstimatorImplementation(covarianceModelCollection, X, Y, HSICVStat())
 {
-  weightFunction_ = weightFunction;
+  computeCovarianceMatrices();
+  setWeightFunction(weightFunction);
 }
 
 /* Virtual constructor */
@@ -54,16 +55,6 @@ void HSICEstimatorConditionalSensitivity::computePValuesAsymptotic() const
   throw NotYetImplementedException(HERE) << "HSICEstimatorConditionalSensitivity cannot compute asymptotic p-values.";
 }
 
-/* Compute the weight matrix from the weight function */
-SquareMatrix HSICEstimatorConditionalSensitivity::computeWeightMatrix(const Sample & Y) const
-{
-  const Sample wY(weightFunction_(Y));
-  const Scalar meanWY(wY.computeMean()[0]);
-  SquareMatrix mat(n_);
-  mat.setDiagonal(wY.asPoint() / meanWY);
-  return mat;
-}
-
 /* Get the weight function */
 Function HSICEstimatorConditionalSensitivity::getWeightFunction() const
 {
@@ -75,18 +66,15 @@ void HSICEstimatorConditionalSensitivity::setWeightFunction(const Function & wei
 {
   weightFunction_ = weightFunction;
   resetIndices();
+  computeWeights();
 }
 
-/* Method save() stores the object through the StorageManager */
-void HSICEstimatorConditionalSensitivity::save(Advocate & adv) const
+/** Compute the weights from the weight function */
+void HSICEstimatorConditionalSensitivity::computeWeights()
 {
-  HSICEstimatorImplementation::save(adv);
-}
-
-/* Method load() reloads the object from the StorageManager */
-void HSICEstimatorConditionalSensitivity::load(Advocate & adv)
-{
-  HSICEstimatorImplementation::load(adv);
+  const Sample wY(weightFunction_(outputSample_));
+  const Scalar meanWY(wY.computeMean()[0]);
+  weights_ = wY.asPoint() / meanWY;
 }
 
 END_NAMESPACE_OPENTURNS
