@@ -2,7 +2,7 @@
 /**
  *  @brief SpaceFillingPhiP
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -20,9 +20,7 @@
  */
 #include "openturns/SpaceFillingPhiP.hxx"
 #include "openturns/PersistentObjectFactory.hxx"
-
-#include <limits>
-
+#include "openturns/SpecFunc.hxx"
 
 namespace OT
 {
@@ -66,7 +64,7 @@ Scalar SpaceFillingPhiP::evaluate(const Sample & sample) const
         const Scalar delta(ptI[d] - ptJ[d]);
         squaredNorm += delta * delta;
       }
-      if (squaredNorm == 0.0) return std::numeric_limits<Scalar>::max();
+      if (squaredNorm == 0.0) return SpecFunc::MaxScalar;
       sum += std::exp(-0.5 * p_ * std::log(squaredNorm));
     }
   }
