@@ -2,7 +2,7 @@
 /*
  *  @brief WeightedExperiment interface
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -94,4 +94,9 @@ Bool WeightedExperiment::hasUniformWeights() const
   return getImplementation()->hasUniformWeights();
 }
 
+Bool WeightedExperiment::isRandom() const
+{
+  return getImplementation()->isRandom();
+}
+
 END_NAMESPACE_OPENTURNS
