@@ -2,7 +2,7 @@
 /**
  *  @brief Abstract top-level view of an weightedExperiment plane
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -43,8 +43,6 @@ WeightedExperimentImplementation::WeightedExperimentImplementation()
 /* Constructor with parameters */
 WeightedExperimentImplementation::WeightedExperimentImplementation(const UnsignedInteger size)
   : ExperimentImplementation()
-  , distribution_()
-  , size_(0)
 {
   // Check if the size is valid
   setSize(size);
@@ -55,7 +53,6 @@ WeightedExperimentImplementation::WeightedExperimentImplementation(const Distrib
     const UnsignedInteger size)
   : ExperimentImplementation()
   , distribution_(distribution)
-  , size_(0)
 {
   // Check if the size is valid
   setSize(size);
@@ -119,6 +116,12 @@ Sample WeightedExperimentImplementation::generateWithWeights(Point & ) const
   throw NotYetImplementedException(HERE) << "In WeightedExperimentImplementation::generateWithWeights()";
 }
 
+/* Return isRandom flag */
+Bool WeightedExperimentImplementation::isRandom() const
+{
+  return true;
+}
+
 /* Method save() stores the object through the StorageManager */
 void WeightedExperimentImplementation::save(Advocate & adv) const
 {
