@@ -2,7 +2,7 @@
 /**
  *  @brief Metropolis-Hastings algorithm
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -126,9 +126,6 @@ Point Gibbs::getRealization() const
 {
   const UnsignedInteger nbSamplers = samplers_.getSize();
 
-  // perform burnin if necessary
-  const UnsignedInteger size = getThinning() + ((samplesNumber_ < getBurnIn()) ? getBurnIn() : 0);
-
   // check the first log-posterior
   if (samplesNumber_ == 0)
   {
@@ -168,22 +165,18 @@ Point Gibbs::getRealization() const
     } // random updating
   }
 
-  // for each new sample
-  for (UnsignedInteger i = 0; i < size; ++ i)
+  switch (updatingMethod_)
   {
-    switch (updatingMethod_)
-    {
-      case DETERMINISTIC_UPDATING:
-        computeRealizationDeterministicUpdating();
-        break;
-      case RANDOM_UPDATING:
-        computeRealizationRandomUpdating();
-        break;
-      default:
-        throw InvalidArgumentException(HERE) << "Error: invalid updating method, must be DETERMINISTIC_UPDATING or RANDOM_UPDATING, here updatingMethod_=" << updatingMethod_;
-    } /* end switch */
-  }
-  samplesNumber_ += size;
+    case DETERMINISTIC_UPDATING:
+      computeRealizationDeterministicUpdating();
+      break;
+    case RANDOM_UPDATING:
+      computeRealizationRandomUpdating();
+      break;
+    default:
+      throw InvalidArgumentException(HERE) << "Error: invalid updating method, must be DETERMINISTIC_UPDATING or RANDOM_UPDATING, here updatingMethod_=" << updatingMethod_;
+  } /* end switch */
+  samplesNumber_ ++;
 
   // Save the current state
   history_.store(currentState_);
@@ -215,30 +208,6 @@ Gibbs::UpdatingMethod Gibbs::getUpdatingMethod() const
   return static_cast<UpdatingMethod>(updatingMethod_);
 }
 
-void Gibbs::setBurnIn(const UnsignedInteger burnIn)
-{
-  burnIn_ = burnIn;
-}
-
-
-UnsignedInteger Gibbs::getBurnIn() const
-{
-  return burnIn_;
-}
-
-
-void Gibbs::setThinning(const UnsignedInteger thinning)
-{
-  if (thinning == 0) throw InvalidArgumentException(HERE) << "The thinning parameter should be positive.";
-  thinning_ = thinning;
-}
-
-
-UnsignedInteger Gibbs::getThinning() const
-{
-  return thinning_;
-}
-
 /* Indices for which the posterior is recomputed */
 Indices Gibbs::getRecomputeLogPosterior() const
 {
@@ -264,8 +233,6 @@ void Gibbs::save(Advocate & adv) const
   adv.saveAttribute("updatingMethod_", updatingMethod_);
   adv.saveAttribute("previouslyChosenSampler_", previouslyChosenSampler_);
   adv.saveAttribute("currentState_", currentState_);
-  adv.saveAttribute("burnIn_", burnIn_);
-  adv.saveAttribute("thinning_", thinning_);
 }
 
 /* Method load() reloads the object from the StorageManager */
@@ -276,8 +243,6 @@ void Gibbs::load(Advocate & adv)
   adv.loadAttribute("updatingMethod_", updatingMethod_);
   adv.loadAttribute("previouslyChosenSampler_", previouslyChosenSampler_);
   adv.loadAttribute("currentState_", currentState_);
-  adv.loadAttribute("burnIn_", burnIn_);
-  adv.loadAttribute("thinning_", thinning_);
 }
 
 
