@@ -2,7 +2,7 @@
 /**
  *  @brief MetropolisHastingsImplementation base class
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -47,8 +47,6 @@ MetropolisHastingsImplementation::MetropolisHastingsImplementation(const Point &
   , initialState_(initialState)
   , currentState_(initialState)
   , history_(Full())
-  , burnIn_(ResourceMap::GetAsUnsignedInteger("MetropolisHastings-DefaultBurnIn"))
-  , thinning_(ResourceMap::GetAsUnsignedInteger("MetropolisHastings-DefaultThinning"))
 {
   setMarginalIndices(marginalIndices);
   history_.setDimension(initialState.getDimension());
@@ -63,8 +61,6 @@ MetropolisHastingsImplementation::MetropolisHastingsImplementation(const Distrib
   , initialState_(initialState)
   , currentState_(initialState)
   , history_(Full())
-  , burnIn_(ResourceMap::GetAsUnsignedInteger("MetropolisHastings-DefaultBurnIn"))
-  , thinning_(ResourceMap::GetAsUnsignedInteger("MetropolisHastings-DefaultThinning"))
 {
   setTargetDistribution(targetDistribution);
   setMarginalIndices(marginalIndices);
@@ -82,8 +78,6 @@ MetropolisHastingsImplementation::MetropolisHastingsImplementation(const Functio
   , history_(Full())
   , targetLogPDF_(targetLogPDF)
   , support_(support)
-  , burnIn_(ResourceMap::GetAsUnsignedInteger("MetropolisHastings-DefaultBurnIn"))
-  , thinning_(ResourceMap::GetAsUnsignedInteger("MetropolisHastings-DefaultThinning"))
 {
   setTargetLogPDF(targetLogPDF, support);
   setMarginalIndices(marginalIndices);
@@ -140,9 +134,7 @@ String MetropolisHastingsImplementation::__repr__() const
          << " conditional=" << conditional_
          << " linkFunction=" << linkFunction_
          << " covariates=" << covariates_
-         << " observations=" << observations_
-         << " burnIn=" << burnIn_
-         << " thinning=" << thinning_;
+         << " observations=" << observations_;
 }
 
 
@@ -181,9 +173,6 @@ Scalar MetropolisHastingsImplementation::computeLogPosterior(const Point & state
 
 Point MetropolisHastingsImplementation::getRealization() const
 {
-  // perform burnin if necessary
-  const UnsignedInteger size = getThinning() + ((samplesNumber_ < getBurnIn()) ? getBurnIn() : 0);
-
   // check the first likelihood
   if (samplesNumber_ == 0)
   {
@@ -192,31 +181,27 @@ Point MetropolisHastingsImplementation::getRealization() const
       throw InvalidArgumentException(HERE) << "The initial state should have non-zero posterior probability density";
   }
 
-  // for each new sample
-  for (UnsignedInteger i = 0; i < size; ++ i)
+  Point newState(currentState_);
+  const Point candidate(getCandidate());
+  for (UnsignedInteger j = 0; j < marginalIndices_.getSize(); ++ j)
+    newState[marginalIndices_[j]] = candidate[j];
+
+  const Scalar newLogPosterior = computeLogPosterior(newState);
+
+  const Scalar alphaLog = newLogPosterior - currentLogPosterior_ + logProbCurrentConditionedToNew_ - logProbNewConditionedToCurrent_;
+  const Scalar uLog = log(RandomGenerator::Generate());
+  if (uLog < alphaLog)
   {
-    Point newState(currentState_);
-    const Point candidate(getCandidate());
-    for (UnsignedInteger j = 0; j < marginalIndices_.getSize(); ++ j)
-      newState[marginalIndices_[j]] = candidate[j];
-
-    const Scalar newLogPosterior = computeLogPosterior(newState);
-
-    // alpha = posterior(newstate)/posterior(oldstate)
-    const Scalar alphaLog = newLogPosterior - currentLogPosterior_ + logProbCurrentConditionedToNew_ - logProbNewConditionedToCurrent_;
-    const Scalar uLog = log(RandomGenerator::Generate());
-    if (uLog < alphaLog)
-    {
-      currentLogPosterior_ = newLogPosterior;
-      ++ acceptedNumber_;
-      ++ acceptedNumberAdaptation_;
-      currentState_ = newState;
-    }
-
-    // increment 1 by 1 as used in getCandidate
-    ++ samplesNumber_;
+    currentLogPosterior_ = newLogPosterior;
+    ++ acceptedNumber_;
+    ++ acceptedNumberAdaptation_;
+    currentState_ = newState;
   }
 
+  // increment 1 by 1 as used in getCandidate
+  ++ samplesNumber_;
+
+
   // Save the current state
   history_.store(currentState_);
 
@@ -341,31 +326,6 @@ Sample MetropolisHastingsImplementation::getCovariates() const
 }
 
 
-void MetropolisHastingsImplementation::setBurnIn(const UnsignedInteger burnIn)
-{
-  burnIn_ = burnIn;
-}
-
-
-UnsignedInteger MetropolisHastingsImplementation::getBurnIn() const
-{
-  return burnIn_;
-}
-
-
-void MetropolisHastingsImplementation::setThinning(const UnsignedInteger thinning)
-{
-  if (thinning == 0) throw InvalidArgumentException(HERE) << "The thinning parameter should be positive.";
-  thinning_ = thinning;
-}
-
-
-UnsignedInteger MetropolisHastingsImplementation::getThinning() const
-{
-  return thinning_;
-}
-
-
 void MetropolisHastingsImplementation::setVerbose(const Bool verbose)
 {
   verbose_ = verbose;
@@ -421,8 +381,6 @@ void MetropolisHastingsImplementation::save(Advocate & adv) const
   adv.saveAttribute("linkFunction_", linkFunction_);
   adv.saveAttribute("covariates_", covariates_);
   adv.saveAttribute("observations_", observations_);
-  adv.saveAttribute("burnIn_", burnIn_);
-  adv.saveAttribute("thinning_", thinning_);
   adv.saveAttribute("verbose_", verbose_);
 }
 
@@ -443,8 +401,6 @@ void MetropolisHastingsImplementation::load(Advocate & adv)
   adv.loadAttribute("linkFunction_", linkFunction_);
   adv.loadAttribute("covariates_", covariates_);
   adv.loadAttribute("observations_", observations_);
-  adv.loadAttribute("burnIn_", burnIn_);
-  adv.loadAttribute("thinning_", thinning_);
   adv.loadAttribute("verbose_", verbose_);
 }
 
