@@ -2,7 +2,7 @@
 /**
  *  @brief The AliMikhailHaqCopula distribution
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -342,6 +342,17 @@ Scalar AliMikhailHaqCopula::computeArchimedeanGeneratorSecondDerivative(const Sc
   return (-theta_ * theta_ / (u * u) - 2.0 * theta_ / (t * u) + 2.0 * std::log(u) / (t * t)) / t;
 }
 
+/* Dependence coefficients */
+CorrelationMatrix AliMikhailHaqCopula::computeUpperTailDependenceMatrix() const
+{
+  return CorrelationMatrix(getDimension());
+}
+
+CorrelationMatrix AliMikhailHaqCopula::computeLowerTailDependenceMatrix() const
+{
+  return CorrelationMatrix(getDimension());
+}
+
 /* Parameters value accessor */
 Point AliMikhailHaqCopula::getParameter() const
 {
