@@ -2,7 +2,7 @@
 /**
  *  @brief The Arcsine distribution
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -259,17 +259,12 @@ Point Arcsine::getKurtosis() const /*throw(NotDefinedException)*/
   return Point(1, (3.0 / 8.0) * a4 / standardDeviation4);
 }
 
-/* Get the moments of the standardized distribution */
-Point Arcsine::getStandardMoment(const UnsignedInteger n) const
-{
-  if (n % 2 == 1) return Point(1, 0.0);
-  return Point(1, std::exp(SpecFunc::LogGamma(0.5 * n + 0.5) - SpecFunc::LogGamma(0.5 * n + 1)) / std::sqrt(M_PI));
-}
-
 /* Get the standard representative in the parametric family, associated with the standard moments */
 Distribution Arcsine::getStandardRepresentative() const
 {
-  return new Arcsine(-1.0, 1.0);
+  Arcsine standard(-1.0, 1.0);
+  standard.setDescription(getDescription());
+  return standard;
 }
 
 /* Compute the covariance of the distribution */
