@@ -2,7 +2,7 @@
 /**
  *  @brief The Bernoulli distribution
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -202,13 +202,6 @@ Point Bernoulli::getKurtosis() const
   return Point(1, 3.0 + (6.0 * p_ * (1.0 - p_) + 1.0) / (p_ * (1.0 - p_)));
 }
 
-/* Get the moments of the standardized distribution */
-Point Bernoulli::getStandardMoment(const UnsignedInteger n) const
-{
-  if (n == 0) return Point(1, 0.0);
-  return Point(1, p_);
-}
-
 /* Compute the covariance of the distribution */
 void Bernoulli::computeCovariance() const
 {
