@@ -2,7 +2,7 @@
 /**
  *  @brief Factory for Bernoulli distribution
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -71,8 +71,11 @@ Bernoulli BernoulliFactory::buildAsBernoulli(const Sample & sample) const
   for (UnsignedInteger i = 0; i < size; ++i)
   {
     const Scalar x = sample(i, 0);
-    const int iX(static_cast<int>(round(x)));
-    if ((std::abs(x - iX) > supportEpsilon) || ((iX != 0) && (iX != 1))) throw InvalidArgumentException(HERE) << "Error: can build a Bernoulli distribution only from a sample made of 0 and 1.";
+    if (!SpecFunc::IsNormal(x))
+      throw InvalidArgumentException(HERE) << "Error: cannot build a Bernoulli distribution if data contains NaN or Inf";
+    const SignedInteger iX = static_cast<SignedInteger>(std::round(x));
+    if ((std::abs(x - iX) > supportEpsilon) || ((iX != 0) && (iX != 1)))
+      throw InvalidArgumentException(HERE) << "Error: can build a Bernoulli distribution only from a sample made of 0 and 1.";
     sum += x;
   }
   Bernoulli result(sum / size);
