@@ -2,7 +2,7 @@
 /**
  *  @brief Abstract top-level class for all BlockIndependentDistribution
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -135,7 +135,7 @@ void BlockIndependentDistribution::setDistributionCollection(const DistributionC
 
 
 /* Distribution collection accessor */
-const BlockIndependentDistribution::DistributionCollection & BlockIndependentDistribution::getDistributionCollection() const
+BlockIndependentDistribution::DistributionCollection BlockIndependentDistribution::getDistributionCollection() const
 {
   return distributionCollection_;
 }
