@@ -2,7 +2,7 @@
 /**
  *  @brief The Chi distribution
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -279,12 +279,6 @@ Point Chi::getKurtosis() const
   return Point(1, 3.0 + 2.0 * (1.0 - sigma * (mu * gamma1 + sigma)) / std::pow(sigma, 2.0));
 }
 
-/* Get the moments of the standardized distribution */
-Point Chi::getStandardMoment(const UnsignedInteger n) const
-{
-  return Point(1, std::exp(0.5 * n * M_LN2 + SpecFunc::LnGamma(0.5 * (n + nu_)) - SpecFunc::LnGamma(0.5 * nu_)));
-}
-
 /* Parameters value accessor */
 Point Chi::getParameter() const
 {
