@@ -2,7 +2,7 @@
 /**
  *  @brief The ChiSquare distribution, ie the Gamma(nu/2,1/2) distribution
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -268,16 +268,12 @@ void ChiSquare::computeCovariance() const
   isAlreadyComputedCovariance_ = true;
 }
 
-/* Get the moments of the standardized distribution */
-Point ChiSquare::getStandardMoment(const UnsignedInteger n) const
-{
-  return Point(1, std::exp(SpecFunc::LnGamma(n + 0.5 * nu_) - SpecFunc::LnGamma(0.5 * nu_)));
-}
-
 /* Get the standard representative in the parametric family, associated with the standard moments */
 Distribution ChiSquare::getStandardRepresentative() const
 {
-  return Gamma(0.5 * nu_, 1.0, 0.0);
+  Gamma standard(0.5 * nu_, 1.0, 0.0);
+  standard.setDescription(getDescription());
+  return standard;
 }
 
 /* Parameters value accessor */
