@@ -2,7 +2,7 @@
 /**
  *  @brief Abstract top-level class for all ComposedCopulas
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -499,7 +499,7 @@ Scalar ComposedCopula::computeConditionalCDF(const Scalar x, const Point & y) co
   const UnsignedInteger conditioningDimension = y.getDimension();
   if (conditioningDimension >= getDimension()) throw InvalidArgumentException(HERE) << "Error: cannot compute a conditional CDF with a conditioning point of dimension greater or equal to the distribution dimension.";
   // Special case for no conditioning or independent copula
-  if ((conditioningDimension == 0) || (hasIndependentCopula())) return std::min(1.0, std::max(0.0, x));
+  if ((conditioningDimension == 0) || (hasIndependentCopula())) return SpecFunc::Clip01(x);
   // General case
   UnsignedInteger copulaIndex = 0;
   UnsignedInteger partialDimension = copulaCollection_[copulaIndex].getDimension();
