@@ -2,7 +2,7 @@
 /**
  *  @brief Abstract top-level class for all ComposedDistributions
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -40,6 +40,8 @@
 #include "openturns/Log.hxx"
 #include "openturns/TBBImplementation.hxx"
 #include "openturns/ComposedFunction.hxx"
+#include "openturns/Os.hxx"
+#include "openturns/OSS.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -161,6 +163,41 @@ String ComposedDistribution::__str__(const String & ) const
   return oss;
 }
 
+String ComposedDistribution::__repr_markdown__() const
+{
+  OSS oss(false);
+  oss << getClassName() << Os::GetEndOfLine();
+  oss << "- name=" << getName() << Os::GetEndOfLine();
+  oss << "- dimension=" << getDimension() << Os::GetEndOfLine();
+  oss << "- description=" << description_ << Os::GetEndOfLine();
+  if (getDimension() > 1) oss << "- copula=" << copula_.__str__() << Os::GetEndOfLine();
+  // Compute maximum distribution's column width
+  String intermediateString;
+  UnsignedInteger maximumColumnWidth = 0;
+  for (UnsignedInteger i = 0; i < distributionCollection_.getSize(); ++i)
+  {
+    intermediateString = OSS() << " " << distributionCollection_[i].__str__() << " ";
+    if (intermediateString.size() > maximumColumnWidth)
+      maximumColumnWidth = intermediateString.size();
+  }
+  intermediateString = OSS() << " Distribution ";
+  if (intermediateString.size() > maximumColumnWidth)
+    maximumColumnWidth = intermediateString.size();
+  // Format the table
+  oss << Os::GetEndOfLine();
+  oss << "| Index | Variable |"
+      << OSS::PadString(" Distribution ", maximumColumnWidth) << "|" << Os::GetEndOfLine();
+  oss << "|-------|----------|" << String(maximumColumnWidth, '-') << "|" << Os::GetEndOfLine();
+  for (UnsignedInteger i = 0; i < distributionCollection_.getSize(); ++i)
+  {
+    oss << "| " << std::setw(5) << i << " |"
+        << " " << std::setw(8) << description_[i] << " |";
+    intermediateString = OSS() << " " << distributionCollection_[i].__str__() << " ";
+    oss << OSS::PadString(intermediateString, maximumColumnWidth) << "|" << Os::GetEndOfLine();
+  }
+  return oss;
+}
+
 
 /* Distribution collection accessor */
 void ComposedDistribution::setDistributionCollection(const DistributionCollection & coll)
@@ -203,11 +240,20 @@ void ComposedDistribution::setDistributionCollection(const DistributionCollectio
   isAlreadyComputedCovariance_ = false;
 
   // avoid description warning with identical entries
-  Description test(description);
-  Description::const_iterator it = std::unique(test.begin(), test.end());
-  if (it != test.end())
+  std::map<String, UnsignedInteger> occurrence;
+  UnsignedInteger idx = 0;
+  for (UnsignedInteger i = 0; i < description.getSize(); ++ i)
   {
-    description = Description::BuildDefault(dimension_, "X");
+    const String currentName(description[i]);
+    ++ occurrence[currentName];
+    if (occurrence[currentName] > 1)
+    {
+      while (occurrence.find(OSS() << "X" << idx) != occurrence.end())
+        ++ idx;
+      const String newName(OSS() << "X" << idx);
+      ++ occurrence[newName]; // avoid duplicates with new ones too
+      description[i] = newName;
+    }
   }
   setDescription(description);
 
@@ -216,7 +262,7 @@ void ComposedDistribution::setDistributionCollection(const DistributionCollectio
 
 
 /* Distribution collection accessor */
-const ComposedDistribution::DistributionCollection & ComposedDistribution::getDistributionCollection() const
+ComposedDistribution::DistributionCollection ComposedDistribution::getDistributionCollection() const
 {
   return distributionCollection_;
 }
@@ -1033,7 +1079,7 @@ ComposedDistribution::PointWithDescriptionCollection ComposedDistribution::getPa
     const PointWithDescriptionCollection marginalParameters(distributionCollection_[marginalIndex].getParametersCollection());
     PointWithDescription point(marginalParameters[0]);
     Description marginalParametersDescription(point.getDescription());
-    // Here we must add a unique prefix to the marginal parameters description in order to deambiguate the parameters of different marginals sharing the same description
+    // Here we must add a unique prefix to the marginal parameters description in order to desambiguate the parameters of different marginals sharing the same description
     for (UnsignedInteger i = 0; i < point.getDimension(); ++i) marginalParametersDescription[i] = (OSS() << marginalParametersDescription[i] << "_marginal_" << marginalIndex);
     point.setDescription(marginalParametersDescription);
     point.setName(description[marginalIndex]);
@@ -1044,7 +1090,7 @@ ComposedDistribution::PointWithDescriptionCollection ComposedDistribution::getPa
     // Second put the dependence parameters
     PointWithDescription point(copula_.getParametersCollection()[0]);
     Description copulaParametersDescription(point.getDescription());
-    // Here we must add a unique prefix to the copula parameters description in order to deambiguate the parameters of marginals sharing the same description
+    // Here we must add a unique prefix to the copula parameters description in order to disambiguate the parameters of marginals sharing the same description
     for (UnsignedInteger i = 0; i < point.getDimension(); ++i) copulaParametersDescription[i] = (OSS() << copulaParametersDescription[i] << "_copula");
     point.setDescription(copulaParametersDescription);
     point.setName(copula_.getName());
