@@ -3,7 +3,7 @@
  *  @brief This class implements the multivariate distribution based on a
  *         bipartite graph and a collection of distributions
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -147,7 +147,7 @@ void CumulativeDistributionNetwork::setDistributionCollection(const Distribution
 }
 
 /* Distribution collection accessor */
-const CumulativeDistributionNetwork::DistributionCollection & CumulativeDistributionNetwork::getDistributionCollection() const
+CumulativeDistributionNetwork::DistributionCollection CumulativeDistributionNetwork::getDistributionCollection() const
 {
   return distributionCollection_;
 }
@@ -168,7 +168,7 @@ void CumulativeDistributionNetwork::setGraph(const BipartiteGraph & graph)
 }
 
 /* Graph accessor */
-const BipartiteGraph & CumulativeDistributionNetwork::getGraph() const
+BipartiteGraph CumulativeDistributionNetwork::getGraph() const
 {
   return graph_;
 }
