@@ -2,7 +2,7 @@
 /**
  *  @brief OpenTURNS wrapper to a library of special functions
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -526,18 +526,9 @@ Indices DistFunc::rBinomial(const UnsignedInteger n,
 /* It implements the alias method as described here: */
 /* http://keithschwarz.com/darts-dice-coins/ */
 /*******************************************************************************************************/
-Indices DistFunc::rDiscrete(const Point & probabilities,
-                            const UnsignedInteger size)
-{
-  Point base;
-  Indices alias;
-  return rDiscrete(probabilities, base, alias, size);
-}
-
-Indices DistFunc::rDiscrete(const Point & probabilities,
-                            Point & base,
-                            Indices & alias,
-                            const UnsignedInteger size)
+void DistFunc::rDiscreteSetup(const Point & probabilities,
+                              Point & base,
+                              Indices & alias)
 {
   // Setup part
   const UnsignedInteger n = probabilities.getSize();
@@ -582,21 +573,6 @@ Indices DistFunc::rDiscrete(const Point & probabilities,
   // The next loop accurs only due to numerical instability
   for (; indexSmall < smallSize; ++indexSmall)
     base[small[indexSmall]] = 1.0;
-  return rDiscrete(base, alias, size);
-}
-
-UnsignedInteger DistFunc::rDiscrete(const Point & probabilities)
-{
-  Point base;
-  Indices alias;
-  return rDiscrete(probabilities, base, alias, 1)[0];
-}
-
-UnsignedInteger DistFunc::rDiscrete(const Point & probabilities,
-                                    Point & base,
-                                    Indices & alias)
-{
-  return DistFunc::rDiscrete(probabilities, base, alias, 1)[0];
 }
 
 UnsignedInteger DistFunc::rDiscrete(const Point & base,
@@ -617,6 +593,20 @@ Indices DistFunc::rDiscrete(const Point & base,
   return result;
 }
 
+UnsignedInteger DistFunc::rDiscrete(const Point & probabilities)
+{
+  return rDiscrete(probabilities, 1)[0];
+}
+
+Indices DistFunc::rDiscrete(const Point & probabilities,
+                            const UnsignedInteger size)
+{
+  Point base;
+  Indices alias;
+  rDiscreteSetup(probabilities, base, alias);
+  return rDiscrete(base, alias, size);
+}
+
 /*******************************************************************************************************/
 /* Normalized Gamma distribution, i.e. with a PDF equals to x ^ (k - 1) . exp(-x) / gamma(k) . (x > 0) */
 /*******************************************************************************************************/
@@ -1566,7 +1556,7 @@ Scalar DistFunc::pSpearmanCorrelation(const UnsignedInteger size, const Scalar r
   }
   // Exact computation for small sample size thanks to the values given
   // in http://www.luke-g.com/math/spearman/index.html
-  // The case n==2 has been addded to the table
+  // The case n==2 has been added to the table
   if (size <= 26)
   {
     // Include the tabulated exact distribution
@@ -1696,7 +1686,7 @@ Scalar DistFunc::eZ1(const UnsignedInteger n)
 
 
 /* Dickey Fuller asymptotic table
-   The use of such table allow to make a linear approximation
+   The use of such table allow one to make a linear approximation
 */
 Scalar DistFunc::pDickeyFullerTrend(const Scalar x,
                                     const Bool tail)
@@ -1958,6 +1948,95 @@ Scalar DistFunc::qDickeyFullerNoConstant(const Scalar p,
   throw NotYetImplementedException(HERE) << "In DistFunc::qDickeyFullerNoConstant(const Scalar p, const Bool tail): cannot give quantile value for the level " << p << ". Value is missing in table";
 }
 
+// For uniform distribution over a segment
+Point DistFunc::rUniformSegment(const Point & a,
+                                const Point & b)
+{
+  const UnsignedInteger dimension = a.getDimension();
+  if (b.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the second point has a dimension=" << b.getDimension() << ", expected dimension=" << dimension;
+  Point result(dimension);
+  rUniformSegment(&a[0], &b[0], dimension, &result[0]);
+  return result;
+}
+
+void DistFunc::rUniformSegment(const Scalar * a,
+                               const Scalar * b,
+                               const UnsignedInteger dimension,
+                               Scalar * result)
+{
+  const Scalar u = RandomGenerator::Generate();
+  const Scalar v = 1.0 - u;
+  for (UnsignedInteger i = 0; i < dimension; ++i)
+    result[i] = u * a[i] + v * b[i];
+}
+
+Sample DistFunc::rUniformSegment(const Point & a,
+                                 const Point & b,
+                                 const UnsignedInteger size)
+{
+  const UnsignedInteger dimension = a.getDimension();
+  if (b.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the second point has a dimension=" << b.getDimension() << ", expected dimension=" << dimension;
+  Sample result(size, dimension);
+  rUniformSegment(&a[0], &b[0], dimension, size, &result(0, 0));
+  return result;
+}
+
+void DistFunc::rUniformSegment(const Scalar * a,
+                               const Scalar * b,
+                               const UnsignedInteger dimension,
+                               const UnsignedInteger size,
+                               Scalar * result)
+{
+  UnsignedInteger index = 0;
+  for (UnsignedInteger j = 0; j < size; ++j)
+  {
+    const Scalar u = RandomGenerator::Generate();
+    const Scalar v = 1.0 - u;
+    for (UnsignedInteger i = 0; i < dimension; ++i)
+    {
+      result[index] = u * a[i] + v * b[i];
+      ++index;
+    } // i
+  } // j
+}
+
+// For uniform distribution over a triangle
+// Many algorithms are possible:
+// 1) Using sorted uniform [0, 1] coordinates:
+//    Scalar u = RandomGenerator::Generate();
+//    Scalar v = RandomGenerator::Generate();
+//    if (u > v) std::swap(u, v);
+//    then the barycentric coordinates are (u, v-u, 1-v)
+//    The resulting speed is 38.6M points/s
+// 2) Using reflection along the line 1-u-v:
+//    Scalar u = RandomGenerator::Generate();
+//    Scalar v = RandomGenerator::Generate();
+//    Scalar w = 1.0 - u - v;
+//    if (w < 0.0)
+//      {
+//        u = 1.0 - u;
+//        v = 1.0 - v;
+//        w = -w;
+//      }
+//    then the barycentric coordinates are (u, v, w)
+//    The resulting speed is 40.9M points/s
+// 3) Using a sampling on a cut parallel to the base then a point on the cut
+//    const Scalar u = RandomGenerator::Generate();
+//    const Scalar v = RandomGenerator::Generate();
+//    const Scalar sqrtU = std::sqrt(u);
+//    Scalar x = 1.0 - sqrtU;
+//    Scalar y = v * sqrtU;
+//    Scalar z = 1.0 - x - y;
+//    if (z < 0.0)
+//    {
+//      x = sqrtU;
+//      y = 1.0 - sqrtU;
+//      z = -z;
+//    }
+//    then the barycentric coordinates are (x, y, z)
+//    The resulting speed is 44.5M points/s
+//
+//    Surprisingly, the fastest involves a square root!
 Point DistFunc::rUniformTriangle(const Point & a,
                                  const Point & b,
                                  const Point & c)
@@ -1965,23 +2044,26 @@ Point DistFunc::rUniformTriangle(const Point & a,
   const UnsignedInteger dimension = a.getDimension();
   if (b.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the second point has a dimension=" << b.getDimension() << ", expected dimension=" << dimension;
   if (c.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the third point has a dimension=" << c.getDimension() << ", expected dimension=" << dimension;
-  const Scalar u = RandomGenerator::Generate();
-  const Scalar v = RandomGenerator::Generate();
-  const Scalar sqrtU = std::sqrt(u);
-  Scalar x = 1.0 - sqrtU;
-  Scalar y = v * sqrtU;
-  Scalar z = 1.0 - x - y;
-  if (z < 0.0)
-  {
-    x = sqrtU;
-    y = 1.0 - sqrtU;
-    z = -z;
-  }
   Point result(dimension);
-  for (UnsignedInteger i = 0; i < dimension; ++i) result[i] = x * a[i] + y * b[i] + z * c[i];
+  rUniformTriangle(&a[0], &b[0], &c[0], dimension, &result[0]);
   return result;
 }
 
+void DistFunc::rUniformTriangle(const Scalar * a,
+                                const Scalar * b,
+                                const Scalar * c,
+                                const UnsignedInteger dimension,
+                                Scalar * result)
+{
+  const Scalar u = RandomGenerator::Generate();
+  const Scalar sqrtV = std::sqrt(RandomGenerator::Generate());
+  const Scalar x = 1.0 - sqrtV;
+  const Scalar y = (1.0 - u) * sqrtV;
+  const Scalar z = u * sqrtV;
+  for (UnsignedInteger i = 0; i < dimension; ++i)
+    result[i] = x * a[i] + y * b[i] + z * c[i];
+}
+
 Sample DistFunc::rUniformTriangle(const Point & a,
                                   const Point & b,
                                   const Point & c,
@@ -1992,25 +2074,206 @@ Sample DistFunc::rUniformTriangle(const Point & a,
   if (b.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the second point has a dimension=" << b.getDimension() << ", expected dimension=" << dimension;
   if (c.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the third point has a dimension=" << c.getDimension() << ", expected dimension=" << dimension;
   Sample result(size, dimension);
+  rUniformTriangle(&a[0], &b[0], &c[0], dimension, size, &result(0, 0));
+  return result;
+}
+
+void DistFunc::rUniformTriangle(const Scalar * a,
+                                const Scalar * b,
+                                const Scalar * c,
+                                const UnsignedInteger dimension,
+                                const UnsignedInteger size,
+                                Scalar * result)
+{
+  UnsignedInteger index = 0;
   for (UnsignedInteger n = 0; n < size; ++n)
   {
     const Scalar u = RandomGenerator::Generate();
-    const Scalar v = RandomGenerator::Generate();
-    const Scalar sqrtU = std::sqrt(u);
-    Scalar x = 1.0 - sqrtU;
-    Scalar y = v * sqrtU;
-    Scalar z = 1.0 - x - y;
-    if (z < 0.0)
+    const Scalar sqrtV = std::sqrt(RandomGenerator::Generate());
+    const Scalar x = 1.0 - sqrtV;
+    const Scalar y = (1.0 - u) * sqrtV;
+    const Scalar z = u * sqrtV;
+    for (UnsignedInteger i = 0; i < dimension; ++i)
     {
-      x = sqrtU;
-      y = 1.0 - sqrtU;
-      z = -z;
+      result[index] = x * a[i] + y * b[i] + z * c[i];
+      ++index;
     }
-    for (UnsignedInteger i = 0; i < dimension; ++i) result(n, i) = x * a[i] + y * b[i] + z * c[i];
   } // n
+}
+
+// For uniform distribution over a tetrahedron
+Point DistFunc::rUniformTetrahedron(const Point & a,
+                                    const Point & b,
+                                    const Point & c,
+                                    const Point & d)
+{
+  const UnsignedInteger dimension = a.getDimension();
+  if (b.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the second point has a dimension=" << b.getDimension() << ", expected dimension=" << dimension;
+  if (c.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the third point has a dimension=" << c.getDimension() << ", expected dimension=" << dimension;
+  if (d.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the fourth point has a dimension=" << c.getDimension() << ", expected dimension=" << dimension;
+  Point result(dimension);
+  rUniformTetrahedron(&a[0], &b[0], &c[0], &d[0], dimension, &result[0]);
   return result;
 }
 
+void DistFunc::rUniformTetrahedron(const Scalar * a,
+                                   const Scalar * b,
+                                   const Scalar * c,
+                                   const Scalar * d,
+                                   const UnsignedInteger dimension,
+                                   Scalar * result)
+{
+  const Scalar u = RandomGenerator::Generate();
+  const Scalar sqrtV = std::sqrt(RandomGenerator::Generate());
+  const Scalar cbrtW = std::cbrt(RandomGenerator::Generate());
+  const Scalar x = u * sqrtV * cbrtW;
+  const Scalar y = (1.0 - u) * sqrtV * cbrtW;
+  const Scalar z = (1.0 - sqrtV) * cbrtW;
+  const Scalar t = 1.0 - cbrtW;
+  for (UnsignedInteger i = 0; i < dimension; ++i) result[i] = x * a[i] + y * b[i] + z * c[i] + t * d[i];
+}
+
+Sample DistFunc::rUniformTetrahedron(const Point & a,
+                                     const Point & b,
+                                     const Point & c,
+                                     const Point & d,
+                                     const UnsignedInteger size)
+{
+  // Here we reproduce the algorithm in order to avoid costly data copy and tests
+  const UnsignedInteger dimension = a.getDimension();
+  if (b.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the second point has a dimension=" << b.getDimension() << ", expected dimension=" << dimension;
+  if (c.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the third point has a dimension=" << c.getDimension() << ", expected dimension=" << dimension;
+  Sample result(size, dimension);
+  rUniformTetrahedron(&a[0], &b[0], &c[0], &d[0], dimension, &result(0, 0));
+  return result;
+}
+
+void DistFunc::rUniformTetrahedron(const Scalar * a,
+                                   const Scalar * b,
+                                   const Scalar * c,
+                                   const Scalar * d,
+                                   const UnsignedInteger dimension,
+                                   const UnsignedInteger size,
+                                   Scalar * result)
+{
+  UnsignedInteger index = 0;
+  for (UnsignedInteger n = 0; n < size; ++n)
+  {
+    const Scalar u = RandomGenerator::Generate();
+    const Scalar sqrtV = std::sqrt(RandomGenerator::Generate());
+    const Scalar cbrtW = std::cbrt(RandomGenerator::Generate());
+    const Scalar x = u * sqrtV * cbrtW;
+    const Scalar y = (1.0 - u) * sqrtV * cbrtW;
+    const Scalar z = (1.0 - sqrtV) * cbrtW;
+    const Scalar t = 1.0 - cbrtW;
+    for (UnsignedInteger i = 0; i < dimension; ++i)
+    {
+      result[index] = x * a[i] + y * b[i] + z * c[i] + t * d[i];
+      ++index;
+    }
+  } // n
+}
+
+// For uniform distribution over a simplex
+Point DistFunc::rUniformSimplex(const Sample & vertices)
+{
+  const UnsignedInteger numVertices = vertices.getSize();
+  if (numVertices == 0) throw InvalidArgumentException(HERE) << "Error: expected at least one vertex to define a simplex.";
+  const UnsignedInteger dimension = vertices.getDimension();
+  Point result(dimension);
+  rUniformSimplex(&vertices(0, 0), dimension, numVertices, &result[0]);
+  return result;
+}
+
+void DistFunc::rUniformSimplex(const Scalar * vertices,
+                               const UnsignedInteger dimension,
+                               const UnsignedInteger numVertices,
+                               Scalar * result)
+{
+  if (numVertices == 1)
+  {
+    std::copy(vertices, vertices + dimension, result);
+    return;
+  }
+  if (numVertices == 2)
+  {
+    rUniformSegment(vertices, vertices + dimension, dimension, result);
+    return;
+  }
+  if (numVertices == 3)
+  {
+    rUniformTriangle(vertices, vertices + dimension, vertices + 2 * dimension, dimension, result);
+    return;
+  }
+  if (numVertices == 4)
+  {
+    rUniformTetrahedron(vertices, vertices + dimension, vertices + 2 * dimension, vertices + 3 * dimension, dimension, result);
+    return;
+  }
+  std::copy(vertices, vertices + dimension, result);
+  UnsignedInteger shift = dimension;
+  for (UnsignedInteger i = 1; i < numVertices; ++i)
+  {
+    const Scalar u = std::pow(RandomGenerator::Generate(), 1.0 / i);
+    for (UnsignedInteger j = 0; j < dimension; ++j) result[j] = u * result[j] + (1.0 - u) * vertices[shift + j];
+    shift += dimension;
+  }
+}
+
+Sample DistFunc::rUniformSimplex(const Sample & vertices,
+                                 const UnsignedInteger size)
+{
+  const UnsignedInteger numVertices = vertices.getSize();
+  if (numVertices == 0) throw InvalidArgumentException(HERE) << "Error: expected at least one vertex to define a simplex.";
+  const UnsignedInteger dimension = vertices.getDimension();
+  Sample result(size, dimension);
+  rUniformSimplex(&vertices(0, 0), dimension, numVertices, size, &result(0, 0));
+  return result;
+}
+
+void DistFunc::rUniformSimplex(const Scalar * vertices,
+                               const UnsignedInteger dimension,
+                               const UnsignedInteger numVertices,
+                               const UnsignedInteger size,
+                               Scalar * result)
+{
+  if (numVertices == 1)
+  {
+    for (UnsignedInteger i = 0; i < size; ++i)
+      std::copy(vertices, vertices + dimension, result + i * dimension);
+    return;
+  }
+  if (numVertices == 2)
+  {
+    rUniformSegment(vertices, vertices + dimension, dimension, size, result);
+    return;
+  }
+  if (numVertices == 3)
+  {
+    rUniformTriangle(vertices, vertices + dimension, vertices + 2 * dimension, dimension, size, result);
+    return;
+  }
+  if (numVertices == 4)
+  {
+    rUniformTetrahedron(vertices, vertices + dimension, vertices + 2 * dimension, vertices + 3 * dimension, dimension, size, result);
+    return;
+  }
+  UnsignedInteger shiftResult = 0;
+  for (UnsignedInteger n = 0; n < size; ++n)
+  {
+    std::copy(vertices, vertices + dimension, result + shiftResult);
+    UnsignedInteger shift = dimension;
+    for (UnsignedInteger i = 1; i < numVertices; ++i)
+    {
+      const Scalar u = std::pow(RandomGenerator::Generate(), 1.0 / i);
+      for (UnsignedInteger j = 0; j < dimension; ++j) result[shiftResult + j] = u * result[shiftResult + j] + (1.0 - u) * vertices[shift + j];
+      shift += dimension;
+    } // i
+    shiftResult += dimension;
+  } // n
+}
+
+
 /* K factor for exact two-sided tolerance intervals of normal pooled populations
  * see Janiga, I. Miklos, R. "Statistical Tolerance Intervals for a Normal Distribution", Measurement Science Review, 2001.
  * Here we use \alpha instead of 1-\alpha wrt the reference
