@@ -2,7 +2,7 @@
 /**
  *  @brief Factory for FisherSnedecor distribution
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -76,7 +76,7 @@ Distribution FisherSnedecorFactory::build() const
 
 DistributionFactoryResult FisherSnedecorFactory::buildEstimator(const Sample & sample) const
 {
-  return buildMaximumLikelihoodEstimator(sample, true);
+  return MaximumLikelihoodFactory::BuildEstimator(*this, sample, true);
 }
 
 FisherSnedecor FisherSnedecorFactory::buildAsFisherSnedecor(const Sample & sample) const
