@@ -2,7 +2,7 @@
 /**
  *  @brief The FrankCopula distribution
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -344,6 +344,17 @@ Scalar FrankCopula::computeArchimedeanGeneratorSecondDerivative(const Scalar t)
   return ratio * ratio * std::exp(thetaT);
 }
 
+/* Dependence coefficients */
+CorrelationMatrix FrankCopula::computeUpperTailDependenceMatrix() const
+{
+  return CorrelationMatrix(getDimension());
+}
+
+CorrelationMatrix FrankCopula::computeLowerTailDependenceMatrix() const
+{
+  return CorrelationMatrix(getDimension());
+}
+
 /* Parameters value accessor */
 Point FrankCopula::getParameter() const
 {
