@@ -2,7 +2,7 @@
 /**
  *  @brief Factory for Frechet distribution
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -120,7 +120,7 @@ Frechet FrechetFactory::buildAsFrechet() const
 
 DistributionFactoryResult FrechetFactory::buildEstimator(const Sample & sample) const
 {
-  return buildMaximumLikelihoodEstimator(sample, true);
+  return MaximumLikelihoodFactory::BuildEstimator(*this, sample, true);
 }
 
 END_NAMESPACE_OPENTURNS
