@@ -2,7 +2,7 @@
 /**
  *  @brief The Gumbel distribution
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -262,7 +262,9 @@ Point Gumbel::getKurtosis() const
 /* Get the standard representative in the parametric family, associated with the standard moments */
 Distribution Gumbel::getStandardRepresentative() const
 {
-  return new Gumbel(1.0, 0.0);
+  Gumbel standard(1.0, 0.0);
+  standard.setDescription(getDescription());
+  return standard;
 }
 
 /* Compute the covariance of the distribution */
