@@ -2,7 +2,7 @@
 /**
  *  @brief The Histogram distribution
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -19,7 +19,6 @@
  *
  */
 #include "openturns/Histogram.hxx"
-#include "openturns/BarPlot.hxx"
 #include "openturns/Curve.hxx"
 #include "openturns/RandomGenerator.hxx"
 #include "openturns/PersistentObjectFactory.hxx"
@@ -306,34 +305,23 @@ void Histogram::computeCovariance() const
   isAlreadyComputedCovariance_ = true;
 }
 
-/* Get the moments of the standardized distribution */
-Point Histogram::getStandardMoment(const UnsignedInteger n) const
-{
-  if (n == 0) return Point(1, 1.0);
-  Scalar value = 0.0;
-  const UnsignedInteger size = width_.getSize();
-  Scalar xPrec = -1.0;
-  const Scalar factor = 2.0 / cumulatedWidth_[size - 1];
-  for (UnsignedInteger i = 0; i < size; ++i)
-  {
-    const Scalar x = xPrec + width_[i] * factor;
-    value += (std::pow(x, static_cast<int>(n + 1)) - std::pow(xPrec, static_cast<int>(n + 1))) * height_[i];
-    xPrec = x;
-  }
-  value /= (n + 1) * factor;
-  return Point(1, value);
-}
-
 /* Get the standard representative in the parametric family, associated with the standard moments */
 Distribution Histogram::getStandardRepresentative() const
 {
   const UnsignedInteger size = width_.getSize();
-  if (size == 1) return Uniform(-1.0, 1.0);
+  if (size == 1)
+  {
+    Uniform standard(-1.0, 1.0);
+    standard.setDescription(getDescription());
+    return standard;
+  }
   // No need to transform an histogram if its range is already [-1.0, 1.0]
   if (first_ == -1.0 && std::abs(cumulatedWidth_[size - 1] - 2.0) <= ResourceMap::GetAsScalar("Distribution-DefaultQuantileEpsilon")) return clone();
   const Scalar first = -1.0;
   const Scalar factor = 2.0 / cumulatedWidth_[size - 1];
-  return new Histogram(first, factor * width_, height_ / factor);
+  Histogram standard(first, factor * width_, height_ / factor);
+  standard.setDescription(getDescription());
+  return standard;
 }
 
 /* Parameters value and description accessor */
