@@ -2,7 +2,7 @@
 /**
  *  @brief The InverseChiSquare distribution
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -287,17 +287,12 @@ Point InverseChiSquare::getKurtosis() const
   return Point(1, 12.0 * (0.5 * nu_ * (0.5 * nu_ + 3.0) - 10.0) / ((nu_ - 6.0) * (nu_ - 8.0)));
 }
 
-/* Get the moments of the standardized distribution */
-Point InverseChiSquare::getStandardMoment(const UnsignedInteger n) const
-{
-  if (nu_ <= 2.0 * n) throw NotDefinedException(HERE) << "InverseChiSquare standard moment of order " << 2.0 * n << " is defined only for nu > " << 2.0 * n << ", here k=" << nu_;
-  return Point(1, std::exp(SpecFunc::LogGamma(0.5 * nu_ - n) - SpecFunc::LogGamma(0.5 * nu_)));
-}
-
 /* Get the standard representative in the parametric family, associated with the standard moments */
 Distribution InverseChiSquare::getStandardRepresentative() const
 {
-  return new InverseChiSquare(nu_);
+  InverseChiSquare standard(nu_);
+  standard.setDescription(getDescription());
+  return standard;
 }
 
 /* Compute the covariance of the distribution */
