@@ -2,7 +2,7 @@
 /**
  *  @brief The Laplace distribution
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -229,17 +229,12 @@ Point Laplace::getKurtosis() const
   return Point(1, 6.0);
 }
 
-/* Get the moments of the standardized distribution */
-Point Laplace::getStandardMoment(const UnsignedInteger n) const
-{
-  if ((n % 2) == 1) return Point(1, 0.0);
-  return Point(1, SpecFunc::Gamma(n + 1));
-}
-
 /* Get the standard representative in the parametric family, associated with the standard moments */
 Distribution Laplace::getStandardRepresentative() const
 {
-  return new Laplace(0.0, 1.0);
+  Laplace standard(0.0, 1.0);
+  standard.setDescription(getDescription());
+  return standard;
 }
 
 /* Compute the covariance of the distribution */
