@@ -2,7 +2,7 @@
 /**
  *  @brief The LogNormal distribution
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -332,16 +332,12 @@ Point LogNormal::getKurtosis() const
   return Point(1, -3.0 + expSigmaLog2 * expSigmaLog2 * (3.0 + expSigmaLog2 * (2.0 + expSigmaLog2)));
 }
 
-/* Get the moments of the standardized distribution */
-Point LogNormal::getStandardMoment(const UnsignedInteger n) const
-{
-  return Point(1, std::exp(n * muLog_ + 0.5 * std::pow(n * sigmaLog_, 2)));
-}
-
 /* Get the standard representative in the parametric family, associated with the standard moments */
 Distribution LogNormal::getStandardRepresentative() const
 {
-  return new LogNormal(muLog_, sigmaLog_, 0.0);
+  LogNormal standard(muLog_, sigmaLog_, 0.0);
+  standard.setDescription(getDescription());
+  return standard;
 }
 
 /* Compute the covariance of the distribution */
