@@ -2,7 +2,7 @@
 /**
  *  @brief The maximum entropy order statistics distribution
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -616,110 +616,6 @@ Scalar MaximumEntropyOrderStatisticsDistribution::computeCDF(const Point & point
 }
 
 
-Scalar MaximumEntropyOrderStatisticsDistribution::computeCDFOld(const Point & point) const
-{
-  const UnsignedInteger dimension = getDimension();
-  if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=" << dimension << ", here dimension=" << point.getDimension();
-  // If there is a miracle: we are in the independent case!
-  if (hasIndependentCopula())
-  {
-    Scalar cdf = distributionCollection_[0].computeCDF(point[0]);
-    for (UnsignedInteger k = 1; k < dimension; ++k) cdf *= distributionCollection_[k].computeCDF(point[k]);
-    return cdf;
-  }
-  // Indices of the components to take into account in the computation
-  Indices toKeep(0);
-  Point reducedPoint(0);
-  const Point lowerBound(getRange().getLowerBound());
-  const Point upperBound(getRange().getUpperBound());
-  for (UnsignedInteger k = 0; k < dimension; ++ k)
-  {
-    const Scalar xK = point[k];
-    // Early exit if one component is nonpositive
-    if (xK <= lowerBound[k]) return 0.0;
-    // Keep only the indices for which xK is in (xk_min, xk_max) and xK < xKp1
-    // Marginalize the others
-    const Scalar bound = k < dimension - 1 ? std::min(point[k + 1], upperBound[k]) : upperBound[k];
-    if (xK < bound)
-    {
-      toKeep.add(k);
-      reducedPoint.add(xK);
-    }
-  } // k
-  // If all the components are greater or equal to their marginal upper bound
-  if (toKeep.getSize() == 0)
-  {
-    return 1.0;
-  }
-  // If one or more components (but not all) are greater or equal to their marginal upper bound compute a marginal CDF
-  if (toKeep.getSize() < dimension)
-  {
-    const Scalar cdf = getMarginal(toKeep).computeCDF(reducedPoint);
-    return cdf;
-  }
-  // Else we have to do some work
-  // Try to split the work into smaller pieces using potential block-independence
-  const UnsignedInteger partitionSize = partition_.getSize();
-  if (partitionSize > 0)
-  {
-    Scalar cdf = 1.0;
-    UnsignedInteger firstIndex = 0;
-    for (UnsignedInteger i = 0; i <= partitionSize; ++i)
-    {
-      const UnsignedInteger lastIndex = i < partitionSize ? partition_[i] + 1 : dimension;
-      Indices dependentBlockIndices(lastIndex - firstIndex);
-      dependentBlockIndices.fill(firstIndex);
-      const UnsignedInteger blockSize = dependentBlockIndices.getSize();
-      reducedPoint = Point(blockSize);
-      for (UnsignedInteger k = 0; k < blockSize; ++k) reducedPoint[k] = point[firstIndex + k];
-      // The cdf is obtained by multiplying lower dimensional cdf, which are much more cheaper to compute than a full multidimensional integration
-      const Distribution marginal(getMarginal(dependentBlockIndices));
-      const Scalar blockCDF = marginal.computeCDF(reducedPoint);
-      cdf *= blockCDF;
-      firstIndex = lastIndex;
-    }
-    return cdf;
-  }
-
-  // Here we are in the full dependent case. Use Gauss-Legendre integration restricted to the support of the copula.
-  // We know that for each k, xk is in (xk_min, xk_max) and for k<dim, xk<xkp1
-  Scalar cdf = 0.0;
-
-  Point gaussWeights;
-  const Point gaussNodes(getGaussNodesAndWeights(gaussWeights));
-  // Perform the integration
-  // There are N^{d-1} integration points to compute:
-  // I = \int_{lb_1}^{x_1}\int_{\max(t_1, lb_2)}^{x_2}\dots\int_{\max(t_{d-2}, lb_{d-1})}^{x_{d-1}}F(x_d|t_1,\dots,t_{d-1})pdf(t_1,\dots,t_{d-1})dt_1\dots dt_{d-1}
-  const UnsignedInteger marginalNodesNumber = getIntegrationNodesNumber();
-  const UnsignedInteger size = std::pow(static_cast< Scalar > (marginalNodesNumber), static_cast< Scalar > (dimension));
-  Indices indices(dimension, 0);
-  for (UnsignedInteger linearIndex = 0; linearIndex < size; ++linearIndex)
-  {
-    Point node(dimension);
-    const Scalar delta0 = 0.5 * (point[0] - lowerBound[0]);
-    const UnsignedInteger index0 = indices[0];
-    node[0] = lowerBound[0] + delta0 * (1.0 + gaussNodes[index0]);
-    Scalar weight = delta0 * gaussWeights[index0];
-    for (UnsignedInteger j = 1; j < dimension; ++j)
-    {
-      const UnsignedInteger indexJ = indices[j];
-      const Scalar aJ = std::max(node[j - 1], distributionCollection_[j].getRange().getLowerBound()[0]);
-      const Scalar deltaJ = 0.5 * (point[j] - aJ);
-      node[j] = aJ + deltaJ * (1.0 + gaussNodes[indexJ]);
-      weight *= deltaJ * gaussWeights[indexJ];
-    }
-    cdf += weight * computePDF(node);
-    /* Update the indices */
-    ++indices[0];
-    /* Propagate the remainders */
-    for (UnsignedInteger j = 0; j < dimension - 1; ++j) indices[j + 1] += (indices[j] == marginalNodesNumber);
-    /* Correction of the indices. The last index cannot overflow. */
-    for (UnsignedInteger j = 0; j < dimension - 1; ++j) indices[j] = indices[j] % marginalNodesNumber;
-  } // Loop over the n-D nodes
-  return cdf;
-}
-
-
 /* Compute the PDF of Xi | X1, ..., Xi-1. x = Xi, y = (X1,...,Xi-1) */
 Scalar MaximumEntropyOrderStatisticsDistribution::computeConditionalPDF (const Scalar x,
     const Point & y) const
@@ -984,7 +880,7 @@ MaximumEntropyOrderStatisticsDistribution::PointWithDescriptionCollection Maximu
     const PointWithDescriptionCollection marginalParameters(distributionCollection_[marginalIndex].getParametersCollection());
     PointWithDescription point(marginalParameters[0]);
     Description marginalParametersDescription(point.getDescription());
-    // Here we must add a unique prefix to the marginal parameters description in order to deambiguate the parameters of different marginals sharing the same description
+    // Here we must add a unique prefix to the marginal parameters description in order to disambiguate the parameters of different marginals sharing the same description
     for (UnsignedInteger i = 0; i < point.getDimension(); ++i) marginalParametersDescription[i] = (OSS() << marginalParametersDescription[i] << "_marginal_" << marginalIndex);
     point.setDescription(marginalParametersDescription);
     point.setName(description[marginalIndex]);
