@@ -2,7 +2,7 @@
 /**
  *  @brief The MixedHistogramUserDefined distribution
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -51,6 +51,7 @@ MixedHistogramUserDefined::MixedHistogramUserDefined()
 {
   setName("MixedHistogramUserDefined");
   setDimension(1);
+  DistFunc::rDiscreteSetup(normalizedProbabilityTable_, base_, alias_);
   computeRange();
 }
 
@@ -98,6 +99,7 @@ MixedHistogramUserDefined::MixedHistogramUserDefined(const PointCollection & tic
   for (UnsignedInteger i = 0; i < probabilityTable_.getSize(); ++ i)
     weightSum += probabilityTable_[i];
   normalizedProbabilityTable_ = probabilityTable_ / weightSum;
+  DistFunc::rDiscreteSetup(normalizedProbabilityTable_, base_, alias_);
 
   setDimension(dimension);
   computeRange();
@@ -169,8 +171,6 @@ void MixedHistogramUserDefined::computeRange()
 Point MixedHistogramUserDefined::getRealization() const
 {
   const UnsignedInteger dimension = getDimension();
-  if (!base_.getSize())
-    (void) DistFunc::rDiscrete(normalizedProbabilityTable_, base_, alias_);
   const UnsignedInteger index = DistFunc::rDiscrete(base_, alias_);
   Point realization(dimension);
   for (UnsignedInteger j = 0; j < discreteIndices_.getSize(); ++j)
@@ -566,16 +566,6 @@ void MixedHistogramUserDefined::computeCovariance() const
   isAlreadyComputedCovariance_ = true;
 }
 
-/* Get the moments of the standardized distribution */
-Point MixedHistogramUserDefined::getStandardMoment(const UnsignedInteger n) const
-{
-  const UnsignedInteger dimension = getDimension();
-  Point standardMoment(dimension);
-  for (UnsignedInteger i = 0; i < dimension; ++i)
-    standardMoment[i] = getMarginal(i).getStandardMoment(n)[0];
-  return standardMoment;
-}
-
 /* Get the standard representative in the parametric family, associated with the standard moments */
 Distribution MixedHistogramUserDefined::getStandardRepresentative() const
 {
