@@ -2,7 +2,7 @@
 /**
  *  @brief Abstract top-level class for all Mixtures
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -235,6 +235,8 @@ void Mixture::setDistributionCollectionWithWeights(const DistributionCollection
   // To force initialization at the first call to getRealization()
   base_ = Point(0);
   alias_ = Indices(0);
+  if (!uniformWeights_)
+    DistFunc::rDiscreteSetup(p_, base_, alias_);
   setDimension(dimension);
   isAlreadyComputedMean_ = false;
   isAlreadyComputedCovariance_ = false;
@@ -254,7 +256,7 @@ void Mixture::setDistributionCollectionWithWeights(const DistributionCollection
 
 
 /* Distribution collection accessor */
-const Mixture::DistributionCollection & Mixture::getDistributionCollection() const
+Mixture::DistributionCollection Mixture::getDistributionCollection() const
 {
   return distributionCollection_;
 }
@@ -270,7 +272,7 @@ Mixture * Mixture::clone() const
 Point Mixture::getRealization() const
 {
   // Select the atom following the weightsDistribution
-  const UnsignedInteger index = (uniformWeights_ ? RandomGenerator::IntegerGenerate(distributionCollection_.getSize()) : (base_.getSize() ? DistFunc::rDiscrete(base_, alias_) : DistFunc::rDiscrete(p_, base_, alias_)));
+  const UnsignedInteger index = (uniformWeights_ ? RandomGenerator::IntegerGenerate(distributionCollection_.getSize()) : DistFunc::rDiscrete(base_, alias_));
   return distributionCollection_[index].getRealization();
 }
 
