@@ -2,7 +2,7 @@
 /**
  *  @brief The Normal distribution
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -176,7 +176,7 @@ Point Normal::getRealization() const
     return value;
   }
   // General case
-  return cholesky_ * value + mean_;
+  return inverseCholesky_.solveLinearSystem(value) + mean_;
 }
 
 Sample Normal::getSample(const UnsignedInteger size) const
@@ -190,7 +190,11 @@ Sample Normal::getSample(const UnsignedInteger size) const
     for (UnsignedInteger i = 0; i < size; ++i)
       for (UnsignedInteger j = 0; j < dimension; ++j) result(i, j) = DistFunc::rNormal();
     if (hasIndependentCopula_) result *= sigma_;
-    else result = cholesky_.getImplementation()->genSampleProd(result, true, false, 'R');
+    else
+    {
+      const TriangularMatrix cholesky(getCholesky());
+      result = cholesky.getImplementation()->genSampleProd(result, true, false, 'R');
+    }
   }
   result += mean_;
   result.setName(getName());
@@ -644,7 +648,7 @@ Point Normal::computeSequentialConditionalQuantile(const Point & q) const
       result[i] = mean_[i] + sigma_[i] * DistFunc::qNormal(q[i]);
     return result;
   }
-  return mean_ + cholesky_ * DistFunc::qNormal(q);
+  return mean_ + inverseCholesky_.solveLinearSystem(DistFunc::qNormal(q));
 }
 
 /* Get the i-th marginal distribution */
@@ -697,20 +701,12 @@ Point Normal::getSkewness() const
   return Point(getDimension(), 0.0);
 }
 
-/* Get the moments of the standardized distribution */
-Point Normal::getStandardMoment(const UnsignedInteger n) const
-{
-  if (n % 2 == 1) return Point(1, 0.0);
-  Scalar moment = 1.0;
-  for (UnsignedInteger i = 1; i < n / 2; ++i)
-    moment *= 2.0 * i + 1.0;
-  return Point(1, moment);
-}
-
 /* Get the standard representative in the parametric family, associated with the standard moments */
 Distribution Normal::getStandardRepresentative() const
 {
-  return Normal(0.0, 1.0);
+  Normal standard(getDimension());
+  standard.setDescription(getDescription());
+  return standard;
 }
 
 /* Get the roughness, i.e. the L2-norm of the PDF */
@@ -730,7 +726,7 @@ Scalar Normal::getRoughness() const
   else
   {
     for (UnsignedInteger d = 0; d < dimension_; ++d)
-      roughness *= 0.2820947917738781434740398 / cholesky_(d, d);
+      roughness *= 0.2820947917738781434740398 * inverseCholesky_(d, d);
   }
   return roughness;
 }
