@@ -2,7 +2,7 @@
 /**
  *  @brief A class that implements a normal copula
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -585,6 +585,17 @@ Bool NormalCopula::hasIndependentCopula() const
   return normal_.hasIndependentCopula();
 }
 
+/* Dependence coefficients */
+CorrelationMatrix NormalCopula::computeUpperTailDependenceMatrix() const
+{
+  return CorrelationMatrix(getDimension());
+}
+
+CorrelationMatrix NormalCopula::computeLowerTailDependenceMatrix() const
+{
+  return CorrelationMatrix(getDimension());
+}
+
 void NormalCopula::setParametersCollection(const PointCollection & parametersCollection)
 {
   // Check if the given parameters are ok
