@@ -2,7 +2,7 @@
 /**
  *  @brief Abstract top-level class for Parametrized distributions
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -230,12 +230,6 @@ Point ParametrizedDistribution::getKurtosis() const
   return distribution_.getKurtosis();
 }
 
-/* Get the raw moments of the standardized distribution */
-Point ParametrizedDistribution::getStandardMoment(const UnsignedInteger n) const
-{
-  return distribution_.getStandardMoment(n);
-}
-
 /* Get the standard representative in the parametric family, associated with the standard moments */
 Distribution ParametrizedDistribution::getStandardRepresentative() const
 {
