@@ -2,7 +2,7 @@
 /**
  *  @brief The Rayleigh distribution
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -245,16 +245,12 @@ Point Rayleigh::getKurtosis() const
   return Point(1, 3.245089300687638062848667);
 }
 
-/* Get the moments of the distribution */
-Point Rayleigh::getStandardMoment(const UnsignedInteger n) const
-{
-  return Point(1, std::exp(0.5 * n * M_LN2 + SpecFunc::LnGamma(1.0 + 0.5 * n)));
-}
-
 /* Get the standard representative in the parametric family, associated with the standard moments */
 Distribution Rayleigh::getStandardRepresentative() const
 {
-  return new Rayleigh(1.0, 0.0);
+  Rayleigh standard(1.0, 0.0);
+  standard.setDescription(getDescription());
+  return standard;
 }
 
 /* Compute the covariance of the distribution */
