@@ -2,7 +2,7 @@
 /**
  *  @brief The Student distribution
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -172,7 +172,7 @@ Point Student::getRealization() const
   Point value(dimension);
   // First, a realization of independent standard normal coordinates
   for (UnsignedInteger i = 0; i < dimension; ++i) value[i] = DistFunc::rNormal();
-  return std::sqrt(0.5 * nu_ / DistFunc::rGamma(0.5 * nu_)) * (cholesky_ * value) + mean_;
+  return std::sqrt(0.5 * nu_ / DistFunc::rGamma(0.5 * nu_)) * inverseCholesky_.solveLinearSystem(value) + mean_;
 }
 
 
@@ -191,7 +191,10 @@ Sample Student::getSample(const UnsignedInteger size) const
   if (dimension == 1)
     result = normalSample * sigma_[0];
   else
-    result = (cholesky_.getImplementation()->genSampleProd(normalSample, true, false, 'R'));
+  {
+    const TriangularMatrix cholesky(getCholesky());
+    result = (cholesky.getImplementation()->genSampleProd(normalSample, true, false, 'R'));
+  }
   for (UnsignedInteger i = 0; i < size; ++i)
   {
     const Scalar alpha = std::sqrt(0.5 * nu_ / gammaDeviates[i]);
@@ -398,10 +401,11 @@ Scalar Student::computeConditionalPDF(const Scalar x,
   UnsignedInteger stop = conditioningDimension;
   UnsignedInteger shift = 0;
   Point yCentered(conditioningDimension);
+  const TriangularMatrix cholesky(getCholesky());
   for (UnsignedInteger i = 0; i < conditioningDimension; ++i)
   {
     yCentered[i] = y[i] - mean_[i];
-    std::copy(cholesky_.getImplementation()->begin() + start, cholesky_.getImplementation()->begin() + stop, cholY.begin() + shift);
+    std::copy(cholesky.getImplementation()->begin() + start, cholesky.getImplementation()->begin() + stop, cholY.begin() + shift);
     start += dimension_ + 1;
     stop += dimension_;
     shift += conditioningDimension + 1;
@@ -449,10 +453,11 @@ Scalar Student::computeConditionalCDF(const Scalar x,
   UnsignedInteger stop = conditioningDimension;
   UnsignedInteger shift = 0;
   Point yCentered(conditioningDimension);
+  const TriangularMatrix cholesky(getCholesky());
   for (UnsignedInteger i = 0; i < conditioningDimension; ++i)
   {
     yCentered[i] = y[i] - mean_[i];
-    std::copy(cholesky_.getImplementation()->begin() + start, cholesky_.getImplementation()->begin() + stop, cholY.begin() + shift);
+    std::copy(cholesky.getImplementation()->begin() + start, cholesky.getImplementation()->begin() + stop, cholY.begin() + shift);
     start += dimension_ + 1;
     stop += dimension_;
     shift += conditioningDimension + 1;
@@ -498,10 +503,11 @@ Scalar Student::computeConditionalQuantile(const Scalar q,
   UnsignedInteger stop = conditioningDimension;
   UnsignedInteger shift = 0;
   Point yCentered(conditioningDimension);
+  const TriangularMatrix cholesky(getCholesky());
   for (UnsignedInteger i = 0; i < conditioningDimension; ++i)
   {
     yCentered[i] = y[i] - mean_[i];
-    std::copy(cholesky_.getImplementation()->begin() + start, cholesky_.getImplementation()->begin() + stop, cholY.begin() + shift);
+    std::copy(cholesky.getImplementation()->begin() + start, cholesky.getImplementation()->begin() + stop, cholY.begin() + shift);
     start += dimension_ + 1;
     stop += dimension_;
     shift += conditioningDimension + 1;
@@ -624,22 +630,12 @@ CovarianceMatrix Student::getCovariance() const
   return EllipticalDistribution::getCovariance();
 }
 
-/* Get the moments of the standardized distribution */
-Point Student::getStandardMoment(const UnsignedInteger n) const
-{
-  if (n >= nu_) throw NotDefinedException(HERE) << "Error: cannot compute a standard moment of order greater or equal to the number of degrees of freedom";
-  if (n % 2 == 1) return Point(1, 0.0);
-  Scalar moment = 1.0;
-  for (UnsignedInteger i = 0; i < n / 2; ++i) moment *= (nu_ * (2 * i + 1)) / (nu_ - 2 * (i + 1));
-  // Alternate expression, not very useful as the raw moments overflow the double precision for n approximately equal to 300 (if nu is large enough), and for these values the loop is equivalent to the analytic expression both in terms of speed and
-  // const Scalar moment(exp(0.5 * n * std::log(nu_) + SpecFunc::LogGamma(0.5 * (n + 1.0)) + SpecFunc::LogGamma(0.5 * (nu_ - n)) - SpecFunc::LogGamma(0.5 * nu_)) / sqrt(M_PI));
-  return Point(1, moment);
-}
-
 /* Get the standard representative in the parametric family, associated with the standard moments */
 Distribution Student::getStandardRepresentative() const
 {
-  return new Student(nu_);
+  Student standard(nu_, getDimension());
+  standard.setDescription(getDescription());
+  return standard;
 }
 
 /* Parameters value and description accessor */
