@@ -2,7 +2,7 @@
 /**
  *  @brief The Trapezoidal distribution
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -385,29 +385,12 @@ Point Trapezoidal::getKurtosis() const /*throw(NotDefinedException)*/
   return Point(1, fourthMoment / standardDeviation4);
 }
 
-/* Get the moments of the standardized distribution */
-Point Trapezoidal::getStandardMoment(const UnsignedInteger n) const
-{
-  if (n == 0) return Point(1, 1.0);
-  const Scalar beta = 1.0 - 2.0 * (d_ - b_) / (d_ - a_);
-  const Scalar gamma = 1.0 - 2.0 * (d_ - c_) / (d_ - a_);
-  const Scalar eta = 2.0 / (2.0 - beta + gamma);
-  const Scalar betaPow = std::pow(beta, n + 1.0);
-  const Scalar gammaPow = std::pow(gamma, n + 1.0);
-  Scalar value = eta * (gammaPow - betaPow) / (n + 1);
-  if (beta > -1.0)
-  {
-    if (n % 2 == 0) value += (eta / (beta + 1.0)) * ((beta * betaPow - 1.0) / (n + 2) + (betaPow + 1.0) / (n + 1));
-    else value += (eta / (beta + 1.0)) * ((beta * betaPow + 1.0) / (n + 2) + (betaPow - 1.0) / (n + 1));
-  }
-  if (gamma <  1.0) value -= (eta / (1.0 - gamma)) * ((1.0 - gamma * gammaPow) / (n + 2) - (1.0 - gammaPow) / (n + 1));
-  return Point(1, value);
-}
-
 /* Get the standard representative in the parametric family, associated with the standard moments */
 Distribution Trapezoidal::getStandardRepresentative() const
 {
-  return new Trapezoidal(-1.0, 1.0 - 2.0 * (d_ - b_) / (d_ - a_), 1.0 - 2.0 * (d_ - c_) / (d_ - a_), 1.0);
+  Trapezoidal standard(-1.0, 1.0 - 2.0 * (d_ - b_) / (d_ - a_), 1.0 - 2.0 * (d_ - c_) / (d_ - a_), 1.0);
+  standard.setDescription(getDescription());
+  return standard;
 }
 
 /* Compute the covariance of the distribution */
