@@ -2,7 +2,7 @@
 /**
  *  @brief The TruncatedNormal distribution
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -500,7 +500,9 @@ Point TruncatedNormal::getKurtosis() const
 /* Get the standard representative in the parametric family, associated with the standard moments */
 Distribution TruncatedNormal::getStandardRepresentative() const
 {
-  return new TruncatedNormal((2.0 * mu_ - (b_ + a_)) / (b_ - a_), 2.0 * sigma_ / (b_ - a_), -1.0, 1.0);
+  TruncatedNormal standard((2.0 * mu_ - (b_ + a_)) / (b_ - a_), 2.0 * sigma_ / (b_ - a_), -1.0, 1.0);
+  standard.setDescription(getDescription());
+  return standard;
 }
 
 /* Compute the covariance of the distribution */
