@@ -2,7 +2,7 @@
 /**
  *  @brief The Uniform distribution
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -292,17 +292,12 @@ void Uniform::computeCovariance() const
   isAlreadyComputedCovariance_ = true;
 }
 
-/* Get the moments of the standardized distribution */
-Point Uniform::getStandardMoment(const UnsignedInteger n) const
-{
-  if (n % 2 == 1) return Point(1, 0.0);
-  return Point(1, 1.0 / (n + 1));
-}
-
 /* Get the standard representative in the parametric family, associated with the standard moments */
 Distribution Uniform::getStandardRepresentative() const
 {
-  return new Uniform(-1.0, 1.0);
+  Uniform standard(-1.0, 1.0);
+  standard.setDescription(getDescription());
+  return standard;
 }
 
 /* Parameters value accessor */
