@@ -2,7 +2,7 @@
 /**
  *  @brief The UserDefined distribution
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -137,10 +137,7 @@ Point UserDefined::getRealization() const
   // Efficient algorithm for uniform weights
   if (hasUniformWeights_) index = RandomGenerator::IntegerGenerate(size);
   // Alias method for nonuniform weights
-  else
-  {
-    index = base_.getSize() ? DistFunc::rDiscrete(base_, alias_) : DistFunc::rDiscrete(probabilities_, base_, alias_);
-  }
+  else index = DistFunc::rDiscrete(base_, alias_);
   return points_[index];
 }
 
@@ -157,11 +154,7 @@ Sample UserDefined::getSample(const UnsignedInteger size) const
   }
   // Alias method for nonuniform weights
   else
-  {
-    if (!base_.getSize())
-      (void) DistFunc::rDiscrete(probabilities_, base_, alias_);
     indices = DistFunc::rDiscrete(base_, alias_, size);
-  }
   return points_.select(indices);
 }
 
@@ -259,9 +252,9 @@ Scalar UserDefined::computeCDF(const Point & point) const
   // Dimension > 1
   for (UnsignedInteger i = 0; i < size; ++i)
   {
-    const Point x(points_[i]);
-    UnsignedInteger j = 0;
-    while ((j < dimension) && (x[j] <= point[j] + supportEpsilon_)) ++j;
+    if (points_(i, 0) > point[0] + supportEpsilon_) break;
+    UnsignedInteger j = 1;
+    while ((j < dimension) && (points_(i, j) <= point[j] + supportEpsilon_)) ++j;
     if (j == dimension) cdf += probabilities_[i];
   }
   return cdf;
@@ -297,9 +290,8 @@ Point UserDefined::computeCDFGradient(const Point & point) const
   Point cdfGradient((dimension + 1) * size, 0.0);
   for (UnsignedInteger i = 0; i < size; ++i)
   {
-    const Point x(points_[i]);
     UnsignedInteger j = 0;
-    while ((j < dimension) && (point[j] <= x[j])) ++j;
+    while ((j < dimension) && (point[j] <= points_(i, j))) ++j;
     if (j == dimension) cdfGradient[i] = 1.0;
   }
   return cdfGradient;
@@ -522,18 +514,16 @@ void UserDefined::setData(const Sample & sample,
   if (size == 0) throw InvalidArgumentException(HERE) << "Error: the collection is empty";
   if (weights.getDimension() != size) throw InvalidArgumentException(HERE) << "Error: cannot build a UserDefined distribution if the weights don't have the same dimension as the sample size.";
   hasUniformWeights_ = true;
-  const UnsignedInteger dimension = sample[0].getDimension();
+  const UnsignedInteger dimension = sample.getDimension();
   if (dimension == 0) throw InvalidArgumentException(HERE) << "Error: the points in the collection must have a dimension > 0";
+  setDimension(dimension);
   // Check if all the given probabilities are >= 0
   // Check if all the points have the same dimension
-  for (UnsignedInteger i = 1; i < size; ++i) if (sample[i].getDimension() != dimension) throw InvalidArgumentException(HERE) << "UserDefined distribution must have all its point with the same dimension";
-  setDimension(dimension);
   // First, sort the collection such that the sample made with the first component is in ascending order
   Sample weightedData(size, dimension + 1);
   for (UnsignedInteger i = 0; i < size; ++i)
   {
-    const Point x(sample[i]);
-    for (UnsignedInteger j = 0; j < dimension; ++j) weightedData(i, j) = x[j];
+    for (UnsignedInteger j = 0; j < dimension; ++j) weightedData(i, j) = sample(i, j);
     weightedData(i, dimension) = weights[i];
   }
   // Sort the pairs
@@ -561,20 +551,19 @@ void UserDefined::setData(const Sample & sample,
   probabilities_ = Point(size);
   for (UnsignedInteger i = 0; i < size; ++i)
   {
-    Point x(dimension);
-    for (UnsignedInteger j = 0; j < dimension; ++j) x[j] = weightedData(i, j);
-    points_[i] = x;
-    probabilities_[i] = std::max(0.0, std::min(1.0, weightedData(i, dimension)));
+    for (UnsignedInteger j = 0; j < dimension; ++j) points_(i, j) = weightedData(i, j);
+    probabilities_[i] = SpecFunc::Clip01(weightedData(i, dimension));
   }
+  base_ = Point(0);
+  alias_ = Indices(0);
+  if (!hasUniformWeights_)
+    DistFunc::rDiscreteSetup(probabilities_, base_, alias_);
   // We augment slightly the last cumulative probability, which should be equal to 1.0 but we enforce a value > 1.0.
   cumulativeProbabilities_[size - 1] = 1.0 + 2.0 * supportEpsilon_;
   isAlreadyComputedMean_ = false;
   isAlreadyComputedCovariance_ = false;
   isAlreadyCreatedGeneratingFunction_ = false;
   computeRange();
-  // trigger reset of alias method
-  base_.clear();
-  alias_.clear();
 }
 
 
@@ -707,13 +696,13 @@ void UserDefined::compactSupport(const Scalar epsilon)
     else
     {
       compactX.add(Point(1, lastLocation));
-      compactP.add(std::max(0.0, std::min(1.0, lastWeight)));
+      compactP.add(SpecFunc::Clip01(lastWeight));
       lastLocation = currentLocation;
       lastWeight = currentWeight;
     }
   }
   compactX.add(Point(1, lastLocation));
-  compactP.add(std::max(0.0, std::min(1.0, lastWeight)));
+  compactP.add(SpecFunc::Clip01(lastWeight));
   setData(compactX, compactP);
 }
 
