@@ -2,7 +2,7 @@
 /**
  *  @brief Factory for WeibullMax distribution
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -61,7 +61,7 @@ Distribution WeibullMaxFactory::build() const
 
 WeibullMax WeibullMaxFactory::buildAsWeibullMax(const Sample & sample) const
 {
-  Distribution weibullMin(WeibullMinFactory().build(-1.0 * sample));
+  const Distribution weibullMin(WeibullMinFactory().build(-1.0 * sample));
   Point parameter(weibullMin.getParameter());
   parameter[2] *= -1.0;// location parameter (gamma)
   return buildAsWeibullMax(parameter);
