@@ -2,7 +2,7 @@
 /**
  *  @brief The WeibullMin distribution
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -201,7 +201,7 @@ Complex WeibullMin::computeCharacteristicFunction(const Scalar x) const
     const Complex term((term4 - term2) / alpha_, sign * (term1 - term3) / alpha_);
     oldNorm = norm;
     norm = std::abs(term);
-    // If the term grows too much, the cancelation will be too large
+    // If the term grows too much, the cancellation will be too large
     if (norm > 1e3) return DistributionImplementation::computeCharacteristicFunction(x);
     value += term;
     increasing = norm > oldNorm;
@@ -307,16 +307,12 @@ void WeibullMin::computeCovariance() const
   isAlreadyComputedCovariance_ = true;
 }
 
-/* Get the moments of the standardized distribution */
-Point WeibullMin::getStandardMoment(const UnsignedInteger n) const
-{
-  return Point(1, SpecFunc::Gamma(1.0 + n / alpha_));
-}
-
 /* Get the standard representative in the parametric family, associated with the standard moments */
 Distribution WeibullMin::getStandardRepresentative() const
 {
-  return new WeibullMin(1.0, alpha_, 0.0);
+  WeibullMin standard(1.0, alpha_, 0.0);
+  standard.setDescription(getDescription());
+  return standard;
 }
 
 /* Parameters value accessor */
