@@ -2,7 +2,7 @@
 /**
  *  @brief Abstract top-level class for all distributions
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -290,12 +290,6 @@ Point Distribution::getKurtosis() const
   return getImplementation()->getKurtosis();
 }
 
-/* Get the raw moments of the standardized distribution */
-Point Distribution::getStandardMoment(const UnsignedInteger n) const
-{
-  return getImplementation()->getStandardMoment(n);
-}
-
 /* Get the raw moments of the distribution */
 Point Distribution::getMoment(const UnsignedInteger n) const
 {
@@ -308,11 +302,6 @@ Point Distribution::getCentralMoment(const UnsignedInteger n) const
   return getImplementation()->getCentralMoment(n);
 }
 
-Point Distribution::getCenteredMoment(const UnsignedInteger n) const
-{
-  return getImplementation()->getCenteredMoment(n);
-}
-
 /* Get the shifted moments of the distribution */
 Point Distribution::getShiftedMoment(const UnsignedInteger n,
                                      const Point & shift) const
@@ -1191,6 +1180,48 @@ Graph Distribution::drawQuantile(const Scalar qMin,
   return getImplementation()->drawQuantile(qMin, qMax, pointNumber, logScale);
 }
 
+/* Dependence functions */
+CorrelationMatrix Distribution::computeUpperTailDependenceMatrix() const
+{
+  return getImplementation()->computeUpperTailDependenceMatrix();
+}
+
+CorrelationMatrix Distribution::computeUpperExtremalDependenceMatrix() const
+{
+  return getImplementation()->computeUpperExtremalDependenceMatrix();
+}
+
+CorrelationMatrix Distribution::computeLowerTailDependenceMatrix() const
+{
+  return getImplementation()->computeLowerTailDependenceMatrix();
+}
+
+CorrelationMatrix Distribution::computeLowerExtremalDependenceMatrix() const
+{
+  return getImplementation()->computeLowerExtremalDependenceMatrix();
+}
+
+/* Draw dependence functions */
+Graph Distribution::drawUpperTailDependenceFunction() const
+{
+  return getImplementation()->drawUpperTailDependenceFunction();
+}
+
+Graph Distribution::drawUpperExtremalDependenceFunction() const
+{
+  return getImplementation()->drawUpperExtremalDependenceFunction();
+}
+
+Graph Distribution::drawLowerTailDependenceFunction() const
+{
+  return getImplementation()->drawLowerTailDependenceFunction();
+}
+
+Graph Distribution::drawLowerExtremalDependenceFunction() const
+{
+  return getImplementation()->drawLowerExtremalDependenceFunction();
+}
+
 /* Parameters value and description accessor */
 Distribution::PointWithDescriptionCollection Distribution::getParametersCollection() const
 {
@@ -1257,7 +1288,7 @@ Scalar Distribution::getCDFEpsilon() const
   return getImplementation()->getCDFEpsilon();
 }
 
-/* Get a positon indicator for a 1D distribution */
+/* Get a position indicator for a 1D distribution */
 Scalar Distribution::getPositionIndicator() const
 {
   return getImplementation()->getPositionIndicator();
