@@ -2,7 +2,7 @@
 /**
  *  @brief A class which implements the ARMA process
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -19,7 +19,6 @@
  *
  */
 
-#include <limits>
 #include "openturns/ARMA.hxx"
 #include "openturns/PersistentObjectFactory.hxx"
 #include "openturns/Exception.hxx"
@@ -230,7 +229,7 @@ UnsignedInteger ARMA::getNThermalization() const
   if (!hasComputedNThermalization_)
   {
     // Not yet in SpecFunc
-    nThermalization_ = computeNThermalization(std::numeric_limits<Scalar>::epsilon());
+    nThermalization_ = computeNThermalization(SpecFunc::ScalarEpsilon);
     hasComputedNThermalization_ = true;
   }
   return nThermalization_;
