@@ -4,7 +4,7 @@
  *         basis and eigenvalues of a given covariance model based on
  *         quadrature approximation.
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -317,7 +317,7 @@ void KarhunenLoeveQuadratureAlgorithm::run()
   // Transform the eigenvectors to the generalized ones
   // Last time we need cholesky, so we can overwrite it by eigenVectors
   LOGINFO("Get the generalized eigenvectors");
-  eigenVectors = choleskyBlock.transpose().solveLinearSystem(eigenVectors, false).getImplementation();
+  eigenVectors = choleskyBlock.transpose().solveLinearSystemInPlace(eigenVectors).getImplementation();
   LOGINFO("Post-process the eigenvalue problem");
   Collection< std::pair<Scalar, UnsignedInteger> > eigenPairs(augmentedDimension);
   for (UnsignedInteger i = 0; i < augmentedDimension; ++i)
