@@ -2,7 +2,7 @@
 /**
  *  @brief The test file of class Basis for standard methods
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -52,7 +52,7 @@ int main(int, char *[])
 
   fullprint << "basis = " << myBasis << std::endl;
 
-  fullprint << "dimension = " << myBasis.getDimension() << std::endl;
+  fullprint << "dimension = " << myBasis.getInputDimension() << std::endl;
 
   return ExitCode::Success;
 }
