@@ -2,7 +2,7 @@
 /**
  *  @brief The test file of class Normal with wrong arguments
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -58,7 +58,7 @@ int main(int, char *[])
       distribution.setCorrelation(newR);
 
       // Normally, we should never go here
-      throw TestFailed("Exception has NOT been thrown or catched !");
+      throw TestFailed("Exception has NOT been thrown or caught !");
 
 
     }
