@@ -2,7 +2,7 @@
 /**
  *  @brief The test file of class Sample for load and save methods
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -149,16 +149,6 @@ int main(int, char *[])
       // Nothing to do
     }
 
-    // Print stream to R format
-    fullprint << "Stream to R format = " << aSample.getImplementation()->streamToRFormat() << std::endl;
-
-    // Store to a temporary file and compute difference with current aSample
-    const String tmpFilename(aSample.getImplementation()->storeToTemporaryFile());
-    Sample tmpSample(Sample::ImportFromTextFile(tmpFilename));
-    // Difference with aSample
-    assert_almost_equal(tmpSample, aSample, 1e-15, 1e-15);
-    Os::Remove(tmpFilename);
-
   }
   catch (TestFailed & ex)
   {
