@@ -2,7 +2,7 @@
 /**
  *  @brief The test file of class Sample for standard methods
  *
- *  Copyright 2005-2022 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -234,11 +234,11 @@ int main(int, char *[])
     try
     {
       // We get the tenth element of the sample
-      // THIS SHOULD NORMALY FAIL
+      // THIS SHOULD NORMALLY FAIL
       Point tenthElement = sample1.at(9);
 
       // Normally, we should never go here
-      throw TestFailed("Exception has NOT been thrown or catched !");
+      throw TestFailed("Exception has NOT been thrown or caught !");
 
     }
     catch (OutOfBoundException & ex)
@@ -246,6 +246,13 @@ int main(int, char *[])
       // Nothing to do
     }
 
+    // append itself
+    sample5.add(sample5);
+    fullprint << "sample5.add(sample5)=" << sample5 << std::endl;
+
+    // stack itself
+    sample5.stack(sample5);
+    fullprint << "sample5.stack(sample5)=" << sample5 << std::endl;
 
   }
   catch (TestFailed & ex)
