@@ -95,3 +95,7 @@ result.getThreshold()
 
 # %%
 result.getStatistic()
+
+# %%
+# Reset default settings
+ot.ResourceMap.Reload()
