@@ -8,16 +8,13 @@ Create a composed function
 
 # %%
 import openturns as ot
-import openturns.viewer as viewer
-from matplotlib import pylab as plt
-import math as m
+
 ot.Log.Show(ot.Log.NONE)
 
 # %%
 # assume f, g functions
-g = ot.SymbolicFunction(['x1', 'x2'],
-                        ['x1 + x2', '3 * x1 * x2'])
-f = ot.SymbolicFunction(['x1', 'x2'], ['2 * x1 - x2'])
+g = ot.SymbolicFunction(["x1", "x2"], ["x1 + x2", "3 * x1 * x2"])
+f = ot.SymbolicFunction(["x1", "x2"], ["2 * x1 - x2"])
 
 # %%
 # create the composed function
@@ -27,4 +24,4 @@ function = ot.ComposedFunction(f, g)
 # evaluate the function
 x = [3.0, 4.0]
 y = function(x)
-print('x=', x, 'y=', y)
+print("x=", x, "y=", y)
