@@ -22,18 +22,16 @@ Create a linear combination of functions
 
 # %%
 import openturns as ot
-import openturns.viewer as viewer
-from matplotlib import pylab as plt
-import math as m
+
 ot.Log.Show(ot.Log.NONE)
 
 # %%
 # assume a list of functions to combine
 functions = list()
-functions.append(ot.SymbolicFunction(['x1', 'x2', 'x3'],
-                                     ['x1^2 + x2', 'x1 + x2 + x3']))
-functions.append(ot.SymbolicFunction(['x1', 'x2', 'x3'],
-                                     ['x1 + 2 * x2 + x3', 'x1 + x2 - x3']))
+functions.append(ot.SymbolicFunction(["x1", "x2", "x3"], ["x1^2 + x2", "x1 + x2 + x3"]))
+functions.append(
+    ot.SymbolicFunction(["x1", "x2", "x3"], ["x1 + 2 * x2 + x3", "x1 + x2 - x3"])
+)
 
 # %%
 # create the combination function
@@ -44,4 +42,4 @@ function = ot.LinearCombinationFunction(functions, coefficients)
 # evaluate the function
 x = [1.0, 2.0, 3.0]
 y = function(x)
-print('x=', x, 'y=', y)
+print("x=", x, "y=", y)
