@@ -6,14 +6,14 @@ Metamodel of a field function
 #
 # In this example we are going to create a metamodel of a field function following these steps:
 #
-# 1. Creation of a field model over an 1-d mesh.
-# 2. Creation of a Gaussian process.
-# 3. Karhunen-Loeve decomposition of a process with known covariance function.
-# 4. Karhunen-Loeve decomposition of a process with known trajectories.
-# 5. Projection of fields.
-# 6. Functional chaos decomposition between the coefficients of the input and output processes.
-# 7. Build a metamodel of the whole field model.
-# 8. Validate the metamodel.
+# 1. create a field model over an 1-d mesh ;
+# 2. create a Gaussian process ;
+# 3. Karhunen-Loeve decomposition of a process with known covariance function ;
+# 4. Karhunen-Loeve decomposition of a process with known trajectories ;
+# 5. fields projection ;
+# 6. functional chaos decomposition between the coefficients of the input and output processes ;
+# 7. build a metamodel of the whole field model ;
+# 8. validate the metamodel.
 #
 
 # %%
@@ -24,7 +24,8 @@ from matplotlib import pylab as plt
 ot.Log.Show(ot.Log.NONE)
 
 # %%
-# Input model
+# Create the input model.
+
 print("Create the input process")
 # Domain bound
 a = 1
@@ -41,7 +42,7 @@ process_X = ot.GaussianProcess(covariance_X, mesh)
 
 
 # %%
-# for some pretty graphs
+# The next function plots the Karhunen-Loève. modes.
 def drawKL(scaledKL, KLev, mesh, title="Scaled KL modes"):
     graph_modes = scaledKL.drawMarginal()
     graph_modes.setTitle(title + " scaled KL modes")
@@ -66,8 +67,7 @@ def drawKL(scaledKL, KLev, mesh, title="Scaled KL modes"):
 
 
 # %%
-# Karhunen-Loeve decomposition of the input process
-print("Compute the decomposition of the input process")
+# Compute the decomposition of the input process.
 threshold = 0.0001
 algo_X = ot.KarhunenLoeveP1Algorithm(mesh, process_X.getCovarianceModel(), threshold)
 algo_X.run()
@@ -80,14 +80,15 @@ view = viewer.View(graph_modes_X)
 
 
 # %%
-# Input database generation
+# Sample the input process.
 print("Sample the input process")
-size = 1000
+size = 500
 sample_X = process_X.getSample(size)
 
-
 # %%
-# The field model: convolution over an 1-d mesh
+# Create a class to perform the convolution over a 1-d mesh.
+
+
 class ConvolutionP1(ot.OpenTURNSPythonFieldFunction):
     def __init__(self, p, mesh):
         # 1 = input dimension, the dimension of the input field
@@ -115,19 +116,16 @@ class ConvolutionP1(ot.OpenTURNSPythonFieldFunction):
 
 
 # %%
-# Dynamical model: convolution wrt kernel p
-print("Create the convolution function")
+# Create the convolution function.
 p = ot.SymbolicFunction("x", "exp(-(x/" + str(h) + ")^2)")
 myConvolution = ot.FieldFunction(ConvolutionP1(p, mesh))
 
 # %%
-# Output database generation
-print("Sample the output process")
+# Sample the output process.
 sample_Y = myConvolution(sample_X)
 
 # %%
-# Karhunen-Loeve decomposition of the output process
-print("Compute the decomposition of the output process")
+# Compute the decomposition of the output process.
 algo_Y = ot.KarhunenLoeveSVDAlgorithm(sample_Y, threshold)
 algo_Y.run()
 result_Y = algo_Y.getResult()
@@ -137,7 +135,7 @@ graph_modes_Y, graph_ev_Y = drawKL(phi_Y, lambda_Y, mesh, "Y")
 view = viewer.View(graph_modes_Y)
 
 # %%
-# Compare eigenvalues of X and Y
+# Compare eigenvalues of X and Y.
 graph_ev_X.add(graph_ev_Y)
 graph_ev_X.setTitle("Input/output eigenvalues comparison")
 graph_ev_X.setYTitle(r"$\lambda_X, \lambda_Y$")
@@ -147,7 +145,7 @@ graph_ev_X.setLegendPosition("topright")
 view = viewer.View(graph_ev_X)
 
 # %%
-# Polynomial chaos between KL coefficients
+# Perform the polynomial chaos expansion between Karhunen-Loève coefficients.
 print("project sample_X")
 sample_xi_X = result_X.project(sample_X)
 
@@ -203,7 +201,7 @@ meta_model_field = ot.FieldToFieldConnection(
 
 
 # %%
-# Meta_model validation
+# Validate the metamodel.
 iMax = 10
 sample_X_validation = process_X.getSample(iMax)
 sample_Y_validation = myConvolution(sample_X_validation)
@@ -234,3 +232,7 @@ graph_sample_Y.setXTitle(r"$t$")
 graph_sample_Y.setYTitle(r"$Y$")
 view = viewer.View(graph_sample_Y)
 plt.show()
+
+# %%
+# Reset default settings
+ot.ResourceMap.Reload()
