@@ -51,7 +51,10 @@ dimension
 
 
 # %%
-# Then we define the Python function which computes the altitude at each time value. In order to compute all altitudes with a vectorized evaluation, we first convert the vertices into a Numpy `array` and use the Numpy functions`exp` and `maximum`: this increases the evaluation performance of the script.
+# Then we define the Python function which computes the altitude at each time value.
+# In order to compute all altitudes with a vectorized evaluation, we first convert
+# the vertices into a Numpy `array` and use the Numpy functions`exp` and `maximum`:
+# this increases the evaluation performance of the script.
 
 # %%
 def AltiFunc(X):
@@ -69,7 +72,9 @@ def AltiFunc(X):
 
 
 # %%
-# In order to create a `Function` from this Python function, we use the `PythonPointToFieldFunction` class. Since the altitude is the only output field, the third argument `outputDimension` is equal to `1`. If we had computed the speed as an extra output field, we would have set `2` instead.
+# In order to create a `Function` from this Python function, we use the `PythonPointToFieldFunction` class.
+# Since the altitude is the only output field, the third argument `outputDimension` is equal to `1`.
+# If we had computed the speed as an extra output field, we would have set `2` instead.
 
 # %%
 outputDimension = 1
@@ -159,4 +164,12 @@ view = viewer.View(graph)
 plt.show()
 
 # %%
-# We see that the blue trajectories (i.e. the metamodel) are close to the red trajectories (i.e. the validation sample). This shows that the metamodel is quite accurate. However, we observe that the trajectory singularity that occurs when the object touches the ground (i.e. when :math:`z` is equal to zero), makes the metamodel less accurate.
+# We see that the blue trajectories (i.e. the metamodel) are close to the red
+# trajectories (i.e. the validation sample).
+# This shows that the metamodel is quite accurate.
+# However, we observe that the trajectory singularity that occurs when the object
+# touches the ground (i.e. when :math:`z` is equal to zero), makes the metamodel less accurate.
+
+# %%
+# Reset ResourceMap
+ot.ResourceMap.Reload()
