@@ -9,6 +9,7 @@ Create the ordinal sum of copulas
 import openturns as ot
 import openturns.viewer as viewer
 from matplotlib import pylab as plt
+
 ot.Log.Show(ot.Log.NONE)
 
 # %%
@@ -23,9 +24,9 @@ print(copula)
 
 # %%
 # Draw PDF
-graph = copula.drawPDF([512]*2)
-graph.setXTitle('x')
-graph.setYTitle('y')
-graph.setLegendPosition('')
+graph = copula.drawPDF([512] * 2)
+graph.setXTitle("x")
+graph.setYTitle("y")
+graph.setLegendPosition("")
 view = viewer.View(graph)
 plt.show()
