@@ -15,7 +15,7 @@ Add a trend to a process
 import openturns as ot
 import openturns.viewer as viewer
 from matplotlib import pylab as plt
-import math as m
+
 ot.Log.Show(ot.Log.NONE)
 
 # %%
@@ -29,24 +29,24 @@ X = ot.GaussianProcess(covModel, grid)
 # %%
 # Draw a sample
 sample = X.getSample(6)
-sample.setName('X')
+sample.setName("X")
 graph = sample.drawMarginal(0)
 view = viewer.View(graph)
 
 # %%
 # Define a trend function
-f = ot.SymbolicFunction(['t'], ['30*t'])
+f = ot.SymbolicFunction(["t"], ["30*t"])
 fTrend = ot.TrendTransform(f, grid)
 
 # %%
 # Add it to the process
 Y = ot.CompositeProcess(fTrend, X)
-Y.setName('Y')
+Y.setName("Y")
 
 # %%
 # Draw a sample
 sample = Y.getSample(6)
-sample.setName('Y')
+sample.setName("Y")
 graph = sample.drawMarginal(0)
 view = viewer.View(graph)
 plt.show()
