@@ -8,8 +8,7 @@ Estimate a probability with Latin Hypercube Sampling
 # %%
 from openturns.usecases import stressed_beam
 import openturns as ot
-import openturns.viewer as viewer
-from matplotlib import pylab as plt
+
 ot.Log.Show(ot.Log.NONE)
 
 # %%
@@ -47,4 +46,4 @@ algo.run()
 # %%
 result = algo.getResult()
 probability = result.getProbabilityEstimate()
-print('Pf=', probability)
+print("Pf=", probability)
