@@ -10,8 +10,7 @@ Estimate a probability with Monte Carlo
 # %%
 from openturns.usecases import stressed_beam
 import openturns as ot
-import openturns.viewer as viewer
-from matplotlib import pylab as plt
+
 ot.Log.Show(ot.Log.NONE)
 
 # %%
@@ -50,4 +49,4 @@ algo.run()
 # %%
 result = algo.getResult()
 probability = result.getProbabilityEstimate()
-print('Pf=', probability)
+print("Pf=", probability)
