@@ -8,8 +8,7 @@ Use a randomized QMC algorithm
 # %%
 from openturns.usecases import cantilever_beam
 import openturns as ot
-import openturns.viewer as viewer
-from matplotlib import pylab as plt
+
 ot.Log.Show(ot.Log.NONE)
 
 # %%
@@ -55,4 +54,4 @@ algo.run()
 # %%
 result = algo.getResult()
 probability = result.getProbabilityEstimate()
-print('Pf=', probability)
+print("Pf=", probability)
